Struct aws_sdk_securityhub::client::fluent_builders::DeleteInsight
source · pub struct DeleteInsight { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteInsight.
Deletes the insight specified by the InsightArn.
Implementations
sourceimpl DeleteInsight
impl DeleteInsight
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DeleteInsight, AwsResponseRetryClassifier>, SdkError<DeleteInsightError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DeleteInsight, AwsResponseRetryClassifier>, SdkError<DeleteInsightError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DeleteInsightOutput, SdkError<DeleteInsightError>>
pub async fn send(
self
) -> Result<DeleteInsightOutput, SdkError<DeleteInsightError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn insight_arn(self, input: impl Into<String>) -> Self
pub fn insight_arn(self, input: impl Into<String>) -> Self
The ARN of the insight to delete.
sourcepub fn set_insight_arn(self, input: Option<String>) -> Self
pub fn set_insight_arn(self, input: Option<String>) -> Self
The ARN of the insight to delete.