pub struct DisassociateFromAdministratorAccount { /* private fields */ }Expand description
Fluent builder constructing a request to DisassociateFromAdministratorAccount.
Disassociates the current Security Hub member account from the associated administrator account.
This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.
Implementations
sourceimpl DisassociateFromAdministratorAccount
impl DisassociateFromAdministratorAccount
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DisassociateFromAdministratorAccount, AwsResponseRetryClassifier>, SdkError<DisassociateFromAdministratorAccountError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DisassociateFromAdministratorAccount, AwsResponseRetryClassifier>, SdkError<DisassociateFromAdministratorAccountError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DisassociateFromAdministratorAccountOutput, SdkError<DisassociateFromAdministratorAccountError>>
pub async fn send(
self
) -> Result<DisassociateFromAdministratorAccountOutput, SdkError<DisassociateFromAdministratorAccountError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.