Enum aws_sdk_securityhub::error::DeleteFindingAggregatorErrorKind[][src]

#[non_exhaustive]
pub enum DeleteFindingAggregatorErrorKind {
    AccessDeniedException(AccessDeniedException),
    InternalException(InternalException),
    InvalidAccessException(InvalidAccessException),
    InvalidInputException(InvalidInputException),
    LimitExceededException(LimitExceededException),
    ResourceNotFoundException(ResourceNotFoundException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the DeleteFindingAggregator operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccessDeniedException(AccessDeniedException)

You don't have permission to perform the action specified in the request.

Tuple Fields of AccessDeniedException

0: AccessDeniedException
InternalException(InternalException)

Internal server error.

Tuple Fields of InternalException

0: InternalException
InvalidAccessException(InvalidAccessException)

There is an issue with the account used to make the request. Either Security Hub is not enabled for the account, or the account does not have permission to perform this action.

Tuple Fields of InvalidAccessException

0: InvalidAccessException
InvalidInputException(InvalidInputException)

The request was rejected because you supplied an invalid or out-of-range value for an input parameter.

Tuple Fields of InvalidInputException

0: InvalidInputException
LimitExceededException(LimitExceededException)

The request was rejected because it attempted to create resources beyond the current Amazon Web Services account or throttling limits. The error code describes the limit exceeded.

Tuple Fields of LimitExceededException

0: LimitExceededException
ResourceNotFoundException(ResourceNotFoundException)

The request was rejected because we can't find the specified resource.

Tuple Fields of ResourceNotFoundException

0: ResourceNotFoundException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>