Struct aws_sdk_securityhub::input::accept_administrator_invitation_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for AcceptAdministratorInvitationInput
Implementations
The account ID of the Security Hub administrator account that sent the invitation.
The account ID of the Security Hub administrator account that sent the invitation.
The identifier of the invitation sent from the Security Hub administrator account.
The identifier of the invitation sent from the Security Hub administrator account.
Consumes the builder and constructs a AcceptAdministratorInvitationInput