Struct aws_sdk_securityhub::input::accept_invitation_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for AcceptInvitationInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn master_id(self, input: impl Into<String>) -> Self
pub fn master_id(self, input: impl Into<String>) -> Self
The account ID of the Security Hub administrator account that sent the invitation.
sourcepub fn set_master_id(self, input: Option<String>) -> Self
pub fn set_master_id(self, input: Option<String>) -> Self
The account ID of the Security Hub administrator account that sent the invitation.
sourcepub fn invitation_id(self, input: impl Into<String>) -> Self
pub fn invitation_id(self, input: impl Into<String>) -> Self
The identifier of the invitation sent from the Security Hub administrator account.
sourcepub fn set_invitation_id(self, input: Option<String>) -> Self
pub fn set_invitation_id(self, input: Option<String>) -> Self
The identifier of the invitation sent from the Security Hub administrator account.
sourcepub fn build(self) -> Result<AcceptInvitationInput, BuildError>
pub fn build(self) -> Result<AcceptInvitationInput, BuildError>
Consumes the builder and constructs a AcceptInvitationInput.