pub struct Builder { /* private fields */ }Expand description
A builder for BatchUpdateFindingsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn finding_identifiers(self, input: AwsSecurityFindingIdentifier) -> Self
pub fn finding_identifiers(self, input: AwsSecurityFindingIdentifier) -> Self
Appends an item to finding_identifiers.
To override the contents of this collection use set_finding_identifiers.
The list of findings to update. BatchUpdateFindings can be used to update up to 100 findings at a time.
For each finding, the list provides the finding identifier and the ARN of the finding provider.
sourcepub fn set_finding_identifiers(
self,
input: Option<Vec<AwsSecurityFindingIdentifier>>
) -> Self
pub fn set_finding_identifiers(
self,
input: Option<Vec<AwsSecurityFindingIdentifier>>
) -> Self
The list of findings to update. BatchUpdateFindings can be used to update up to 100 findings at a time.
For each finding, the list provides the finding identifier and the ARN of the finding provider.
sourcepub fn note(self, input: NoteUpdate) -> Self
pub fn note(self, input: NoteUpdate) -> Self
The updated note.
sourcepub fn set_note(self, input: Option<NoteUpdate>) -> Self
pub fn set_note(self, input: Option<NoteUpdate>) -> Self
The updated note.
sourcepub fn severity(self, input: SeverityUpdate) -> Self
pub fn severity(self, input: SeverityUpdate) -> Self
Used to update the finding severity.
sourcepub fn set_severity(self, input: Option<SeverityUpdate>) -> Self
pub fn set_severity(self, input: Option<SeverityUpdate>) -> Self
Used to update the finding severity.
sourcepub fn verification_state(self, input: VerificationState) -> Self
pub fn verification_state(self, input: VerificationState) -> Self
Indicates the veracity of a finding.
The available values for VerificationState are as follows.
-
UNKNOWN– The default disposition of a security finding -
TRUE_POSITIVE– The security finding is confirmed -
FALSE_POSITIVE– The security finding was determined to be a false alarm -
BENIGN_POSITIVE– A special case ofTRUE_POSITIVEwhere the finding doesn't pose any threat, is expected, or both
sourcepub fn set_verification_state(self, input: Option<VerificationState>) -> Self
pub fn set_verification_state(self, input: Option<VerificationState>) -> Self
Indicates the veracity of a finding.
The available values for VerificationState are as follows.
-
UNKNOWN– The default disposition of a security finding -
TRUE_POSITIVE– The security finding is confirmed -
FALSE_POSITIVE– The security finding was determined to be a false alarm -
BENIGN_POSITIVE– A special case ofTRUE_POSITIVEwhere the finding doesn't pose any threat, is expected, or both
sourcepub fn confidence(self, input: i32) -> Self
pub fn confidence(self, input: i32) -> Self
The updated value for the finding confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
sourcepub fn set_confidence(self, input: Option<i32>) -> Self
pub fn set_confidence(self, input: Option<i32>) -> Self
The updated value for the finding confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
sourcepub fn criticality(self, input: i32) -> Self
pub fn criticality(self, input: i32) -> Self
The updated value for the level of importance assigned to the resources associated with the findings.
A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources.
sourcepub fn set_criticality(self, input: Option<i32>) -> Self
pub fn set_criticality(self, input: Option<i32>) -> Self
The updated value for the level of importance assigned to the resources associated with the findings.
A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources.
sourcepub fn types(self, input: impl Into<String>) -> Self
pub fn types(self, input: impl Into<String>) -> Self
Appends an item to types.
To override the contents of this collection use set_types.
One or more finding types in the format of namespace/category/classifier that classify a finding.
Valid namespace values are as follows.
-
Software and Configuration Checks
-
TTPs
-
Effects
-
Unusual Behaviors
-
Sensitive Data Identifications
sourcepub fn set_types(self, input: Option<Vec<String>>) -> Self
pub fn set_types(self, input: Option<Vec<String>>) -> Self
One or more finding types in the format of namespace/category/classifier that classify a finding.
Valid namespace values are as follows.
-
Software and Configuration Checks
-
TTPs
-
Effects
-
Unusual Behaviors
-
Sensitive Data Identifications
sourcepub fn user_defined_fields(
self,
k: impl Into<String>,
v: impl Into<String>
) -> Self
pub fn user_defined_fields(
self,
k: impl Into<String>,
v: impl Into<String>
) -> Self
Adds a key-value pair to user_defined_fields.
To override the contents of this collection use set_user_defined_fields.
A list of name/value string pairs associated with the finding. These are custom, user-defined fields added to a finding.
sourcepub fn set_user_defined_fields(
self,
input: Option<HashMap<String, String>>
) -> Self
pub fn set_user_defined_fields(
self,
input: Option<HashMap<String, String>>
) -> Self
A list of name/value string pairs associated with the finding. These are custom, user-defined fields added to a finding.
sourcepub fn workflow(self, input: WorkflowUpdate) -> Self
pub fn workflow(self, input: WorkflowUpdate) -> Self
Used to update the workflow status of a finding.
The workflow status indicates the progress of the investigation into the finding.
sourcepub fn set_workflow(self, input: Option<WorkflowUpdate>) -> Self
pub fn set_workflow(self, input: Option<WorkflowUpdate>) -> Self
Used to update the workflow status of a finding.
The workflow status indicates the progress of the investigation into the finding.
Appends an item to related_findings.
To override the contents of this collection use set_related_findings.
A list of findings that are related to the updated findings.
A list of findings that are related to the updated findings.
sourcepub fn build(self) -> Result<BatchUpdateFindingsInput, BuildError>
pub fn build(self) -> Result<BatchUpdateFindingsInput, BuildError>
Consumes the builder and constructs a BatchUpdateFindingsInput.