Struct aws_sdk_securityhub::input::decline_invitations_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeclineInvitationsInput
Implementations
Appends an item to account_ids.
To override the contents of this collection use set_account_ids.
The list of account IDs for the accounts from which to decline the invitations to Security Hub.
The list of account IDs for the accounts from which to decline the invitations to Security Hub.
Consumes the builder and constructs a DeclineInvitationsInput