Struct aws_sdk_securityhub::input::describe_standards_controls_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribeStandardsControlsInput
Implementations
The ARN of a resource that represents your subscription to a supported standard. To get
the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
The ARN of a resource that represents your subscription to a supported standard. To get
the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
The token that is required for pagination. On your first call to the
DescribeStandardsControls operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The token that is required for pagination. On your first call to the
DescribeStandardsControls operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The maximum number of security standard controls to return.
The maximum number of security standard controls to return.
Consumes the builder and constructs a DescribeStandardsControlsInput