Struct aws_sdk_securityhub::input::describe_standards_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribeStandardsInput
Implementations
The token that is required for pagination. On your first call to the
DescribeStandards operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The token that is required for pagination. On your first call to the
DescribeStandards operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The maximum number of standards to return.
The maximum number of standards to return.
Consumes the builder and constructs a DescribeStandardsInput