pub struct Builder { /* private fields */ }Expand description
A builder for DisassociateMembersInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn account_ids(self, input: impl Into<String>) -> Self
pub fn account_ids(self, input: impl Into<String>) -> Self
Appends an item to account_ids.
To override the contents of this collection use set_account_ids.
The account IDs of the member accounts to disassociate from the administrator account.
sourcepub fn set_account_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_account_ids(self, input: Option<Vec<String>>) -> Self
The account IDs of the member accounts to disassociate from the administrator account.
sourcepub fn build(self) -> Result<DisassociateMembersInput, BuildError>
pub fn build(self) -> Result<DisassociateMembersInput, BuildError>
Consumes the builder and constructs a DisassociateMembersInput.