pub struct Builder { /* private fields */ }Expand description
A builder for GetEnabledStandardsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_subscription_arns(self, input: impl Into<String>) -> Self
pub fn standards_subscription_arns(self, input: impl Into<String>) -> Self
Appends an item to standards_subscription_arns.
To override the contents of this collection use set_standards_subscription_arns.
The list of the standards subscription ARNs for the standards to retrieve.
sourcepub fn set_standards_subscription_arns(self, input: Option<Vec<String>>) -> Self
pub fn set_standards_subscription_arns(self, input: Option<Vec<String>>) -> Self
The list of the standards subscription ARNs for the standards to retrieve.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
sourcepub fn build(self) -> Result<GetEnabledStandardsInput, BuildError>
pub fn build(self) -> Result<GetEnabledStandardsInput, BuildError>
Consumes the builder and constructs a GetEnabledStandardsInput.