Struct aws_sdk_securityhub::input::get_insight_results_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetInsightResultsInput
Implementations
The ARN of the insight for which to return results.
The ARN of the insight for which to return results.
Consumes the builder and constructs a GetInsightResultsInput