pub struct Builder { /* private fields */ }
A builder for GetInsightsInput.

Implementations

Appends an item to insight_arns.

To override the contents of this collection use set_insight_arns.

The ARNs of the insights to describe. If you do not provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights.

The ARNs of the insights to describe. If you do not provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights.

The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

The maximum number of items to return in the response.

The maximum number of items to return in the response.

Consumes the builder and constructs a GetInsightsInput.