Struct aws_sdk_securityhub::input::invite_members_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for InviteMembersInput
Implementations
Appends an item to account_ids.
To override the contents of this collection use set_account_ids.
The list of account IDs of the Amazon Web Services accounts to invite to Security Hub as members.
The list of account IDs of the Amazon Web Services accounts to invite to Security Hub as members.
Consumes the builder and constructs a InviteMembersInput