Struct aws_sdk_securityhub::input::list_invitations_input::Builder
source · [−]pub struct Builder { /* private fields */ }Expand description
A builder for ListInvitationsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of items to return in the response.
sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of items to return in the response.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn build(self) -> Result<ListInvitationsInput, BuildError>
pub fn build(self) -> Result<ListInvitationsInput, BuildError>
Consumes the builder and constructs a ListInvitationsInput.