Struct aws_sdk_securityhub::input::list_members_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListMembersInput
Implementations
Specifies which member accounts to include in the response based on their relationship
status with the administrator account. The default value is TRUE.
If OnlyAssociated is set to TRUE, the response includes member
accounts whose relationship status with the administrator account is set to ENABLED.
If OnlyAssociated is set to FALSE, the response includes all
existing member accounts.
Specifies which member accounts to include in the response based on their relationship
status with the administrator account. The default value is TRUE.
If OnlyAssociated is set to TRUE, the response includes member
accounts whose relationship status with the administrator account is set to ENABLED.
If OnlyAssociated is set to FALSE, the response includes all
existing member accounts.
The maximum number of items to return in the response.
The maximum number of items to return in the response.
The token that is required for pagination. On your first call to the
ListMembers operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The token that is required for pagination. On your first call to the
ListMembers operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
Consumes the builder and constructs a ListMembersInput