#[non_exhaustive]pub struct AcceptAdministratorInvitationInput { /* private fields */ }Implementations
sourceimpl AcceptAdministratorInvitationInput
impl AcceptAdministratorInvitationInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AcceptAdministratorInvitation, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AcceptAdministratorInvitation, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<AcceptAdministratorInvitation>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AcceptAdministratorInvitationInput.
sourceimpl AcceptAdministratorInvitationInput
impl AcceptAdministratorInvitationInput
sourcepub fn administrator_id(&self) -> Option<&str>
pub fn administrator_id(&self) -> Option<&str>
The account ID of the Security Hub administrator account that sent the invitation.
sourcepub fn invitation_id(&self) -> Option<&str>
pub fn invitation_id(&self) -> Option<&str>
The identifier of the invitation sent from the Security Hub administrator account.