#[non_exhaustive]pub struct BatchUpdateFindingsInput { /* private fields */ }Implementations
sourceimpl BatchUpdateFindingsInput
impl BatchUpdateFindingsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchUpdateFindings, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchUpdateFindings, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<BatchUpdateFindings>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture BatchUpdateFindingsInput.
sourceimpl BatchUpdateFindingsInput
impl BatchUpdateFindingsInput
sourcepub fn finding_identifiers(&self) -> Option<&[AwsSecurityFindingIdentifier]>
pub fn finding_identifiers(&self) -> Option<&[AwsSecurityFindingIdentifier]>
The list of findings to update. BatchUpdateFindings can be used to update up to 100 findings at a time.
For each finding, the list provides the finding identifier and the ARN of the finding provider.
sourcepub fn note(&self) -> Option<&NoteUpdate>
pub fn note(&self) -> Option<&NoteUpdate>
The updated note.
sourcepub fn severity(&self) -> Option<&SeverityUpdate>
pub fn severity(&self) -> Option<&SeverityUpdate>
Used to update the finding severity.
sourcepub fn verification_state(&self) -> Option<&VerificationState>
pub fn verification_state(&self) -> Option<&VerificationState>
Indicates the veracity of a finding.
The available values for VerificationState are as follows.
-
UNKNOWN– The default disposition of a security finding -
TRUE_POSITIVE– The security finding is confirmed -
FALSE_POSITIVE– The security finding was determined to be a false alarm -
BENIGN_POSITIVE– A special case ofTRUE_POSITIVEwhere the finding doesn't pose any threat, is expected, or both
sourcepub fn confidence(&self) -> i32
pub fn confidence(&self) -> i32
The updated value for the finding confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
sourcepub fn criticality(&self) -> i32
pub fn criticality(&self) -> i32
The updated value for the level of importance assigned to the resources associated with the findings.
A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources.
sourcepub fn types(&self) -> Option<&[String]>
pub fn types(&self) -> Option<&[String]>
One or more finding types in the format of namespace/category/classifier that classify a finding.
Valid namespace values are as follows.
-
Software and Configuration Checks
-
TTPs
-
Effects
-
Unusual Behaviors
-
Sensitive Data Identifications
sourcepub fn user_defined_fields(&self) -> Option<&HashMap<String, String>>
pub fn user_defined_fields(&self) -> Option<&HashMap<String, String>>
A list of name/value string pairs associated with the finding. These are custom, user-defined fields added to a finding.
sourcepub fn workflow(&self) -> Option<&WorkflowUpdate>
pub fn workflow(&self) -> Option<&WorkflowUpdate>
Used to update the workflow status of a finding.
The workflow status indicates the progress of the investigation into the finding.
A list of findings that are related to the updated findings.