#[non_exhaustive]pub struct DescribeActionTargetsInput { /* private fields */ }Implementations
sourceimpl DescribeActionTargetsInput
impl DescribeActionTargetsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeActionTargets, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeActionTargets, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeActionTargets>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeActionTargetsInput.
sourceimpl DescribeActionTargetsInput
impl DescribeActionTargetsInput
sourcepub fn action_target_arns(&self) -> Option<&[String]>
pub fn action_target_arns(&self) -> Option<&[String]>
A list of custom action target ARNs for the custom action targets to retrieve.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the DescribeActionTargets operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of results to return.