#[non_exhaustive]pub struct DescribeStandardsControlsInput { /* private fields */ }Implementations
sourceimpl DescribeStandardsControlsInput
impl DescribeStandardsControlsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeStandardsControls, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeStandardsControls, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeStandardsControls>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeStandardsControlsInput.
sourceimpl DescribeStandardsControlsInput
impl DescribeStandardsControlsInput
sourcepub fn standards_subscription_arn(&self) -> Option<&str>
pub fn standards_subscription_arn(&self) -> Option<&str>
The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of security standard controls to return.