Struct aws_sdk_securityhub::input::DescribeStandardsInput
source · #[non_exhaustive]pub struct DescribeStandardsInput { /* private fields */ }Implementations
sourceimpl DescribeStandardsInput
impl DescribeStandardsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeStandards, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeStandards, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeStandards>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeStandardsInput.
sourceimpl DescribeStandardsInput
impl DescribeStandardsInput
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the DescribeStandards operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of standards to return.