#[non_exhaustive]pub struct GetEnabledStandardsInput { /* private fields */ }Implementations
sourceimpl GetEnabledStandardsInput
impl GetEnabledStandardsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetEnabledStandards, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetEnabledStandards, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<GetEnabledStandards>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GetEnabledStandardsInput.
sourceimpl GetEnabledStandardsInput
impl GetEnabledStandardsInput
sourcepub fn standards_subscription_arns(&self) -> Option<&[String]>
pub fn standards_subscription_arns(&self) -> Option<&[String]>
The list of the standards subscription ARNs for the standards to retrieve.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of results to return in the response.