#[non_exhaustive]pub struct ListOrganizationAdminAccountsInput { /* private fields */ }Implementations
sourceimpl ListOrganizationAdminAccountsInput
impl ListOrganizationAdminAccountsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListOrganizationAdminAccounts, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListOrganizationAdminAccounts, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<ListOrganizationAdminAccounts>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListOrganizationAdminAccountsInput.
sourceimpl ListOrganizationAdminAccountsInput
impl ListOrganizationAdminAccountsInput
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of items to return in the response.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the ListOrganizationAdminAccounts operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.