#[non_exhaustive]pub struct UpdateOrganizationConfigurationInput { /* private fields */ }Implementations
sourceimpl UpdateOrganizationConfigurationInput
impl UpdateOrganizationConfigurationInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateOrganizationConfiguration, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateOrganizationConfiguration, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<UpdateOrganizationConfiguration>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateOrganizationConfigurationInput.
sourceimpl UpdateOrganizationConfigurationInput
impl UpdateOrganizationConfigurationInput
sourcepub fn auto_enable(&self) -> bool
pub fn auto_enable(&self) -> bool
Whether to automatically enable Security Hub for new accounts in the organization.
By default, this is false, and new accounts are not added automatically.
To automatically enable Security Hub for new accounts, set this to true.
sourcepub fn auto_enable_standards(&self) -> Option<&AutoEnableStandards>
pub fn auto_enable_standards(&self) -> Option<&AutoEnableStandards>
Whether to automatically enable Security Hub default standards for new member accounts in the organization.
By default, this parameter is equal to DEFAULT, and new member accounts are automatically enabled with default Security Hub standards.
To opt out of enabling default standards for new member accounts, set this parameter equal to NONE.