#[non_exhaustive]pub struct UpdateSecurityHubConfigurationInput { /* private fields */ }Implementations
sourceimpl UpdateSecurityHubConfigurationInput
impl UpdateSecurityHubConfigurationInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateSecurityHubConfiguration, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateSecurityHubConfiguration, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<UpdateSecurityHubConfiguration>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateSecurityHubConfigurationInput.
sourceimpl UpdateSecurityHubConfigurationInput
impl UpdateSecurityHubConfigurationInput
sourcepub fn auto_enable_controls(&self) -> bool
pub fn auto_enable_controls(&self) -> bool
Whether to automatically enable new controls when they are added to standards that are enabled.
By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false.