#[non_exhaustive]pub struct UpdateStandardsControlInput { /* private fields */ }Implementations
sourceimpl UpdateStandardsControlInput
impl UpdateStandardsControlInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateStandardsControl, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateStandardsControl, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateStandardsControl>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateStandardsControlInput.
sourceimpl UpdateStandardsControlInput
impl UpdateStandardsControlInput
sourcepub fn standards_control_arn(&self) -> Option<&str>
pub fn standards_control_arn(&self) -> Option<&str>
The ARN of the security standard control to enable or disable.
sourcepub fn control_status(&self) -> Option<&ControlStatus>
pub fn control_status(&self) -> Option<&ControlStatus>
The updated status of the security standard control.
sourcepub fn disabled_reason(&self) -> Option<&str>
pub fn disabled_reason(&self) -> Option<&str>
A description of the reason why you are disabling a security standard control. If you are disabling a control, then this is required.