Struct aws_sdk_securityhub::input::update_insight_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for UpdateInsightInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn insight_arn(self, input: impl Into<String>) -> Self
pub fn insight_arn(self, input: impl Into<String>) -> Self
The ARN of the insight that you want to update.
sourcepub fn set_insight_arn(self, input: Option<String>) -> Self
pub fn set_insight_arn(self, input: Option<String>) -> Self
The ARN of the insight that you want to update.
sourcepub fn filters(self, input: AwsSecurityFindingFilters) -> Self
pub fn filters(self, input: AwsSecurityFindingFilters) -> Self
The updated filters that define this insight.
sourcepub fn set_filters(self, input: Option<AwsSecurityFindingFilters>) -> Self
pub fn set_filters(self, input: Option<AwsSecurityFindingFilters>) -> Self
The updated filters that define this insight.
sourcepub fn group_by_attribute(self, input: impl Into<String>) -> Self
pub fn group_by_attribute(self, input: impl Into<String>) -> Self
The updated GroupBy attribute that defines this insight.
sourcepub fn set_group_by_attribute(self, input: Option<String>) -> Self
pub fn set_group_by_attribute(self, input: Option<String>) -> Self
The updated GroupBy attribute that defines this insight.
sourcepub fn build(self) -> Result<UpdateInsightInput, BuildError>
pub fn build(self) -> Result<UpdateInsightInput, BuildError>
Consumes the builder and constructs a UpdateInsightInput.