pub struct Builder { /* private fields */ }Expand description
A builder for UpdateSecurityHubConfigurationInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn auto_enable_controls(self, input: bool) -> Self
pub fn auto_enable_controls(self, input: bool) -> Self
Whether to automatically enable new controls when they are added to standards that are enabled.
By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false.
sourcepub fn set_auto_enable_controls(self, input: Option<bool>) -> Self
pub fn set_auto_enable_controls(self, input: Option<bool>) -> Self
Whether to automatically enable new controls when they are added to standards that are enabled.
By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false.
sourcepub fn build(self) -> Result<UpdateSecurityHubConfigurationInput, BuildError>
pub fn build(self) -> Result<UpdateSecurityHubConfigurationInput, BuildError>
Consumes the builder and constructs a UpdateSecurityHubConfigurationInput.