pub struct Builder { /* private fields */ }Expand description
A builder for Action.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn action_type(self, input: impl Into<String>) -> Self
pub fn action_type(self, input: impl Into<String>) -> Self
The type of action that was detected. The possible action types are:
-
NETWORK_CONNECTION -
AWS_API_CALL -
DNS_REQUEST -
PORT_PROBE
sourcepub fn set_action_type(self, input: Option<String>) -> Self
pub fn set_action_type(self, input: Option<String>) -> Self
The type of action that was detected. The possible action types are:
-
NETWORK_CONNECTION -
AWS_API_CALL -
DNS_REQUEST -
PORT_PROBE
sourcepub fn network_connection_action(self, input: NetworkConnectionAction) -> Self
pub fn network_connection_action(self, input: NetworkConnectionAction) -> Self
Included if ActionType is NETWORK_CONNECTION. Provides details about the network connection that was detected.
sourcepub fn set_network_connection_action(
self,
input: Option<NetworkConnectionAction>
) -> Self
pub fn set_network_connection_action(
self,
input: Option<NetworkConnectionAction>
) -> Self
Included if ActionType is NETWORK_CONNECTION. Provides details about the network connection that was detected.
sourcepub fn aws_api_call_action(self, input: AwsApiCallAction) -> Self
pub fn aws_api_call_action(self, input: AwsApiCallAction) -> Self
Included if ActionType is AWS_API_CALL. Provides details about the API call that was detected.
sourcepub fn set_aws_api_call_action(self, input: Option<AwsApiCallAction>) -> Self
pub fn set_aws_api_call_action(self, input: Option<AwsApiCallAction>) -> Self
Included if ActionType is AWS_API_CALL. Provides details about the API call that was detected.
sourcepub fn dns_request_action(self, input: DnsRequestAction) -> Self
pub fn dns_request_action(self, input: DnsRequestAction) -> Self
Included if ActionType is DNS_REQUEST. Provides details about the DNS request that was detected.
sourcepub fn set_dns_request_action(self, input: Option<DnsRequestAction>) -> Self
pub fn set_dns_request_action(self, input: Option<DnsRequestAction>) -> Self
Included if ActionType is DNS_REQUEST. Provides details about the DNS request that was detected.
sourcepub fn port_probe_action(self, input: PortProbeAction) -> Self
pub fn port_probe_action(self, input: PortProbeAction) -> Self
Included if ActionType is PORT_PROBE. Provides details about the port probe that was detected.
sourcepub fn set_port_probe_action(self, input: Option<PortProbeAction>) -> Self
pub fn set_port_probe_action(self, input: Option<PortProbeAction>) -> Self
Included if ActionType is PORT_PROBE. Provides details about the port probe that was detected.