Struct aws_sdk_securityhub::model::admin_account::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for AdminAccount.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account identifier of the Security Hub administrator account.
sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
The Amazon Web Services account identifier of the Security Hub administrator account.
sourcepub fn status(self, input: AdminStatus) -> Self
pub fn status(self, input: AdminStatus) -> Self
The current status of the Security Hub administrator account. Indicates whether the account is currently enabled as a Security Hub administrator.
sourcepub fn set_status(self, input: Option<AdminStatus>) -> Self
pub fn set_status(self, input: Option<AdminStatus>) -> Self
The current status of the Security Hub administrator account. Indicates whether the account is currently enabled as a Security Hub administrator.
sourcepub fn build(self) -> AdminAccount
pub fn build(self) -> AdminAccount
Consumes the builder and constructs a AdminAccount.