pub struct Builder { /* private fields */ }Expand description
A builder for AwsCertificateManagerCertificateOptions.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn certificate_transparency_logging_preference(
self,
input: impl Into<String>
) -> Self
pub fn certificate_transparency_logging_preference(
self,
input: impl Into<String>
) -> Self
Whether to add the certificate to a transparency log.
Valid values: DISABLED | ENABLED
sourcepub fn set_certificate_transparency_logging_preference(
self,
input: Option<String>
) -> Self
pub fn set_certificate_transparency_logging_preference(
self,
input: Option<String>
) -> Self
Whether to add the certificate to a transparency log.
Valid values: DISABLED | ENABLED
sourcepub fn build(self) -> AwsCertificateManagerCertificateOptions
pub fn build(self) -> AwsCertificateManagerCertificateOptions
Consumes the builder and constructs a AwsCertificateManagerCertificateOptions.