pub struct Builder { /* private fields */ }
A builder for AwsEc2EipDetails.

Implementations

The identifier of the EC2 instance.

The identifier of the EC2 instance.

A public IP address that is associated with the EC2 instance.

A public IP address that is associated with the EC2 instance.

The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.

The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.

The identifier that represents the association of the Elastic IP address with an EC2 instance.

The identifier that represents the association of the Elastic IP address with an EC2 instance.

The domain in which to allocate the address.

If the address is for use with EC2 instances in a VPC, then Domain is vpc. Otherwise, Domain is standard.

The domain in which to allocate the address.

If the address is for use with EC2 instances in a VPC, then Domain is vpc. Otherwise, Domain is standard.

The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.

The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.

The name of the location from which the Elastic IP address is advertised.

The name of the location from which the Elastic IP address is advertised.

The identifier of the network interface.

The identifier of the network interface.

The Amazon Web Services account ID of the owner of the network interface.

The Amazon Web Services account ID of the owner of the network interface.

The private IP address that is associated with the Elastic IP address.

The private IP address that is associated with the Elastic IP address.

Consumes the builder and constructs a AwsEc2EipDetails.