pub struct Builder { /* private fields */ }Expand description
A builder for BatchUpdateFindingsUnprocessedFinding.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn finding_identifier(self, input: AwsSecurityFindingIdentifier) -> Self
pub fn finding_identifier(self, input: AwsSecurityFindingIdentifier) -> Self
The identifier of the finding that was not updated.
sourcepub fn set_finding_identifier(
self,
input: Option<AwsSecurityFindingIdentifier>
) -> Self
pub fn set_finding_identifier(
self,
input: Option<AwsSecurityFindingIdentifier>
) -> Self
The identifier of the finding that was not updated.
sourcepub fn error_code(self, input: impl Into<String>) -> Self
pub fn error_code(self, input: impl Into<String>) -> Self
The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
sourcepub fn set_error_code(self, input: Option<String>) -> Self
pub fn set_error_code(self, input: Option<String>) -> Self
The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
sourcepub fn build(self) -> BatchUpdateFindingsUnprocessedFinding
pub fn build(self) -> BatchUpdateFindingsUnprocessedFinding
Consumes the builder and constructs a BatchUpdateFindingsUnprocessedFinding.