Struct aws_sdk_securityhub::model::insight_results::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for InsightResults
Implementations
The ARN of the insight whose results are returned by the GetInsightResults
operation.
The ARN of the insight whose results are returned by the GetInsightResults
operation.
The attribute that the findings are grouped by for the insight whose results are
returned by the GetInsightResults operation.
The attribute that the findings are grouped by for the insight whose results are
returned by the GetInsightResults operation.
Appends an item to result_values.
To override the contents of this collection use set_result_values.
The list of insight result values returned by the GetInsightResults
operation.
The list of insight result values returned by the GetInsightResults
operation.
Consumes the builder and constructs a InsightResults