Struct aws_sdk_securityhub::model::member::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for Member.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID of the member account.
sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
The Amazon Web Services account ID of the member account.
sourcepub fn master_id(self, input: impl Into<String>) -> Self
👎Deprecated: This field is deprecated, use AdministratorId instead.
pub fn master_id(self, input: impl Into<String>) -> Self
This is replaced by AdministratorID.
The Amazon Web Services account ID of the Security Hub administrator account associated with this member account.
sourcepub fn set_master_id(self, input: Option<String>) -> Self
👎Deprecated: This field is deprecated, use AdministratorId instead.
pub fn set_master_id(self, input: Option<String>) -> Self
This is replaced by AdministratorID.
The Amazon Web Services account ID of the Security Hub administrator account associated with this member account.
sourcepub fn administrator_id(self, input: impl Into<String>) -> Self
pub fn administrator_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID of the Security Hub administrator account associated with this member account.
sourcepub fn set_administrator_id(self, input: Option<String>) -> Self
pub fn set_administrator_id(self, input: Option<String>) -> Self
The Amazon Web Services account ID of the Security Hub administrator account associated with this member account.
sourcepub fn member_status(self, input: impl Into<String>) -> Self
pub fn member_status(self, input: impl Into<String>) -> Self
The status of the relationship between the member account and its administrator account.
The status can have one of the following values:
-
CREATED- Indicates that the administrator account added the member account, but has not yet invited the member account. -
INVITED- Indicates that the administrator account invited the member account. The member account has not yet responded to the invitation. -
ENABLED- Indicates that the member account is currently active. For manually invited member accounts, indicates that the member account accepted the invitation. -
REMOVED- Indicates that the administrator account disassociated the member account. -
RESIGNED- Indicates that the member account disassociated themselves from the administrator account. -
DELETED- Indicates that the administrator account deleted the member account. -
ACCOUNT_SUSPENDED- Indicates that an organization account was suspended from Amazon Web Services at the same time that the administrator account tried to enable the organization account as a member account.
sourcepub fn set_member_status(self, input: Option<String>) -> Self
pub fn set_member_status(self, input: Option<String>) -> Self
The status of the relationship between the member account and its administrator account.
The status can have one of the following values:
-
CREATED- Indicates that the administrator account added the member account, but has not yet invited the member account. -
INVITED- Indicates that the administrator account invited the member account. The member account has not yet responded to the invitation. -
ENABLED- Indicates that the member account is currently active. For manually invited member accounts, indicates that the member account accepted the invitation. -
REMOVED- Indicates that the administrator account disassociated the member account. -
RESIGNED- Indicates that the member account disassociated themselves from the administrator account. -
DELETED- Indicates that the administrator account deleted the member account. -
ACCOUNT_SUSPENDED- Indicates that an organization account was suspended from Amazon Web Services at the same time that the administrator account tried to enable the organization account as a member account.
sourcepub fn invited_at(self, input: DateTime) -> Self
pub fn invited_at(self, input: DateTime) -> Self
A timestamp for the date and time when the invitation was sent to the member account.
sourcepub fn set_invited_at(self, input: Option<DateTime>) -> Self
pub fn set_invited_at(self, input: Option<DateTime>) -> Self
A timestamp for the date and time when the invitation was sent to the member account.
sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp for the date and time when the member account was updated.
sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp for the date and time when the member account was updated.