Struct aws_sdk_securityhub::model::related_finding::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for RelatedFinding
Implementations
The ARN of the product that generated a related finding.
The ARN of the product that generated a related finding.
The product-generated identifier for a related finding.
The product-generated identifier for a related finding.
Consumes the builder and constructs a RelatedFinding