Struct aws_sdk_securityhub::model::severity_update::Builder
source · [−]pub struct Builder { /* private fields */ }Expand description
A builder for SeverityUpdate.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn normalized(self, input: i32) -> Self
pub fn normalized(self, input: i32) -> Self
The normalized severity for the finding. This attribute is to be deprecated in favor of Label.
If you provide Normalized and do not provide Label, Label is set automatically as follows.
-
0 -
INFORMATIONAL -
1–39 -
LOW -
40–69 -
MEDIUM -
70–89 -
HIGH -
90–100 -
CRITICAL
sourcepub fn set_normalized(self, input: Option<i32>) -> Self
pub fn set_normalized(self, input: Option<i32>) -> Self
The normalized severity for the finding. This attribute is to be deprecated in favor of Label.
If you provide Normalized and do not provide Label, Label is set automatically as follows.
-
0 -
INFORMATIONAL -
1–39 -
LOW -
40–69 -
MEDIUM -
70–89 -
HIGH -
90–100 -
CRITICAL
sourcepub fn product(self, input: f64) -> Self
pub fn product(self, input: f64) -> Self
The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
sourcepub fn set_product(self, input: Option<f64>) -> Self
pub fn set_product(self, input: Option<f64>) -> Self
The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
sourcepub fn label(self, input: SeverityLabel) -> Self
pub fn label(self, input: SeverityLabel) -> Self
The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
sourcepub fn set_label(self, input: Option<SeverityLabel>) -> Self
pub fn set_label(self, input: Option<SeverityLabel>) -> Self
The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
sourcepub fn build(self) -> SeverityUpdate
pub fn build(self) -> SeverityUpdate
Consumes the builder and constructs a SeverityUpdate.