pub struct Builder { /* private fields */ }Expand description
A builder for Standard.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_arn(self, input: impl Into<String>) -> Self
pub fn standards_arn(self, input: impl Into<String>) -> Self
The ARN of a standard.
sourcepub fn set_standards_arn(self, input: Option<String>) -> Self
pub fn set_standards_arn(self, input: Option<String>) -> Self
The ARN of a standard.
sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the standard.
sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the standard.
sourcepub fn enabled_by_default(self, input: bool) -> Self
pub fn enabled_by_default(self, input: bool) -> Self
Whether the standard is enabled by default. When Security Hub is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.
When Security Hub is enabled using the EnableSecurityHub API operation, the standard is enabled by default unless EnableDefaultStandards is set to false.
sourcepub fn set_enabled_by_default(self, input: Option<bool>) -> Self
pub fn set_enabled_by_default(self, input: Option<bool>) -> Self
Whether the standard is enabled by default. When Security Hub is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.
When Security Hub is enabled using the EnableSecurityHub API operation, the standard is enabled by default unless EnableDefaultStandards is set to false.