Struct aws_sdk_securityhub::model::AdminAccount
source · [−]#[non_exhaustive]pub struct AdminAccount { /* private fields */ }Expand description
Represents a Security Hub administrator account designated by an organization management account.
Implementations
sourceimpl AdminAccount
impl AdminAccount
sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The Amazon Web Services account identifier of the Security Hub administrator account.
sourcepub fn status(&self) -> Option<&AdminStatus>
pub fn status(&self) -> Option<&AdminStatus>
The current status of the Security Hub administrator account. Indicates whether the account is currently enabled as a Security Hub administrator.
sourceimpl AdminAccount
impl AdminAccount
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AdminAccount.