#[non_exhaustive]pub struct AwsApiGatewayAccessLogSettings { /* private fields */ }Expand description
Contains information about settings for logging access for the stage.
Implementations
sourceimpl AwsApiGatewayAccessLogSettings
impl AwsApiGatewayAccessLogSettings
sourcepub fn format(&self) -> Option<&str>
pub fn format(&self) -> Option<&str>
A single-line format of the access logs of data, as specified by selected $context variables. The format must include at least $context.requestId.
sourcepub fn destination_arn(&self) -> Option<&str>
pub fn destination_arn(&self) -> Option<&str>
The ARN of the CloudWatch Logs log group that receives the access logs.
sourceimpl AwsApiGatewayAccessLogSettings
impl AwsApiGatewayAccessLogSettings
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsApiGatewayAccessLogSettings.