Struct aws_sdk_securityhub::model::AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails [−][src]
#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails {
pub device_name: Option<String>,
pub ebs: Option<AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails>,
pub no_device: bool,
pub virtual_name: Option<String>,
}Expand description
A block device for the instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_name: Option<String>The device name that is exposed to the EC2 instance. For example, /dev/sdh or xvdh.
ebs: Option<AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails>Parameters that are used to automatically set up Amazon EBS volumes when an instance is launched.
no_device: boolWhether to suppress the device that is included in the block device mapping of the Amazon Machine Image (AMI).
If NoDevice is true, then you cannot specify Ebs.>
virtual_name: Option<String>The name of the virtual device (for example, ephemeral0).
You can provide either VirtualName or Ebs, but not both.
Implementations
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails