Struct aws_sdk_securityhub::model::AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
source · [−]#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails { /* private fields */ }Expand description
Parameters that are used to automatically set up EBS volumes when an instance is launched.
Implementations
sourceimpl AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
impl AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
sourcepub fn delete_on_termination(&self) -> bool
pub fn delete_on_termination(&self) -> bool
Whether to delete the volume when the instance is terminated.
sourcepub fn iops(&self) -> i32
pub fn iops(&self) -> i32
The number of input/output (I/O) operations per second (IOPS) to provision for the volume.
Only supported for gp3 or io1 volumes. Required for io1 volumes. Not used with standard, gp2, st1, or sc1 volumes.
sourcepub fn snapshot_id(&self) -> Option<&str>
pub fn snapshot_id(&self) -> Option<&str>
The snapshot ID of the volume to use.
You must specify either VolumeSize or SnapshotId.
sourcepub fn volume_size(&self) -> i32
pub fn volume_size(&self) -> i32
The volume size, in GiBs. The following are the supported volumes sizes for each volume type:
-
gp2 and gp3: 1-16,384
-
io1: 4-16,384
-
st1 and sc1: 125-16,384
-
standard: 1-1,024
You must specify either SnapshotId or VolumeSize. If you specify both SnapshotId and VolumeSize, the volume size must be equal or greater than the size of the snapshot.
sourcepub fn volume_type(&self) -> Option<&str>
pub fn volume_type(&self) -> Option<&str>
The volume type. Valid values are as follows:
-
gp2 -
gp3 -
io1 -
sc1 -
st1 -
standard
sourceimpl AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
impl AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails.