#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationDetails { /* private fields */ }Expand description
Details about a launch configuration.
Implementations
sourceimpl AwsAutoScalingLaunchConfigurationDetails
impl AwsAutoScalingLaunchConfigurationDetails
sourcepub fn associate_public_ip_address(&self) -> bool
pub fn associate_public_ip_address(&self) -> bool
For Auto Scaling groups that run in a VPC, specifies whether to assign a public IP address to the group's instances.
sourcepub fn block_device_mappings(
&self
) -> Option<&[AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails]>
pub fn block_device_mappings(
&self
) -> Option<&[AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails]>
Specifies the block devices for the instance.
sourcepub fn classic_link_vpc_id(&self) -> Option<&str>
pub fn classic_link_vpc_id(&self) -> Option<&str>
The identifier of a ClassicLink-enabled VPC that EC2-Classic instances are linked to.
sourcepub fn classic_link_vpc_security_groups(&self) -> Option<&[String]>
pub fn classic_link_vpc_security_groups(&self) -> Option<&[String]>
The identifiers of one or more security groups for the VPC that is specified in ClassicLinkVPCId.
sourcepub fn created_time(&self) -> Option<&str>
pub fn created_time(&self) -> Option<&str>
The creation date and time for the launch configuration.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn ebs_optimized(&self) -> bool
pub fn ebs_optimized(&self) -> bool
Whether the launch configuration is optimized for Amazon EBS I/O.
sourcepub fn iam_instance_profile(&self) -> Option<&str>
pub fn iam_instance_profile(&self) -> Option<&str>
The name or the ARN of the instance profile associated with the IAM role for the instance. The instance profile contains the IAM role.
sourcepub fn image_id(&self) -> Option<&str>
pub fn image_id(&self) -> Option<&str>
The identifier of the Amazon Machine Image (AMI) that is used to launch EC2 instances.
sourcepub fn instance_monitoring(
&self
) -> Option<&AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails>
pub fn instance_monitoring(
&self
) -> Option<&AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails>
Indicates the type of monitoring for instances in the group.
sourcepub fn instance_type(&self) -> Option<&str>
pub fn instance_type(&self) -> Option<&str>
The instance type for the instances.
sourcepub fn launch_configuration_name(&self) -> Option<&str>
pub fn launch_configuration_name(&self) -> Option<&str>
The name of the launch configuration.
sourcepub fn placement_tenancy(&self) -> Option<&str>
pub fn placement_tenancy(&self) -> Option<&str>
The tenancy of the instance. An instance with dedicated tenancy runs on isolated, single-tenant hardware and can only be launched into a VPC.
sourcepub fn ramdisk_id(&self) -> Option<&str>
pub fn ramdisk_id(&self) -> Option<&str>
The identifier of the RAM disk associated with the AMI.
sourcepub fn security_groups(&self) -> Option<&[String]>
pub fn security_groups(&self) -> Option<&[String]>
The security groups to assign to the instances in the Auto Scaling group.
sourcepub fn spot_price(&self) -> Option<&str>
pub fn spot_price(&self) -> Option<&str>
The maximum hourly price to be paid for any Spot Instance that is launched to fulfill the request.
sourcepub fn user_data(&self) -> Option<&str>
pub fn user_data(&self) -> Option<&str>
The user data to make available to the launched EC2 instances. Must be base64-encoded text.
sourcepub fn metadata_options(
&self
) -> Option<&AwsAutoScalingLaunchConfigurationMetadataOptions>
pub fn metadata_options(
&self
) -> Option<&AwsAutoScalingLaunchConfigurationMetadataOptions>
The metadata options for the instances.
sourceimpl AwsAutoScalingLaunchConfigurationDetails
impl AwsAutoScalingLaunchConfigurationDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationDetails.