#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationMetadataOptions { /* private fields */ }Expand description
The metadata options for the instances.
Implementations
sourceimpl AwsAutoScalingLaunchConfigurationMetadataOptions
impl AwsAutoScalingLaunchConfigurationMetadataOptions
sourcepub fn http_endpoint(&self) -> Option<&str>
pub fn http_endpoint(&self) -> Option<&str>
Enables or disables the HTTP metadata endpoint on your instances. By default, the metadata endpoint is enabled.
sourcepub fn http_put_response_hop_limit(&self) -> i32
pub fn http_put_response_hop_limit(&self) -> i32
The HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
sourcepub fn http_tokens(&self) -> Option<&str>
pub fn http_tokens(&self) -> Option<&str>
Indicates whether token usage is required or optional for metadata requests. By default, token usage is optional.
sourceimpl AwsAutoScalingLaunchConfigurationMetadataOptions
impl AwsAutoScalingLaunchConfigurationMetadataOptions
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationMetadataOptions.