#[non_exhaustive]pub struct AwsBackupBackupPlanAdvancedBackupSettingsDetails { /* private fields */ }Expand description
Provides a list of backup options for each resource type.
Implementations
sourceimpl AwsBackupBackupPlanAdvancedBackupSettingsDetails
impl AwsBackupBackupPlanAdvancedBackupSettingsDetails
sourcepub fn backup_options(&self) -> Option<&HashMap<String, String>>
pub fn backup_options(&self) -> Option<&HashMap<String, String>>
Specifies the backup option for a selected resource. This option is only available for Windows Volume Shadow Copy Service (VSS) backup jobs. Valid values are as follows:
-
Set to
WindowsVSS: enabledto enable the WindowsVSS backup option and create a Windows VSS backup. -
Set to
WindowsVSS: disabledto create a regular backup. TheWindowsVSSoption is not enabled by default.
sourcepub fn resource_type(&self) -> Option<&str>
pub fn resource_type(&self) -> Option<&str>
The name of a resource type. The only supported resource type is Amazon EC2 instances with Windows VSS.
The only valid value is EC2.
sourceimpl AwsBackupBackupPlanAdvancedBackupSettingsDetails
impl AwsBackupBackupPlanAdvancedBackupSettingsDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupBackupPlanAdvancedBackupSettingsDetails.