#[non_exhaustive]pub struct AwsBackupBackupPlanBackupPlanDetails { /* private fields */ }Expand description
Provides details about an Backup backup plan and an array of BackupRule objects, each of which specifies a backup rule.
Implementations
sourceimpl AwsBackupBackupPlanBackupPlanDetails
impl AwsBackupBackupPlanBackupPlanDetails
sourcepub fn backup_plan_name(&self) -> Option<&str>
pub fn backup_plan_name(&self) -> Option<&str>
The display name of a backup plan.
sourcepub fn advanced_backup_settings(
&self
) -> Option<&[AwsBackupBackupPlanAdvancedBackupSettingsDetails]>
pub fn advanced_backup_settings(
&self
) -> Option<&[AwsBackupBackupPlanAdvancedBackupSettingsDetails]>
A list of backup options for each resource type.
sourcepub fn backup_plan_rule(&self) -> Option<&[AwsBackupBackupPlanRuleDetails]>
pub fn backup_plan_rule(&self) -> Option<&[AwsBackupBackupPlanRuleDetails]>
An array of BackupRule objects, each of which specifies a scheduled task that is used to back up a selection of resources.
sourceimpl AwsBackupBackupPlanBackupPlanDetails
impl AwsBackupBackupPlanBackupPlanDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupBackupPlanBackupPlanDetails.