#[non_exhaustive]pub struct AwsBackupBackupPlanLifecycleDetails { /* private fields */ }Expand description
Provides lifecycle details for the backup plan. A lifecycle defines when a backup is transitioned to cold storage and when it expires.
Implementations
sourceimpl AwsBackupBackupPlanLifecycleDetails
impl AwsBackupBackupPlanLifecycleDetails
sourcepub fn delete_after_days(&self) -> i64
pub fn delete_after_days(&self) -> i64
Specifies the number of days after creation that a recovery point is deleted. Must be greater than 90 days plus MoveToColdStorageAfterDays.
sourcepub fn move_to_cold_storage_after_days(&self) -> i64
pub fn move_to_cold_storage_after_days(&self) -> i64
Specifies the number of days after creation that a recovery point is moved to cold storage.
sourceimpl AwsBackupBackupPlanLifecycleDetails
impl AwsBackupBackupPlanLifecycleDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupBackupPlanLifecycleDetails.