#[non_exhaustive]pub struct AwsBackupBackupVaultDetails { /* private fields */ }Expand description
Provides details about an Backup backup vault. In Backup, a backup vault is a container that stores and organizes your backups.
Implementations
sourceimpl AwsBackupBackupVaultDetails
impl AwsBackupBackupVaultDetails
sourcepub fn backup_vault_arn(&self) -> Option<&str>
pub fn backup_vault_arn(&self) -> Option<&str>
An Amazon Resource Name (ARN) that uniquely identifies a backup vault.
sourcepub fn backup_vault_name(&self) -> Option<&str>
pub fn backup_vault_name(&self) -> Option<&str>
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the Amazon Web Services account used to create them and the Amazon Web Services Region where they are created. They consist of lowercase letters, numbers, and hyphens.
sourcepub fn encryption_key_arn(&self) -> Option<&str>
pub fn encryption_key_arn(&self) -> Option<&str>
The unique ARN associated with the server-side encryption key. You can specify a key to encrypt your backups from services that support full Backup management. If you do not specify a key, Backup creates an KMS key for you by default.
sourcepub fn notifications(&self) -> Option<&AwsBackupBackupVaultNotificationsDetails>
pub fn notifications(&self) -> Option<&AwsBackupBackupVaultNotificationsDetails>
The Amazon SNS event notifications for the specified backup vault.
sourcepub fn access_policy(&self) -> Option<&str>
pub fn access_policy(&self) -> Option<&str>
A resource-based policy that is used to manage access permissions on the target backup vault.
sourceimpl AwsBackupBackupVaultDetails
impl AwsBackupBackupVaultDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupBackupVaultDetails.