#[non_exhaustive]pub struct AwsBackupRecoveryPointCreatedByDetails { /* private fields */ }Expand description
Contains information about the backup plan and rule that Backup used to initiate the recovery point backup.
Implementations
sourceimpl AwsBackupRecoveryPointCreatedByDetails
impl AwsBackupRecoveryPointCreatedByDetails
sourcepub fn backup_plan_arn(&self) -> Option<&str>
pub fn backup_plan_arn(&self) -> Option<&str>
An Amazon Resource Name (ARN) that uniquely identifies a backup plan.
sourcepub fn backup_plan_id(&self) -> Option<&str>
pub fn backup_plan_id(&self) -> Option<&str>
Uniquely identifies a backup plan.
sourcepub fn backup_plan_version(&self) -> Option<&str>
pub fn backup_plan_version(&self) -> Option<&str>
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version IDs cannot be edited.
sourcepub fn backup_rule_id(&self) -> Option<&str>
pub fn backup_rule_id(&self) -> Option<&str>
Uniquely identifies a rule used to schedule the backup of a selection of resources.
sourceimpl AwsBackupRecoveryPointCreatedByDetails
impl AwsBackupRecoveryPointCreatedByDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupRecoveryPointCreatedByDetails.