#[non_exhaustive]pub struct AwsBackupRecoveryPointLifecycleDetails { /* private fields */ }Expand description
Contains an array of Transition objects specifying how long in days before a recovery point transitions to cold storage or is deleted.
Implementations
sourceimpl AwsBackupRecoveryPointLifecycleDetails
impl AwsBackupRecoveryPointLifecycleDetails
sourcepub fn delete_after_days(&self) -> i64
pub fn delete_after_days(&self) -> i64
Specifies the number of days after creation that a recovery point is deleted. Must be greater than 90 days plus MoveToColdStorageAfterDays.
sourcepub fn move_to_cold_storage_after_days(&self) -> i64
pub fn move_to_cold_storage_after_days(&self) -> i64
Specifies the number of days after creation that a recovery point is moved to cold storage.
sourceimpl AwsBackupRecoveryPointLifecycleDetails
impl AwsBackupRecoveryPointLifecycleDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsBackupRecoveryPointLifecycleDetails.