Struct aws_sdk_securityhub::model::AwsCertificateManagerCertificateDetails [−][src]
#[non_exhaustive]pub struct AwsCertificateManagerCertificateDetails {Show 23 fields
pub certificate_authority_arn: Option<String>,
pub created_at: Option<String>,
pub domain_name: Option<String>,
pub domain_validation_options: Option<Vec<AwsCertificateManagerCertificateDomainValidationOption>>,
pub extended_key_usages: Option<Vec<AwsCertificateManagerCertificateExtendedKeyUsage>>,
pub failure_reason: Option<String>,
pub imported_at: Option<String>,
pub in_use_by: Option<Vec<String>>,
pub issued_at: Option<String>,
pub issuer: Option<String>,
pub key_algorithm: Option<String>,
pub key_usages: Option<Vec<AwsCertificateManagerCertificateKeyUsage>>,
pub not_after: Option<String>,
pub not_before: Option<String>,
pub options: Option<AwsCertificateManagerCertificateOptions>,
pub renewal_eligibility: Option<String>,
pub renewal_summary: Option<AwsCertificateManagerCertificateRenewalSummary>,
pub serial: Option<String>,
pub signature_algorithm: Option<String>,
pub status: Option<String>,
pub subject: Option<String>,
pub subject_alternative_names: Option<Vec<String>>,
pub type: Option<String>,
}Expand description
Provides details about an Certificate Manager certificate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The ARN of the private certificate authority (CA) that will be used to issue the certificate.
created_at: Option<String>Indicates when the certificate was requested.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
domain_name: Option<String>The fully qualified domain name (FQDN), such as www.example.com, that is secured by the certificate.
domain_validation_options: Option<Vec<AwsCertificateManagerCertificateDomainValidationOption>>Contains information about the initial validation of each domain name that occurs as a
result of the RequestCertificate request.
Only provided if the certificate type is AMAZON_ISSUED.
extended_key_usages: Option<Vec<AwsCertificateManagerCertificateExtendedKeyUsage>>Contains a list of Extended Key Usage X.509 v3 extension objects. Each object specifies a purpose for which the certificate public key can be used and consists of a name and an object identifier (OID).
failure_reason: Option<String>For a failed certificate request, the reason for the failure.
Valid values: NO_AVAILABLE_CONTACTS |
ADDITIONAL_VERIFICATION_REQUIRED | DOMAIN_NOT_ALLOWED |
INVALID_PUBLIC_DOMAIN | DOMAIN_VALIDATION_DENIED |
CAA_ERROR | PCA_LIMIT_EXCEEDED | PCA_INVALID_ARN
| PCA_INVALID_STATE | PCA_REQUEST_FAILED |
PCA_NAME_CONSTRAINTS_VALIDATION | PCA_RESOURCE_NOT_FOUND |
PCA_INVALID_ARGS | PCA_INVALID_DURATION |
PCA_ACCESS_DENIED | SLR_NOT_FOUND | OTHER
imported_at: Option<String>Indicates when the certificate was imported. Provided if the certificate type is
IMPORTED.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
in_use_by: Option<Vec<String>>The list of ARNs for the Amazon Web Services resources that use the certificate.
issued_at: Option<String>Indicates when the certificate was issued. Provided if the certificate type is
AMAZON_ISSUED.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
issuer: Option<String>The name of the certificate authority that issued and signed the certificate.
key_algorithm: Option<String>The algorithm that was used to generate the public-private key pair.
Valid values: RSA_2048 | RSA_1024 | RSA_4096 |
EC_prime256v1 | EC_secp384r1 |
EC_secp521r1
key_usages: Option<Vec<AwsCertificateManagerCertificateKeyUsage>>A list of key usage X.509 v3 extension objects.
not_after: Option<String>The time after which the certificate becomes invalid.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
not_before: Option<String>The time before which the certificate is not valid.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
options: Option<AwsCertificateManagerCertificateOptions>Provides a value that specifies whether to add the certificate to a transparency log.
renewal_eligibility: Option<String>Whether the certificate is eligible for renewal.
Valid values: ELIGIBLE | INELIGIBLE
renewal_summary: Option<AwsCertificateManagerCertificateRenewalSummary>Information about the status of the Certificate Manager managed renewal for the
certificate. Provided only when the certificate type is AMAZON_ISSUED.
serial: Option<String>The serial number of the certificate.
signature_algorithm: Option<String>The algorithm that was used to sign the certificate.
status: Option<String>The status of the certificate.
Valid values: PENDING_VALIDATION | ISSUED |
INACTIVE | EXPIRED | VALIDATION_TIMED_OUT |
REVOKED | FAILED
subject: Option<String>The name of the entity that is associated with the public key contained in the certificate.
subject_alternative_names: Option<Vec<String>>One or more domain names (subject alternative names) included in the certificate. This list contains the domain names that are bound to the public key that is contained in the certificate.
The subject alternative names include the canonical domain name (CN) of the certificate and additional domain names that can be used to connect to the website.
type: Option<String>The source of the certificate. For certificates that Certificate Manager provides,
Type is AMAZON_ISSUED. For certificates that are imported with
ImportCertificate, Type is IMPORTED.
Valid values: IMPORTED | AMAZON_ISSUED |
PRIVATE
Implementations
The ARN of the private certificate authority (CA) that will be used to issue the certificate.
Indicates when the certificate was requested.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
The fully qualified domain name (FQDN), such as www.example.com, that is secured by the certificate.
Contains information about the initial validation of each domain name that occurs as a
result of the RequestCertificate request.
Only provided if the certificate type is AMAZON_ISSUED.
pub fn extended_key_usages(
&self
) -> Option<&[AwsCertificateManagerCertificateExtendedKeyUsage]>
pub fn extended_key_usages(
&self
) -> Option<&[AwsCertificateManagerCertificateExtendedKeyUsage]>
Contains a list of Extended Key Usage X.509 v3 extension objects. Each object specifies a purpose for which the certificate public key can be used and consists of a name and an object identifier (OID).
For a failed certificate request, the reason for the failure.
Valid values: NO_AVAILABLE_CONTACTS |
ADDITIONAL_VERIFICATION_REQUIRED | DOMAIN_NOT_ALLOWED |
INVALID_PUBLIC_DOMAIN | DOMAIN_VALIDATION_DENIED |
CAA_ERROR | PCA_LIMIT_EXCEEDED | PCA_INVALID_ARN
| PCA_INVALID_STATE | PCA_REQUEST_FAILED |
PCA_NAME_CONSTRAINTS_VALIDATION | PCA_RESOURCE_NOT_FOUND |
PCA_INVALID_ARGS | PCA_INVALID_DURATION |
PCA_ACCESS_DENIED | SLR_NOT_FOUND | OTHER
Indicates when the certificate was imported. Provided if the certificate type is
IMPORTED.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
The list of ARNs for the Amazon Web Services resources that use the certificate.
Indicates when the certificate was issued. Provided if the certificate type is
AMAZON_ISSUED.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
The name of the certificate authority that issued and signed the certificate.
The algorithm that was used to generate the public-private key pair.
Valid values: RSA_2048 | RSA_1024 | RSA_4096 |
EC_prime256v1 | EC_secp384r1 |
EC_secp521r1
A list of key usage X.509 v3 extension objects.
The time after which the certificate becomes invalid.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
The time before which the certificate is not valid.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
Provides a value that specifies whether to add the certificate to a transparency log.
Whether the certificate is eligible for renewal.
Valid values: ELIGIBLE | INELIGIBLE
Information about the status of the Certificate Manager managed renewal for the
certificate. Provided only when the certificate type is AMAZON_ISSUED.
The algorithm that was used to sign the certificate.
The status of the certificate.
Valid values: PENDING_VALIDATION | ISSUED |
INACTIVE | EXPIRED | VALIDATION_TIMED_OUT |
REVOKED | FAILED
The name of the entity that is associated with the public key contained in the certificate.
One or more domain names (subject alternative names) included in the certificate. This list contains the domain names that are bound to the public key that is contained in the certificate.
The subject alternative names include the canonical domain name (CN) of the certificate and additional domain names that can be used to connect to the website.
Creates a new builder-style object to manufacture AwsCertificateManagerCertificateDetails