#[non_exhaustive]
pub struct AwsCertificateManagerCertificateDomainValidationOption { /* private fields */ }
Contains information about one of the following:

  • The initial validation of each domain name that occurs as a result of the RequestCertificate request

  • The validation of each domain name in the certificate, as it pertains to Certificate Manager managed renewal

Implementations

A fully qualified domain name (FQDN) in the certificate.

The CNAME record that is added to the DNS database for domain validation.

The domain name that Certificate Manager uses to send domain validation emails.

A list of email addresses that Certificate Manager uses to send domain validation emails.

The method used to validate the domain name.

The validation status of the domain name.

Creates a new builder-style object to manufacture AwsCertificateManagerCertificateDomainValidationOption.