#[non_exhaustive]pub struct AwsCloudFormationStackDetails { /* private fields */ }Expand description
Nests a stack as a resource in a top-level template. Nested stacks are stacks created as resources for another stack.
Implementations
sourceimpl AwsCloudFormationStackDetails
impl AwsCloudFormationStackDetails
sourcepub fn capabilities(&self) -> Option<&[String]>
pub fn capabilities(&self) -> Option<&[String]>
The capabilities allowed in the stack.
sourcepub fn creation_time(&self) -> Option<&str>
pub fn creation_time(&self) -> Option<&str>
The time at which the stack was created.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A user-defined description associated with the stack.
sourcepub fn disable_rollback(&self) -> bool
pub fn disable_rollback(&self) -> bool
Boolean to enable or disable rollback on stack creation failures.
sourcepub fn drift_information(
&self
) -> Option<&AwsCloudFormationStackDriftInformationDetails>
pub fn drift_information(
&self
) -> Option<&AwsCloudFormationStackDriftInformationDetails>
Information about whether a stack's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters.
sourcepub fn enable_termination_protection(&self) -> bool
pub fn enable_termination_protection(&self) -> bool
Whether termination protection is enabled for the stack.
sourcepub fn last_updated_time(&self) -> Option<&str>
pub fn last_updated_time(&self) -> Option<&str>
The time the nested stack was last updated. This field will only be returned if the stack has been updated at least once.
sourcepub fn notification_arns(&self) -> Option<&[String]>
pub fn notification_arns(&self) -> Option<&[String]>
The Amazon Resource Names (ARNs) of the Amazon SNS topic to which stack-related events are published.
sourcepub fn outputs(&self) -> Option<&[AwsCloudFormationStackOutputsDetails]>
pub fn outputs(&self) -> Option<&[AwsCloudFormationStackOutputsDetails]>
A list of output structures.
sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The ARN of an IAM role that's associated with the stack.
sourcepub fn stack_name(&self) -> Option<&str>
pub fn stack_name(&self) -> Option<&str>
The name associated with the stack.
sourcepub fn stack_status(&self) -> Option<&str>
pub fn stack_status(&self) -> Option<&str>
Current status of the stack.
sourcepub fn stack_status_reason(&self) -> Option<&str>
pub fn stack_status_reason(&self) -> Option<&str>
Success or failure message associated with the stack status.
sourcepub fn timeout_in_minutes(&self) -> i32
pub fn timeout_in_minutes(&self) -> i32
The length of time, in minutes, that CloudFormation waits for the nested stack to reach the CREATE_COMPLETE state.
sourceimpl AwsCloudFormationStackDetails
impl AwsCloudFormationStackDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCloudFormationStackDetails.