#[non_exhaustive]pub struct AwsCloudFrontDistributionDetails { /* private fields */ }Expand description
A CloudFront distribution configuration.
Implementations
sourceimpl AwsCloudFrontDistributionDetails
impl AwsCloudFrontDistributionDetails
sourcepub fn cache_behaviors(
&self
) -> Option<&AwsCloudFrontDistributionCacheBehaviors>
pub fn cache_behaviors(
&self
) -> Option<&AwsCloudFrontDistributionCacheBehaviors>
Provides information about the cache configuration for the distribution.
sourcepub fn default_cache_behavior(
&self
) -> Option<&AwsCloudFrontDistributionDefaultCacheBehavior>
pub fn default_cache_behavior(
&self
) -> Option<&AwsCloudFrontDistributionDefaultCacheBehavior>
The default cache behavior for the configuration.
sourcepub fn default_root_object(&self) -> Option<&str>
pub fn default_root_object(&self) -> Option<&str>
The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The domain name corresponding to the distribution.
sourcepub fn last_modified_time(&self) -> Option<&str>
pub fn last_modified_time(&self) -> Option<&str>
Indicates when that the distribution was last modified.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn logging(&self) -> Option<&AwsCloudFrontDistributionLogging>
pub fn logging(&self) -> Option<&AwsCloudFrontDistributionLogging>
A complex type that controls whether access logs are written for the distribution.
sourcepub fn origins(&self) -> Option<&AwsCloudFrontDistributionOrigins>
pub fn origins(&self) -> Option<&AwsCloudFrontDistributionOrigins>
A complex type that contains information about origins for this distribution.
sourcepub fn origin_groups(&self) -> Option<&AwsCloudFrontDistributionOriginGroups>
pub fn origin_groups(&self) -> Option<&AwsCloudFrontDistributionOriginGroups>
Provides information about the origin groups in the distribution.
sourcepub fn viewer_certificate(
&self
) -> Option<&AwsCloudFrontDistributionViewerCertificate>
pub fn viewer_certificate(
&self
) -> Option<&AwsCloudFrontDistributionViewerCertificate>
Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.
sourcepub fn web_acl_id(&self) -> Option<&str>
pub fn web_acl_id(&self) -> Option<&str>
A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution.
sourceimpl AwsCloudFrontDistributionDetails
impl AwsCloudFrontDistributionDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCloudFrontDistributionDetails.