#[non_exhaustive]pub struct AwsCloudFrontDistributionOriginS3OriginConfig { /* private fields */ }Expand description
Information about an origin that is an Amazon S3 bucket that is not configured with static website hosting.
Implementations
sourceimpl AwsCloudFrontDistributionOriginS3OriginConfig
impl AwsCloudFrontDistributionOriginS3OriginConfig
sourcepub fn origin_access_identity(&self) -> Option<&str>
pub fn origin_access_identity(&self) -> Option<&str>
The CloudFront origin access identity to associate with the origin.
sourceimpl AwsCloudFrontDistributionOriginS3OriginConfig
impl AwsCloudFrontDistributionOriginS3OriginConfig
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCloudFrontDistributionOriginS3OriginConfig.