Struct aws_sdk_securityhub::model::AwsCloudFrontDistributionViewerCertificate [−][src]
#[non_exhaustive]pub struct AwsCloudFrontDistributionViewerCertificate {
pub acm_certificate_arn: Option<String>,
pub certificate: Option<String>,
pub certificate_source: Option<String>,
pub cloud_front_default_certificate: bool,
pub iam_certificate_id: Option<String>,
pub minimum_protocol_version: Option<String>,
pub ssl_support_method: Option<String>,
}Expand description
Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.acm_certificate_arn: Option<String>The ARN of the ACM certificate. Used if the certificate is stored in ACM. If you provide an ACM certificate ARN, you must also provide MinimumCertificateVersion and SslSupportMethod.
certificate: Option<String>The identifier of the certificate. Note that in CloudFront, this attribute is deprecated.
certificate_source: Option<String>The source of the certificate identified by Certificate. Note that in CloudFront, this attribute is deprecated.
cloud_front_default_certificate: boolWhether the distribution uses the CloudFront domain name. If set to false, then you provide either AcmCertificateArn or IamCertificateId.
iam_certificate_id: Option<String>The identifier of the IAM certificate. Used if the certificate is stored in IAM. If you provide IamCertificateId, then you also must provide MinimumProtocolVersion and SslSupportMethod.
minimum_protocol_version: Option<String>The security policy that CloudFront uses for HTTPS connections with viewers. If SslSupportMethod is sni-only, then MinimumProtocolVersion must be TLSv1 or higher.
ssl_support_method: Option<String>The viewers that the distribution accepts HTTPS connections from.
Implementations
Creates a new builder-style object to manufacture AwsCloudFrontDistributionViewerCertificate