Struct aws_sdk_securityhub::model::AwsCloudTrailTrailDetails [−][src]
#[non_exhaustive]pub struct AwsCloudTrailTrailDetails {Show 15 fields
pub cloud_watch_logs_log_group_arn: Option<String>,
pub cloud_watch_logs_role_arn: Option<String>,
pub has_custom_event_selectors: bool,
pub home_region: Option<String>,
pub include_global_service_events: bool,
pub is_multi_region_trail: bool,
pub is_organization_trail: bool,
pub kms_key_id: Option<String>,
pub log_file_validation_enabled: bool,
pub name: Option<String>,
pub s3_bucket_name: Option<String>,
pub s3_key_prefix: Option<String>,
pub sns_topic_arn: Option<String>,
pub sns_topic_name: Option<String>,
pub trail_arn: Option<String>,
}Expand description
Provides details about a CloudTrail trail.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_watch_logs_log_group_arn: Option<String>The ARN of the log group that CloudTrail logs are delivered to.
cloud_watch_logs_role_arn: Option<String>The ARN of the role that the CloudWatch Events endpoint assumes when it writes to the log group.
has_custom_event_selectors: boolIndicates whether the trail has custom event selectors.
home_region: Option<String>The Region where the trail was created.
include_global_service_events: boolIndicates whether the trail publishes events from global services such as IAM to the log files.
is_multi_region_trail: boolIndicates whether the trail applies only to the current Region or to all Regions.
is_organization_trail: boolWhether the trail is created for all accounts in an organization in Organizations, or only for the current Amazon Web Services account.
kms_key_id: Option<String>The KMS key ID to use to encrypt the logs.
log_file_validation_enabled: boolIndicates whether CloudTrail log file validation is enabled.
name: Option<String>The name of the trail.
s3_bucket_name: Option<String>The name of the S3 bucket where the log files are published.
s3_key_prefix: Option<String>The S3 key prefix. The key prefix is added after the name of the S3 bucket where the log files are published.
sns_topic_arn: Option<String>The ARN of the SNS topic that is used for notifications of log file delivery.
sns_topic_name: Option<String>The name of the SNS topic that is used for notifications of log file delivery.
trail_arn: Option<String>The ARN of the trail.
Implementations
The ARN of the log group that CloudTrail logs are delivered to.
The ARN of the role that the CloudWatch Events endpoint assumes when it writes to the log group.
Indicates whether the trail has custom event selectors.
The Region where the trail was created.
Indicates whether the trail publishes events from global services such as IAM to the log files.
Indicates whether the trail applies only to the current Region or to all Regions.
Whether the trail is created for all accounts in an organization in Organizations, or only for the current Amazon Web Services account.
The KMS key ID to use to encrypt the logs.
Indicates whether CloudTrail log file validation is enabled.
The name of the S3 bucket where the log files are published.
The S3 key prefix. The key prefix is added after the name of the S3 bucket where the log files are published.
The ARN of the SNS topic that is used for notifications of log file delivery.
The name of the SNS topic that is used for notifications of log file delivery.
Creates a new builder-style object to manufacture AwsCloudTrailTrailDetails