#[non_exhaustive]pub struct AwsCodeBuildProjectArtifactsDetails { /* private fields */ }Expand description
Information about the build artifacts for the CodeBuild project.
Implementations
sourceimpl AwsCodeBuildProjectArtifactsDetails
impl AwsCodeBuildProjectArtifactsDetails
sourcepub fn artifact_identifier(&self) -> Option<&str>
pub fn artifact_identifier(&self) -> Option<&str>
An identifier for the artifact definition.
sourcepub fn encryption_disabled(&self) -> bool
pub fn encryption_disabled(&self) -> bool
Indicates whether to disable encryption on the artifact. Only valid when Type is S3.
sourcepub fn location(&self) -> Option<&str>
pub fn location(&self) -> Option<&str>
Only used when Type is S3. The name of the S3 bucket where the artifact is located.
sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
Only used when Type is S3. The name of the artifact. Used with NamepaceType and Path to determine the pattern for storing the artifact.
sourcepub fn namespace_type(&self) -> Option<&str>
pub fn namespace_type(&self) -> Option<&str>
Only used when Type is S3. The value to use for the namespace. Used with Name and Path to determine the pattern for storing the artifact.
sourcepub fn override_artifact_name(&self) -> bool
pub fn override_artifact_name(&self) -> bool
Whether the name specified in the buildspec file overrides the artifact name.
sourcepub fn packaging(&self) -> Option<&str>
pub fn packaging(&self) -> Option<&str>
Only used when Type is S3. The type of output artifact to create.
sourceimpl AwsCodeBuildProjectArtifactsDetails
impl AwsCodeBuildProjectArtifactsDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCodeBuildProjectArtifactsDetails.