#[non_exhaustive]pub struct AwsCodeBuildProjectSource { /* private fields */ }Expand description
Information about the build input source code for this build project.
Implementations
sourceimpl AwsCodeBuildProjectSource
impl AwsCodeBuildProjectSource
sourcepub fn type(&self) -> Option<&str>
pub fn type(&self) -> Option<&str>
The type of repository that contains the source code to be built. Valid values are:
-
BITBUCKET- The source code is in a Bitbucket repository. -
CODECOMMIT- The source code is in an CodeCommit repository. -
CODEPIPELINE- The source code settings are specified in the source action of a pipeline in CodePipeline. -
GITHUB- The source code is in a GitHub repository. -
GITHUB_ENTERPRISE- The source code is in a GitHub Enterprise repository. -
NO_SOURCE- The project does not have input source code. -
S3- The source code is in an S3 input bucket.
sourcepub fn location(&self) -> Option<&str>
pub fn location(&self) -> Option<&str>
Information about the location of the source code to be built.
Valid values include:
-
For source code settings that are specified in the source action of a pipeline in CodePipeline, location should not be specified. If it is specified, CodePipeline ignores it. This is because CodePipeline uses the settings in a pipeline's source action instead of this value.
-
For source code in an CodeCommit repository, the HTTPS clone URL to the repository that contains the source code and the build spec file (for example,
https://git-codecommit.region-ID.amazonaws.com/v1/repos/repo-name). -
For source code in an S3 input bucket, one of the following.
-
The path to the ZIP file that contains the source code (for example,
bucket-name/path/to/object-name.zip). -
The path to the folder that contains the source code (for example,
bucket-name/path/to/source-code/folder/).
-
-
For source code in a GitHub repository, the HTTPS clone URL to the repository that contains the source and the build spec file.
-
For source code in a Bitbucket repository, the HTTPS clone URL to the repository that contains the source and the build spec file.
sourcepub fn git_clone_depth(&self) -> i32
pub fn git_clone_depth(&self) -> i32
Information about the Git clone depth for the build project.
sourcepub fn insecure_ssl(&self) -> bool
pub fn insecure_ssl(&self) -> bool
Whether to ignore SSL warnings while connecting to the project source code.
sourceimpl AwsCodeBuildProjectSource
impl AwsCodeBuildProjectSource
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCodeBuildProjectSource.