#[non_exhaustive]pub struct AwsDynamoDbTableBillingModeSummary { /* private fields */ }Expand description
Provides information about the billing for read/write capacity on the table.
Implementations
sourceimpl AwsDynamoDbTableBillingModeSummary
impl AwsDynamoDbTableBillingModeSummary
sourcepub fn billing_mode(&self) -> Option<&str>
pub fn billing_mode(&self) -> Option<&str>
The method used to charge for read and write throughput and to manage capacity.
sourcepub fn last_update_to_pay_per_request_date_time(&self) -> Option<&str>
pub fn last_update_to_pay_per_request_date_time(&self) -> Option<&str>
If the billing mode is PAY_PER_REQUEST, indicates when the billing mode was set to that value.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourceimpl AwsDynamoDbTableBillingModeSummary
impl AwsDynamoDbTableBillingModeSummary
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableBillingModeSummary.