#[non_exhaustive]pub struct AwsDynamoDbTableGlobalSecondaryIndex { /* private fields */ }Expand description
Information abut a global secondary index for the table.
Implementations
sourceimpl AwsDynamoDbTableGlobalSecondaryIndex
impl AwsDynamoDbTableGlobalSecondaryIndex
sourcepub fn backfilling(&self) -> bool
pub fn backfilling(&self) -> bool
Whether the index is currently backfilling.
sourcepub fn index_name(&self) -> Option<&str>
pub fn index_name(&self) -> Option<&str>
The name of the index.
sourcepub fn index_size_bytes(&self) -> i64
pub fn index_size_bytes(&self) -> i64
The total size in bytes of the index.
sourcepub fn index_status(&self) -> Option<&str>
pub fn index_status(&self) -> Option<&str>
The current status of the index.
-
ACTIVE -
CREATING -
DELETING -
UPDATING
sourcepub fn item_count(&self) -> i32
pub fn item_count(&self) -> i32
The number of items in the index.
sourcepub fn key_schema(&self) -> Option<&[AwsDynamoDbTableKeySchema]>
pub fn key_schema(&self) -> Option<&[AwsDynamoDbTableKeySchema]>
The key schema for the index.
sourcepub fn projection(&self) -> Option<&AwsDynamoDbTableProjection>
pub fn projection(&self) -> Option<&AwsDynamoDbTableProjection>
Attributes that are copied from the table into an index.
sourcepub fn provisioned_throughput(
&self
) -> Option<&AwsDynamoDbTableProvisionedThroughput>
pub fn provisioned_throughput(
&self
) -> Option<&AwsDynamoDbTableProvisionedThroughput>
Information about the provisioned throughput settings for the indexes.
sourceimpl AwsDynamoDbTableGlobalSecondaryIndex
impl AwsDynamoDbTableGlobalSecondaryIndex
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableGlobalSecondaryIndex.