#[non_exhaustive]pub struct AwsDynamoDbTableKeySchema { /* private fields */ }Expand description
A component of the key schema for the DynamoDB table, a global secondary index, or a local secondary index.
Implementations
sourceimpl AwsDynamoDbTableKeySchema
impl AwsDynamoDbTableKeySchema
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableKeySchema.