#[non_exhaustive]pub struct AwsDynamoDbTableProjection { /* private fields */ }Expand description
For global and local secondary indexes, identifies the attributes that are copied from the table into the index.
Implementations
sourceimpl AwsDynamoDbTableProjection
impl AwsDynamoDbTableProjection
sourcepub fn non_key_attributes(&self) -> Option<&[String]>
pub fn non_key_attributes(&self) -> Option<&[String]>
The nonkey attributes that are projected into the index. For each attribute, provide the attribute name.
sourcepub fn projection_type(&self) -> Option<&str>
pub fn projection_type(&self) -> Option<&str>
The types of attributes that are projected into the index. Valid values are as follows:
-
ALL -
INCLUDE -
KEYS_ONLY
sourceimpl AwsDynamoDbTableProjection
impl AwsDynamoDbTableProjection
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableProjection.