#[non_exhaustive]pub struct AwsDynamoDbTableProvisionedThroughput { /* private fields */ }Expand description
Information about the provisioned throughput for the table or for a global secondary index.
Implementations
sourceimpl AwsDynamoDbTableProvisionedThroughput
impl AwsDynamoDbTableProvisionedThroughput
sourcepub fn last_decrease_date_time(&self) -> Option<&str>
pub fn last_decrease_date_time(&self) -> Option<&str>
Indicates when the provisioned throughput was last decreased.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn last_increase_date_time(&self) -> Option<&str>
pub fn last_increase_date_time(&self) -> Option<&str>
Indicates when the provisioned throughput was last increased.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn number_of_decreases_today(&self) -> i32
pub fn number_of_decreases_today(&self) -> i32
The number of times during the current UTC calendar day that the provisioned throughput was decreased.
sourcepub fn read_capacity_units(&self) -> i32
pub fn read_capacity_units(&self) -> i32
The maximum number of strongly consistent reads consumed per second before DynamoDB returns a ThrottlingException.
sourcepub fn write_capacity_units(&self) -> i32
pub fn write_capacity_units(&self) -> i32
The maximum number of writes consumed per second before DynamoDB returns a ThrottlingException.
sourceimpl AwsDynamoDbTableProvisionedThroughput
impl AwsDynamoDbTableProvisionedThroughput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableProvisionedThroughput.