#[non_exhaustive]pub struct AwsDynamoDbTableReplicaGlobalSecondaryIndex { /* private fields */ }Expand description
Information about a global secondary index for a DynamoDB table replica.
Implementations
sourceimpl AwsDynamoDbTableReplicaGlobalSecondaryIndex
impl AwsDynamoDbTableReplicaGlobalSecondaryIndex
sourcepub fn index_name(&self) -> Option<&str>
pub fn index_name(&self) -> Option<&str>
The name of the index.
sourcepub fn provisioned_throughput_override(
&self
) -> Option<&AwsDynamoDbTableProvisionedThroughputOverride>
pub fn provisioned_throughput_override(
&self
) -> Option<&AwsDynamoDbTableProvisionedThroughputOverride>
Replica-specific configuration for the provisioned throughput for the index.
sourceimpl AwsDynamoDbTableReplicaGlobalSecondaryIndex
impl AwsDynamoDbTableReplicaGlobalSecondaryIndex
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsDynamoDbTableReplicaGlobalSecondaryIndex.