Struct aws_sdk_securityhub::model::AwsEc2EipDetails
source · [−]#[non_exhaustive]pub struct AwsEc2EipDetails { /* private fields */ }Expand description
Information about an Elastic IP address.
Implementations
sourceimpl AwsEc2EipDetails
impl AwsEc2EipDetails
sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the EC2 instance.
sourcepub fn public_ip(&self) -> Option<&str>
pub fn public_ip(&self) -> Option<&str>
A public IP address that is associated with the EC2 instance.
sourcepub fn allocation_id(&self) -> Option<&str>
pub fn allocation_id(&self) -> Option<&str>
The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
sourcepub fn association_id(&self) -> Option<&str>
pub fn association_id(&self) -> Option<&str>
The identifier that represents the association of the Elastic IP address with an EC2 instance.
sourcepub fn domain(&self) -> Option<&str>
pub fn domain(&self) -> Option<&str>
The domain in which to allocate the address.
If the address is for use with EC2 instances in a VPC, then Domain is vpc. Otherwise, Domain is standard.
sourcepub fn public_ipv4_pool(&self) -> Option<&str>
pub fn public_ipv4_pool(&self) -> Option<&str>
The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.
sourcepub fn network_border_group(&self) -> Option<&str>
pub fn network_border_group(&self) -> Option<&str>
The name of the location from which the Elastic IP address is advertised.
sourcepub fn network_interface_id(&self) -> Option<&str>
pub fn network_interface_id(&self) -> Option<&str>
The identifier of the network interface.
sourcepub fn network_interface_owner_id(&self) -> Option<&str>
pub fn network_interface_owner_id(&self) -> Option<&str>
The Amazon Web Services account ID of the owner of the network interface.
sourcepub fn private_ip_address(&self) -> Option<&str>
pub fn private_ip_address(&self) -> Option<&str>
The private IP address that is associated with the Elastic IP address.
sourceimpl AwsEc2EipDetails
impl AwsEc2EipDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2EipDetails.