Struct aws_sdk_securityhub::model::AwsEc2InstanceDetails
source · [−]#[non_exhaustive]pub struct AwsEc2InstanceDetails { /* private fields */ }Expand description
The details of an Amazon EC2 instance.
Implementations
sourceimpl AwsEc2InstanceDetails
impl AwsEc2InstanceDetails
sourcepub fn ip_v4_addresses(&self) -> Option<&[String]>
pub fn ip_v4_addresses(&self) -> Option<&[String]>
The IPv4 addresses associated with the instance.
sourcepub fn ip_v6_addresses(&self) -> Option<&[String]>
pub fn ip_v6_addresses(&self) -> Option<&[String]>
The IPv6 addresses associated with the instance.
sourcepub fn iam_instance_profile_arn(&self) -> Option<&str>
pub fn iam_instance_profile_arn(&self) -> Option<&str>
The IAM profile ARN of the instance.
sourcepub fn vpc_id(&self) -> Option<&str>
pub fn vpc_id(&self) -> Option<&str>
The identifier of the VPC that the instance was launched in.
sourcepub fn subnet_id(&self) -> Option<&str>
pub fn subnet_id(&self) -> Option<&str>
The identifier of the subnet that the instance was launched in.
sourcepub fn launched_at(&self) -> Option<&str>
pub fn launched_at(&self) -> Option<&str>
Indicates when the instance was launched.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn network_interfaces(
&self
) -> Option<&[AwsEc2InstanceNetworkInterfacesDetails]>
pub fn network_interfaces(
&self
) -> Option<&[AwsEc2InstanceNetworkInterfacesDetails]>
The identifiers of the network interfaces for the EC2 instance. The details for each network interface are in a corresponding AwsEc2NetworkInterfacesDetails object.
sourcepub fn virtualization_type(&self) -> Option<&str>
pub fn virtualization_type(&self) -> Option<&str>
The virtualization type of the Amazon Machine Image (AMI) required to launch the instance.
sourcepub fn metadata_options(&self) -> Option<&AwsEc2InstanceMetadataOptions>
pub fn metadata_options(&self) -> Option<&AwsEc2InstanceMetadataOptions>
Details about the metadata options for the Amazon EC2 instance.
sourceimpl AwsEc2InstanceDetails
impl AwsEc2InstanceDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2InstanceDetails.