#[non_exhaustive]pub struct AwsEc2InstanceMetadataOptions { /* private fields */ }Expand description
Metadata options that allow you to configure and secure the Amazon EC2 instance.
Implementations
sourceimpl AwsEc2InstanceMetadataOptions
impl AwsEc2InstanceMetadataOptions
sourcepub fn http_endpoint(&self) -> Option<&str>
pub fn http_endpoint(&self) -> Option<&str>
Enables or disables the HTTP metadata endpoint on the instance.
sourcepub fn http_protocol_ipv6(&self) -> Option<&str>
pub fn http_protocol_ipv6(&self) -> Option<&str>
Enables or disables the IPv6 endpoint for the instance metadata service.
sourcepub fn http_put_response_hop_limit(&self) -> i32
pub fn http_put_response_hop_limit(&self) -> i32
The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
sourcepub fn http_tokens(&self) -> Option<&str>
pub fn http_tokens(&self) -> Option<&str>
The state of token usage for your instance metadata requests.
Specifies whether to allow access to instance tags from the instance metadata.
sourceimpl AwsEc2InstanceMetadataOptions
impl AwsEc2InstanceMetadataOptions
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2InstanceMetadataOptions.