#[non_exhaustive]
pub struct AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails { /* private fields */ }
Information about the target Capacity Reservation or Capacity Reservation group in which to run an Amazon EC2 instance.

Implementations

The ID of the Capacity Reservation in which to run the instance.

The Amazon Resource Name (ARN) of the Capacity Reservation resource group in which to run the instance.