#[non_exhaustive]pub struct AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails { /* private fields */ }Expand description
One or more network interfaces to attach to an Amazon EC2 instance. If you specify a network interface, you must specify security groups and subnets as part of the network interface.
Implementations
sourceimpl AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails
impl AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails
sourcepub fn associate_carrier_ip_address(&self) -> bool
pub fn associate_carrier_ip_address(&self) -> bool
Indicates whether to associate a Carrier IP address with eth0 for a new network interface. You use this option when you launch an instance in a Wavelength Zone and want to associate a Carrier IP address with the network interface. For more information, see Carrier IP address in the Wavelength Developer Guide.
sourcepub fn associate_public_ip_address(&self) -> bool
pub fn associate_public_ip_address(&self) -> bool
Associates a public IPv4 address with eth0 for a new network interface.
sourcepub fn delete_on_termination(&self) -> bool
pub fn delete_on_termination(&self) -> bool
Indicates whether the network interface is deleted when the instance is terminated.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description for the network interface.
sourcepub fn device_index(&self) -> i32
pub fn device_index(&self) -> i32
The device index for the network interface attachment.
sourcepub fn interface_type(&self) -> Option<&str>
pub fn interface_type(&self) -> Option<&str>
The type of network interface.
sourcepub fn ipv4_prefix_count(&self) -> i32
pub fn ipv4_prefix_count(&self) -> i32
The number of IPv4 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv4Prefixes option.
sourcepub fn ipv4_prefixes(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv4PrefixesDetails]>
pub fn ipv4_prefixes(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv4PrefixesDetails]>
One or more IPv4 prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option.
sourcepub fn ipv6_address_count(&self) -> i32
pub fn ipv6_address_count(&self) -> i32
The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if you use Ipv6Addresses.
sourcepub fn ipv6_addresses(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6AddressesDetails]>
pub fn ipv6_addresses(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6AddressesDetails]>
One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't use this option if you use Ipv6AddressCount.
sourcepub fn ipv6_prefix_count(&self) -> i32
pub fn ipv6_prefix_count(&self) -> i32
The number of IPv6 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv6Prefix option.
sourcepub fn ipv6_prefixes(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6PrefixesDetails]>
pub fn ipv6_prefixes(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6PrefixesDetails]>
One or more IPv6 prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option.
sourcepub fn network_card_index(&self) -> i32
pub fn network_card_index(&self) -> i32
The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0.
sourcepub fn network_interface_id(&self) -> Option<&str>
pub fn network_interface_id(&self) -> Option<&str>
The ID of the network interface.
sourcepub fn private_ip_address(&self) -> Option<&str>
pub fn private_ip_address(&self) -> Option<&str>
The primary private IPv4 address of the network interface.
sourcepub fn private_ip_addresses(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetPrivateIpAddressesDetails]>
pub fn private_ip_addresses(
&self
) -> Option<&[AwsEc2LaunchTemplateDataNetworkInterfaceSetPrivateIpAddressesDetails]>
One or more private IPv4 addresses.
sourcepub fn secondary_private_ip_address_count(&self) -> i32
pub fn secondary_private_ip_address_count(&self) -> i32
The number of secondary private IPv4 addresses to assign to a network interface.
sourceimpl AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails
impl AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails.