Struct aws_sdk_securityhub::model::AwsEc2NetworkAclEntry
source · [−]#[non_exhaustive]pub struct AwsEc2NetworkAclEntry { /* private fields */ }Expand description
A rule for the network ACL. Each rule allows or denies access based on the IP address, traffic direction, port, and protocol.
Implementations
sourceimpl AwsEc2NetworkAclEntry
impl AwsEc2NetworkAclEntry
sourcepub fn cidr_block(&self) -> Option<&str>
pub fn cidr_block(&self) -> Option<&str>
The IPV4 network range for which to deny or allow access.
sourcepub fn egress(&self) -> bool
pub fn egress(&self) -> bool
Whether the rule is an egress rule. An egress rule is a rule that applies to traffic that leaves the subnet.
sourcepub fn icmp_type_code(&self) -> Option<&IcmpTypeCode>
pub fn icmp_type_code(&self) -> Option<&IcmpTypeCode>
The Internet Control Message Protocol (ICMP) type and code for which to deny or allow access.
sourcepub fn ipv6_cidr_block(&self) -> Option<&str>
pub fn ipv6_cidr_block(&self) -> Option<&str>
The IPV6 network range for which to deny or allow access.
sourcepub fn port_range(&self) -> Option<&PortRangeFromTo>
pub fn port_range(&self) -> Option<&PortRangeFromTo>
For TCP or UDP protocols, the range of ports that the rule applies to.
sourcepub fn protocol(&self) -> Option<&str>
pub fn protocol(&self) -> Option<&str>
The protocol that the rule applies to. To deny or allow access to all protocols, use the value -1.
sourcepub fn rule_action(&self) -> Option<&str>
pub fn rule_action(&self) -> Option<&str>
Whether the rule is used to allow access or deny access.
sourcepub fn rule_number(&self) -> i32
pub fn rule_number(&self) -> i32
The rule number. The rules are processed in order by their number.
sourceimpl AwsEc2NetworkAclEntry
impl AwsEc2NetworkAclEntry
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2NetworkAclEntry.