Struct aws_sdk_securityhub::model::AwsEc2SubnetDetails
source · [−]#[non_exhaustive]pub struct AwsEc2SubnetDetails { /* private fields */ }Expand description
Contains information about a subnet in Amazon EC2.
Implementations
sourceimpl AwsEc2SubnetDetails
impl AwsEc2SubnetDetails
sourcepub fn assign_ipv6_address_on_creation(&self) -> bool
pub fn assign_ipv6_address_on_creation(&self) -> bool
Whether to assign an IPV6 address to a network interface that is created in this subnet.
sourcepub fn availability_zone(&self) -> Option<&str>
pub fn availability_zone(&self) -> Option<&str>
The Availability Zone for the subnet.
sourcepub fn availability_zone_id(&self) -> Option<&str>
pub fn availability_zone_id(&self) -> Option<&str>
The identifier of the Availability Zone for the subnet.
sourcepub fn available_ip_address_count(&self) -> i32
pub fn available_ip_address_count(&self) -> i32
The number of available IPV4 addresses in the subnet. Does not include addresses for stopped instances.
sourcepub fn cidr_block(&self) -> Option<&str>
pub fn cidr_block(&self) -> Option<&str>
The IPV4 CIDR block that is assigned to the subnet.
sourcepub fn default_for_az(&self) -> bool
pub fn default_for_az(&self) -> bool
Whether this subnet is the default subnet for the Availability Zone.
sourcepub fn map_public_ip_on_launch(&self) -> bool
pub fn map_public_ip_on_launch(&self) -> bool
Whether instances in this subnet receive a public IP address.
sourcepub fn owner_id(&self) -> Option<&str>
pub fn owner_id(&self) -> Option<&str>
The identifier of the Amazon Web Services account that owns the subnet.
sourcepub fn state(&self) -> Option<&str>
pub fn state(&self) -> Option<&str>
The current state of the subnet. Valid values are available or pending.
sourcepub fn subnet_arn(&self) -> Option<&str>
pub fn subnet_arn(&self) -> Option<&str>
The ARN of the subnet.
sourcepub fn ipv6_cidr_block_association_set(
&self
) -> Option<&[Ipv6CidrBlockAssociation]>
pub fn ipv6_cidr_block_association_set(
&self
) -> Option<&[Ipv6CidrBlockAssociation]>
The IPV6 CIDR blocks that are associated with the subnet.
sourceimpl AwsEc2SubnetDetails
impl AwsEc2SubnetDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2SubnetDetails.