#[non_exhaustive]pub struct AwsEc2TransitGatewayDetails { /* private fields */ }Expand description
Information about an Amazon Web Services Amazon EC2 Transit Gateway that interconnects virtual private clouds (VPCs) and on-premises networks.
Implementations
sourceimpl AwsEc2TransitGatewayDetails
impl AwsEc2TransitGatewayDetails
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the transit gateway.
sourcepub fn default_route_table_propagation(&self) -> Option<&str>
pub fn default_route_table_propagation(&self) -> Option<&str>
Turn on or turn off automatic propagation of routes to the default propagation route table.
Turn on or turn off automatic acceptance of attachment requests.
sourcepub fn default_route_table_association(&self) -> Option<&str>
pub fn default_route_table_association(&self) -> Option<&str>
Turn on or turn off automatic association with the default association route table.
sourcepub fn transit_gateway_cidr_blocks(&self) -> Option<&[String]>
pub fn transit_gateway_cidr_blocks(&self) -> Option<&[String]>
The transit gateway Classless Inter-Domain Routing (CIDR) blocks.
sourcepub fn association_default_route_table_id(&self) -> Option<&str>
pub fn association_default_route_table_id(&self) -> Option<&str>
The ID of the default association route table.
sourcepub fn propagation_default_route_table_id(&self) -> Option<&str>
pub fn propagation_default_route_table_id(&self) -> Option<&str>
The ID of the default propagation route table.
sourcepub fn vpn_ecmp_support(&self) -> Option<&str>
pub fn vpn_ecmp_support(&self) -> Option<&str>
Turn on or turn off Equal Cost Multipath Protocol (ECMP) support.
sourcepub fn dns_support(&self) -> Option<&str>
pub fn dns_support(&self) -> Option<&str>
Turn on or turn off DNS support.
sourcepub fn multicast_support(&self) -> Option<&str>
pub fn multicast_support(&self) -> Option<&str>
Indicates whether multicast is supported on the transit gateway.
sourcepub fn amazon_side_asn(&self) -> i32
pub fn amazon_side_asn(&self) -> i32
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
sourceimpl AwsEc2TransitGatewayDetails
impl AwsEc2TransitGatewayDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2TransitGatewayDetails.