#[non_exhaustive]
pub struct AwsEc2VpcEndpointServiceDetails { /* private fields */ }
Contains details about the service configuration for a VPC endpoint service.

Implementations

Whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.

The Availability Zones where the service is available.

The DNS names for the service.

Whether the service manages its VPC endpoints.

The ARNs of the Gateway Load Balancers for the service.

The ARNs of the Network Load Balancers for the service.

The private DNS name for the service.

The identifier of the service.

The name of the service.

The current state of the service. Valid values are as follows:

  • Available

  • Deleted

  • Deleting

  • Failed

  • Pending

The types for the service.

Creates a new builder-style object to manufacture AwsEc2VpcEndpointServiceDetails.