#[non_exhaustive]
pub struct AwsEc2VpnConnectionDetails { /* private fields */ }
Details about an Amazon EC2 VPN connection.

Implementations

The identifier of the VPN connection.

The current state of the VPN connection. Valid values are as follows:

  • available

  • deleted

  • deleting

  • pending

The identifier of the customer gateway that is at your end of the VPN connection.

The configuration information for the VPN connection's customer gateway, in the native XML format.

The type of VPN connection.

The identifier of the virtual private gateway that is at the Amazon Web Services side of the VPN connection.

The category of the VPN connection. VPN indicates an Amazon Web Services VPN connection. VPN-Classic indicates an Amazon Web Services Classic VPN connection.

Information about the VPN tunnel.

The VPN connection options.

The static routes that are associated with the VPN connection.

The identifier of the transit gateway that is associated with the VPN connection.

Creates a new builder-style object to manufacture AwsEc2VpnConnectionDetails.