Struct aws_sdk_securityhub::model::AwsEc2VpnConnectionOptionsTunnelOptionsDetails [−][src]
#[non_exhaustive]pub struct AwsEc2VpnConnectionOptionsTunnelOptionsDetails {Show 16 fields
pub dpd_timeout_seconds: i32,
pub ike_versions: Option<Vec<String>>,
pub outside_ip_address: Option<String>,
pub phase1_dh_group_numbers: Option<Vec<i32>>,
pub phase1_encryption_algorithms: Option<Vec<String>>,
pub phase1_integrity_algorithms: Option<Vec<String>>,
pub phase1_lifetime_seconds: i32,
pub phase2_dh_group_numbers: Option<Vec<i32>>,
pub phase2_encryption_algorithms: Option<Vec<String>>,
pub phase2_integrity_algorithms: Option<Vec<String>>,
pub phase2_lifetime_seconds: i32,
pub pre_shared_key: Option<String>,
pub rekey_fuzz_percentage: i32,
pub rekey_margin_time_seconds: i32,
pub replay_window_size: i32,
pub tunnel_inside_cidr: Option<String>,
}Expand description
The VPN tunnel options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dpd_timeout_seconds: i32The number of seconds after which a Dead Peer Detection (DPD) timeout occurs.
ike_versions: Option<Vec<String>>The Internet Key Exchange (IKE) versions that are permitted for the VPN tunnel.
outside_ip_address: Option<String>The external IP address of the VPN tunnel.
phase1_dh_group_numbers: Option<Vec<i32>>The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
phase1_encryption_algorithms: Option<Vec<String>>The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
phase1_integrity_algorithms: Option<Vec<String>>The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
phase1_lifetime_seconds: i32The lifetime for phase 1 of the IKE negotiation, in seconds.
phase2_dh_group_numbers: Option<Vec<i32>>The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
phase2_encryption_algorithms: Option<Vec<String>>The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
phase2_integrity_algorithms: Option<Vec<String>>The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
phase2_lifetime_seconds: i32The lifetime for phase 2 of the IKE negotiation, in seconds.
The preshared key to establish initial authentication between the virtual private gateway and the customer gateway.
rekey_fuzz_percentage: i32The percentage of the rekey window, which is determined by
RekeyMarginTimeSeconds during which the rekey time is randomly selected.
rekey_margin_time_seconds: i32The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
replay_window_size: i32The number of packets in an IKE replay window.
tunnel_inside_cidr: Option<String>The range of inside IPv4 addresses for the tunnel.
Implementations
Creates a new builder-style object to manufacture AwsEc2VpnConnectionOptionsTunnelOptionsDetails