#[non_exhaustive]pub struct AwsEcrContainerImageDetails { /* private fields */ }Expand description
Information about an Amazon ECR image.
Implementations
sourceimpl AwsEcrContainerImageDetails
impl AwsEcrContainerImageDetails
sourcepub fn registry_id(&self) -> Option<&str>
pub fn registry_id(&self) -> Option<&str>
The Amazon Web Services account identifier that is associated with the registry that the image belongs to.
sourcepub fn repository_name(&self) -> Option<&str>
pub fn repository_name(&self) -> Option<&str>
The name of the repository that the image belongs to.
sourcepub fn architecture(&self) -> Option<&str>
pub fn architecture(&self) -> Option<&str>
The architecture of the image. Valid values are as follows:
-
arm64 -
i386 -
x86_64
sourcepub fn image_digest(&self) -> Option<&str>
pub fn image_digest(&self) -> Option<&str>
The sha256 digest of the image manifest.
The list of tags that are associated with the image.
sourcepub fn image_published_at(&self) -> Option<&str>
pub fn image_published_at(&self) -> Option<&str>
The date and time when the image was pushed to the repository.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourceimpl AwsEcrContainerImageDetails
impl AwsEcrContainerImageDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcrContainerImageDetails.