Struct aws_sdk_securityhub::model::AwsEcsClusterConfigurationExecuteCommandConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsEcsClusterConfigurationExecuteCommandConfigurationDetails {
pub kms_key_id: Option<String>,
pub log_configuration: Option<AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails>,
pub logging: Option<String>,
}Expand description
Contains the run command configuration for the cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key_id: Option<String>The identifier of the KMS key that is used to encrypt the data between the local client and the container.
log_configuration: Option<AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails>The log configuration for the results of the run command actions. Required if Logging is NONE.
logging: Option<String>The log setting to use for redirecting logs for run command results.
Implementations
Creates a new builder-style object to manufacture AwsEcsClusterConfigurationExecuteCommandConfigurationDetails