Struct aws_sdk_securityhub::model::AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails {
pub cloud_watch_encryption_enabled: bool,
pub cloud_watch_log_group_name: Option<String>,
pub s3_bucket_name: Option<String>,
pub s3_encryption_enabled: bool,
pub s3_key_prefix: Option<String>,
}Expand description
The log configuration for the results of the run command actions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_watch_encryption_enabled: boolWhether to enable encryption on the CloudWatch logs.
cloud_watch_log_group_name: Option<String>The name of the CloudWatch log group to send the logs to.
s3_bucket_name: Option<String>The name of the S3 bucket to send logs to.
s3_encryption_enabled: boolWhether to encrypt the logs that are sent to the S3 bucket.
s3_key_prefix: Option<String>Identifies the folder in the S3 bucket to send the logs to.
Implementations
Creates a new builder-style object to manufacture AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails