Struct aws_sdk_securityhub::model::AwsEcsClusterDefaultCapacityProviderStrategyDetails [−][src]
#[non_exhaustive]pub struct AwsEcsClusterDefaultCapacityProviderStrategyDetails {
pub base: i32,
pub capacity_provider: Option<String>,
pub weight: i32,
}Expand description
The default capacity provider strategy for the cluster. The default capacity provider strategy is used when services or tasks are run without a specified launch type or capacity provider strategy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.base: i32The minimum number of tasks to run on the specified capacity provider.
capacity_provider: Option<String>The name of the capacity provider.
weight: i32The relative percentage of the total number of tasks launched that should use the capacity provider.
Implementations
Creates a new builder-style object to manufacture AwsEcsClusterDefaultCapacityProviderStrategyDetails