Struct aws_sdk_securityhub::model::AwsEcsClusterDetails
source · [−]#[non_exhaustive]pub struct AwsEcsClusterDetails { /* private fields */ }Expand description
Provides details about an Amazon ECS cluster.
Implementations
sourceimpl AwsEcsClusterDetails
impl AwsEcsClusterDetails
sourcepub fn cluster_arn(&self) -> Option<&str>
pub fn cluster_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) that identifies the cluster.
sourcepub fn active_services_count(&self) -> i32
pub fn active_services_count(&self) -> i32
The number of services that are running on the cluster in an ACTIVE state. You can view these services with the Amazon ECS ListServices API operation.
sourcepub fn capacity_providers(&self) -> Option<&[String]>
pub fn capacity_providers(&self) -> Option<&[String]>
The short name of one or more capacity providers to associate with the cluster.
sourcepub fn cluster_settings(&self) -> Option<&[AwsEcsClusterClusterSettingsDetails]>
pub fn cluster_settings(&self) -> Option<&[AwsEcsClusterClusterSettingsDetails]>
The setting to use to create the cluster. Specifically used to configure whether to enable CloudWatch Container Insights for the cluster.
sourcepub fn configuration(&self) -> Option<&AwsEcsClusterConfigurationDetails>
pub fn configuration(&self) -> Option<&AwsEcsClusterConfigurationDetails>
The run command configuration for the cluster.
sourcepub fn default_capacity_provider_strategy(
&self
) -> Option<&[AwsEcsClusterDefaultCapacityProviderStrategyDetails]>
pub fn default_capacity_provider_strategy(
&self
) -> Option<&[AwsEcsClusterDefaultCapacityProviderStrategyDetails]>
The default capacity provider strategy for the cluster. The default capacity provider strategy is used when services or tasks are run without a specified launch type or capacity provider strategy.
sourcepub fn cluster_name(&self) -> Option<&str>
pub fn cluster_name(&self) -> Option<&str>
A name that you use to identify your cluster.
sourcepub fn registered_container_instances_count(&self) -> i32
pub fn registered_container_instances_count(&self) -> i32
The number of container instances registered into the cluster. This includes container instances in both ACTIVE and DRAINING status.
sourcepub fn running_tasks_count(&self) -> i32
pub fn running_tasks_count(&self) -> i32
The number of tasks in the cluster that are in the RUNNING state.
sourceimpl AwsEcsClusterDetails
impl AwsEcsClusterDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcsClusterDetails.