Struct aws_sdk_securityhub::model::AwsEcsContainerDetails
source · [−]#[non_exhaustive]pub struct AwsEcsContainerDetails { /* private fields */ }Expand description
Provides information about an Amazon ECS container.
Implementations
sourceimpl AwsEcsContainerDetails
impl AwsEcsContainerDetails
sourcepub fn mount_points(&self) -> Option<&[AwsMountPoint]>
pub fn mount_points(&self) -> Option<&[AwsMountPoint]>
The mount points for data volumes in your container.
sourcepub fn privileged(&self) -> bool
pub fn privileged(&self) -> bool
When this parameter is true, the container is given elevated privileges on the host container instance (similar to the root user).
sourceimpl AwsEcsContainerDetails
impl AwsEcsContainerDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcsContainerDetails.