#[non_exhaustive]pub struct AwsEcsServiceDeploymentControllerDetails { /* private fields */ }Expand description
Information about the deployment controller type that the service uses.
Implementations
sourceimpl AwsEcsServiceDeploymentControllerDetails
impl AwsEcsServiceDeploymentControllerDetails
sourcepub fn type(&self) -> Option<&str>
pub fn type(&self) -> Option<&str>
The rolling update (ECS) deployment type replaces the current running version of the container with the latest version.
The blue/green (CODE_DEPLOY) deployment type uses the blue/green deployment model that is powered by CodeDeploy. This deployment model a new deployment of a service can be verified before production traffic is sent to it.
The external (EXTERNAL) deployment type allows the use of any third-party deployment controller for full control over the deployment process for an Amazon ECS service.
Valid values: ECS | CODE_DEPLOY | EXTERNAL
sourceimpl AwsEcsServiceDeploymentControllerDetails
impl AwsEcsServiceDeploymentControllerDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcsServiceDeploymentControllerDetails.