Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails {
pub command: Option<Vec<String>>,
pub interval: i32,
pub retries: i32,
pub start_period: i32,
pub timeout: i32,
}Expand description
The container health check command and associated configuration parameters for the container.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.command: Option<Vec<String>>The command that the container runs to determine whether it is healthy.
interval: i32The time period in seconds between each health check execution. The default value is 30 seconds.
retries: i32The number of times to retry a failed health check before the container is considered unhealthy. The default value is 3.
start_period: i32The optional grace period in seconds that allows containers time to bootstrap before failed health checks count towards the maximum number of retries.
timeout: i32The time period in seconds to wait for a health check to succeed before it is considered a failure. The default value is 5.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails