Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails {
pub capabilities: Option<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails>,
pub devices: Option<Vec<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>>,
pub init_process_enabled: bool,
pub max_swap: i32,
pub shared_memory_size: i32,
pub swappiness: i32,
pub tmpfs: Option<Vec<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails>>,
}Expand description
>Linux-specific modifications that are applied to the container, such as Linux kernel capabilities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capabilities: Option<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails>The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
devices: Option<Vec<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>>The host devices to expose to the container.
init_process_enabled: boolWhether to run an init process inside the container that forwards signals and reaps processes.
max_swap: i32The total amount of swap memory (in MiB) that a container can use.
The value for the size (in MiB) of the /dev/shm volume.
swappiness: i32Configures the container's memory swappiness behavior. Determines how aggressively pages are swapped. The higher the value, the more aggressive the swappiness. The default is 60.
tmpfs: Option<Vec<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails>>The container path, mount options, and size (in MiB) of the tmpfs mount.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails