Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails {
pub container_path: Option<String>,
pub read_only: bool,
pub source_volume: Option<String>,
}Expand description
A mount point for the data volumes in the container.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_path: Option<String>The path on the container to mount the host volume at.
read_only: boolWhether the container has read-only access to the volume.
source_volume: Option<String>The name of the volume to mount. Must match the name of a volume listed in VolumeDetails for the task definition.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails