#[non_exhaustive]pub struct AwsEcsTaskDefinitionDetails { /* private fields */ }Expand description
Details about a task definition. A task definition describes the container and volume definitions of an Amazon Elastic Container Service task.
Implementations
sourceimpl AwsEcsTaskDefinitionDetails
impl AwsEcsTaskDefinitionDetails
sourcepub fn container_definitions(
&self
) -> Option<&[AwsEcsTaskDefinitionContainerDefinitionsDetails]>
pub fn container_definitions(
&self
) -> Option<&[AwsEcsTaskDefinitionContainerDefinitionsDetails]>
The container definitions that describe the containers that make up the task.
sourcepub fn cpu(&self) -> Option<&str>
pub fn cpu(&self) -> Option<&str>
The number of CPU units used by the task.Valid values are as follows:
-
256 (.25 vCPU) -
512 (.5 vCPU) -
1024 (1 vCPU) -
2048 (2 vCPU) -
4096 (4 vCPU)
sourcepub fn execution_role_arn(&self) -> Option<&str>
pub fn execution_role_arn(&self) -> Option<&str>
The ARN of the task execution role that grants the container agent permission to make API calls on behalf of the container user.
sourcepub fn family(&self) -> Option<&str>
pub fn family(&self) -> Option<&str>
The name of a family that this task definition is registered to.
sourcepub fn inference_accelerators(
&self
) -> Option<&[AwsEcsTaskDefinitionInferenceAcceleratorsDetails]>
pub fn inference_accelerators(
&self
) -> Option<&[AwsEcsTaskDefinitionInferenceAcceleratorsDetails]>
The Elastic Inference accelerators to use for the containers in the task.
sourcepub fn ipc_mode(&self) -> Option<&str>
pub fn ipc_mode(&self) -> Option<&str>
The inter-process communication (IPC) resource namespace to use for the containers in the task. Valid values are as follows:
-
host -
none -
task
sourcepub fn memory(&self) -> Option<&str>
pub fn memory(&self) -> Option<&str>
The amount (in MiB) of memory used by the task.
For tasks that are hosted on Amazon EC2, you can provide a task-level memory value or a container-level memory value. For tasks that are hosted on Fargate, you must use one of the specified values in the Amazon Elastic Container Service Developer Guide , which determines your range of supported values for the Cpu and Memory parameters.
sourcepub fn network_mode(&self) -> Option<&str>
pub fn network_mode(&self) -> Option<&str>
The Docker networking mode to use for the containers in the task. Valid values are as follows:
-
awsvpc -
bridge -
host -
none
sourcepub fn pid_mode(&self) -> Option<&str>
pub fn pid_mode(&self) -> Option<&str>
The process namespace to use for the containers in the task. Valid values are host or task.
sourcepub fn placement_constraints(
&self
) -> Option<&[AwsEcsTaskDefinitionPlacementConstraintsDetails]>
pub fn placement_constraints(
&self
) -> Option<&[AwsEcsTaskDefinitionPlacementConstraintsDetails]>
The placement constraint objects to use for tasks.
sourcepub fn proxy_configuration(
&self
) -> Option<&AwsEcsTaskDefinitionProxyConfigurationDetails>
pub fn proxy_configuration(
&self
) -> Option<&AwsEcsTaskDefinitionProxyConfigurationDetails>
The configuration details for the App Mesh proxy.
sourcepub fn requires_compatibilities(&self) -> Option<&[String]>
pub fn requires_compatibilities(&self) -> Option<&[String]>
The task launch types that the task definition was validated against.
sourcepub fn task_role_arn(&self) -> Option<&str>
pub fn task_role_arn(&self) -> Option<&str>
The short name or ARN of the IAM role that grants containers in the task permission to call Amazon Web Services API operations on your behalf.
sourcepub fn volumes(&self) -> Option<&[AwsEcsTaskDefinitionVolumesDetails]>
pub fn volumes(&self) -> Option<&[AwsEcsTaskDefinitionVolumesDetails]>
The data volume definitions for the task.
sourceimpl AwsEcsTaskDefinitionDetails
impl AwsEcsTaskDefinitionDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionDetails.