Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionProxyConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionProxyConfigurationDetails {
pub container_name: Option<String>,
pub proxy_configuration_properties: Option<Vec<AwsEcsTaskDefinitionProxyConfigurationProxyConfigurationPropertiesDetails>>,
pub type: Option<String>,
}Expand description
The configuration details for the App Mesh proxy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_name: Option<String>The name of the container that will serve as the App Mesh proxy.
proxy_configuration_properties: Option<Vec<AwsEcsTaskDefinitionProxyConfigurationProxyConfigurationPropertiesDetails>>The set of network configuration parameters to provide to the Container Network Interface (CNI) plugin, specified as key-value pairs.
type: Option<String>The proxy type.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionProxyConfigurationDetails