Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails {
pub autoprovision: bool,
pub driver: Option<String>,
pub driver_opts: Option<HashMap<String, String>>,
pub labels: Option<HashMap<String, String>>,
pub scope: Option<String>,
}Expand description
Information about a Docker volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autoprovision: boolWhether to create the Docker volume automatically if it does not already exist.
driver: Option<String>The Docker volume driver to use.
driver_opts: Option<HashMap<String, String>>A map of Docker driver-specific options that are passed through.
labels: Option<HashMap<String, String>>Custom metadata to add to the Docker volume.
scope: Option<String>The scope for the Docker volume that determines its lifecycle. Docker volumes that are scoped to a task are provisioned automatically when the task starts and destroyed when the task stops. Docker volumes that are shared persist after the task stops.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails