Struct aws_sdk_securityhub::model::AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetails {
pub authorization_config: Option<AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationAuthorizationConfigDetails>,
pub filesystem_id: Option<String>,
pub root_directory: Option<String>,
pub transit_encryption: Option<String>,
pub transit_encryption_port: i32,
}Expand description
Information about the Amazon Elastic File System file system that is used for task storage.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The authorization configuration details for the Amazon EFS file system.
filesystem_id: Option<String>The Amazon EFS file system identifier to use.
root_directory: Option<String>The directory within the Amazon EFS file system to mount as the root directory inside the host.
transit_encryption: Option<String>Whether to enable encryption for Amazon EFS data in transit between the Amazon ECS host and the Amazon EFS server.
transit_encryption_port: i32The port to use when sending encrypted data between the Amazon ECS host and the Amazon EFS server.
Implementations
Creates a new builder-style object to manufacture AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetails