#[non_exhaustive]pub struct AwsEcsTaskVolumeHostDetails { /* private fields */ }Expand description
Provides details on a container instance bind mount host volume.
Implementations
sourceimpl AwsEcsTaskVolumeHostDetails
impl AwsEcsTaskVolumeHostDetails
sourcepub fn source_path(&self) -> Option<&str>
pub fn source_path(&self) -> Option<&str>
When the host parameter is used, specify a sourcePath to declare the path on the host container instance that's presented to the container.
sourceimpl AwsEcsTaskVolumeHostDetails
impl AwsEcsTaskVolumeHostDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEcsTaskVolumeHostDetails.