Struct aws_sdk_securityhub::model::AwsElasticBeanstalkEnvironmentDetails [−][src]
#[non_exhaustive]pub struct AwsElasticBeanstalkEnvironmentDetails {Show 16 fields
pub application_name: Option<String>,
pub cname: Option<String>,
pub date_created: Option<String>,
pub date_updated: Option<String>,
pub description: Option<String>,
pub endpoint_url: Option<String>,
pub environment_arn: Option<String>,
pub environment_id: Option<String>,
pub environment_links: Option<Vec<AwsElasticBeanstalkEnvironmentEnvironmentLink>>,
pub environment_name: Option<String>,
pub option_settings: Option<Vec<AwsElasticBeanstalkEnvironmentOptionSetting>>,
pub platform_arn: Option<String>,
pub solution_stack_name: Option<String>,
pub status: Option<String>,
pub tier: Option<AwsElasticBeanstalkEnvironmentTier>,
pub version_label: Option<String>,
}Expand description
Contains details about an Elastic Beanstalk environment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_name: Option<String>The name of the application that is associated with the environment.
cname: Option<String>The URL to the CNAME for this environment.
date_created: Option<String>The creation date for this environment.
date_updated: Option<String>The date when this environment was last modified.
description: Option<String>A description of the environment.
endpoint_url: Option<String>For load-balanced, autoscaling environments, the URL to the load balancer. For single-instance environments, the IP address of the instance.
environment_arn: Option<String>The ARN of the environment.
environment_id: Option<String>The identifier of the environment.
environment_links: Option<Vec<AwsElasticBeanstalkEnvironmentEnvironmentLink>>Links to other environments in the same group.
environment_name: Option<String>The name of the environment.
option_settings: Option<Vec<AwsElasticBeanstalkEnvironmentOptionSetting>>The configuration setting for the environment.
platform_arn: Option<String>The ARN of the platform version for the environment.
solution_stack_name: Option<String>The name of the solution stack that is deployed with the environment.
status: Option<String>The current operational status of the environment.
tier: Option<AwsElasticBeanstalkEnvironmentTier>The tier of the environment.
version_label: Option<String>The application version of the environment.
Implementations
Creates a new builder-style object to manufacture AwsElasticBeanstalkEnvironmentDetails