#[non_exhaustive]pub struct AwsElasticsearchDomainDetails { /* private fields */ }Expand description
Information about an Elasticsearch domain.
Implementations
sourceimpl AwsElasticsearchDomainDetails
impl AwsElasticsearchDomainDetails
sourcepub fn access_policies(&self) -> Option<&str>
pub fn access_policies(&self) -> Option<&str>
IAM policy document specifying the access policies for the new Elasticsearch domain.
sourcepub fn domain_endpoint_options(
&self
) -> Option<&AwsElasticsearchDomainDomainEndpointOptions>
pub fn domain_endpoint_options(
&self
) -> Option<&AwsElasticsearchDomainDomainEndpointOptions>
Additional options for the domain endpoint.
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
Name of an Elasticsearch domain.
Domain names are unique across all domains owned by the same account within an Amazon Web Services Region.
Domain names must start with a lowercase letter and must be between 3 and 28 characters.
Valid characters are a-z (lowercase only), 0-9, and – (hyphen).
sourcepub fn endpoint(&self) -> Option<&str>
pub fn endpoint(&self) -> Option<&str>
Domain-specific endpoint used to submit index, search, and data upload requests to an Elasticsearch domain.
The endpoint is a service URL.
sourcepub fn endpoints(&self) -> Option<&HashMap<String, String>>
pub fn endpoints(&self) -> Option<&HashMap<String, String>>
The key-value pair that exists if the Elasticsearch domain uses VPC endpoints.
sourcepub fn elasticsearch_version(&self) -> Option<&str>
pub fn elasticsearch_version(&self) -> Option<&str>
OpenSearch version.
sourcepub fn elasticsearch_cluster_config(
&self
) -> Option<&AwsElasticsearchDomainElasticsearchClusterConfigDetails>
pub fn elasticsearch_cluster_config(
&self
) -> Option<&AwsElasticsearchDomainElasticsearchClusterConfigDetails>
Information about an OpenSearch cluster configuration.
sourcepub fn encryption_at_rest_options(
&self
) -> Option<&AwsElasticsearchDomainEncryptionAtRestOptions>
pub fn encryption_at_rest_options(
&self
) -> Option<&AwsElasticsearchDomainEncryptionAtRestOptions>
Details about the configuration for encryption at rest.
sourcepub fn log_publishing_options(
&self
) -> Option<&AwsElasticsearchDomainLogPublishingOptions>
pub fn log_publishing_options(
&self
) -> Option<&AwsElasticsearchDomainLogPublishingOptions>
Configures the CloudWatch Logs to publish for the Elasticsearch domain.
sourcepub fn node_to_node_encryption_options(
&self
) -> Option<&AwsElasticsearchDomainNodeToNodeEncryptionOptions>
pub fn node_to_node_encryption_options(
&self
) -> Option<&AwsElasticsearchDomainNodeToNodeEncryptionOptions>
Details about the configuration for node-to-node encryption.
sourcepub fn service_software_options(
&self
) -> Option<&AwsElasticsearchDomainServiceSoftwareOptions>
pub fn service_software_options(
&self
) -> Option<&AwsElasticsearchDomainServiceSoftwareOptions>
Information about the status of a domain relative to the latest service software.
sourcepub fn vpc_options(&self) -> Option<&AwsElasticsearchDomainVpcOptions>
pub fn vpc_options(&self) -> Option<&AwsElasticsearchDomainVpcOptions>
Information that OpenSearch derives based on VPCOptions for the domain.
sourceimpl AwsElasticsearchDomainDetails
impl AwsElasticsearchDomainDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElasticsearchDomainDetails.