#[non_exhaustive]pub struct AwsElasticsearchDomainDomainEndpointOptions { /* private fields */ }Expand description
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
Implementations
sourceimpl AwsElasticsearchDomainDomainEndpointOptions
impl AwsElasticsearchDomainDomainEndpointOptions
sourcepub fn enforce_https(&self) -> bool
pub fn enforce_https(&self) -> bool
Whether to require that all traffic to the domain arrive over HTTPS.
sourcepub fn tls_security_policy(&self) -> Option<&str>
pub fn tls_security_policy(&self) -> Option<&str>
The TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.
Valid values:
-
Policy-Min-TLS-1-0-2019-07, which supports TLSv1.0 and higher -
Policy-Min-TLS-1-2-2019-07, which only supports TLSv1.2
sourceimpl AwsElasticsearchDomainDomainEndpointOptions
impl AwsElasticsearchDomainDomainEndpointOptions
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElasticsearchDomainDomainEndpointOptions.