#[non_exhaustive]pub struct AwsElasticsearchDomainServiceSoftwareOptions { /* private fields */ }Expand description
Information about the state of the domain relative to the latest service software.
Implementations
sourceimpl AwsElasticsearchDomainServiceSoftwareOptions
impl AwsElasticsearchDomainServiceSoftwareOptions
sourcepub fn automated_update_date(&self) -> Option<&str>
pub fn automated_update_date(&self) -> Option<&str>
The epoch time when the deployment window closes for required updates. After this time, Amazon OpenSearch Service schedules the software upgrade automatically.
sourcepub fn cancellable(&self) -> bool
pub fn cancellable(&self) -> bool
Whether a request to update the domain can be canceled.
sourcepub fn current_version(&self) -> Option<&str>
pub fn current_version(&self) -> Option<&str>
The version of the service software that is currently installed on the domain.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A more detailed description of the service software status.
sourcepub fn new_version(&self) -> Option<&str>
pub fn new_version(&self) -> Option<&str>
The most recent version of the service software.
sourcepub fn update_available(&self) -> bool
pub fn update_available(&self) -> bool
Whether a service software update is available for the domain.
sourcepub fn update_status(&self) -> Option<&str>
pub fn update_status(&self) -> Option<&str>
The status of the service software update. Valid values are as follows:
-
COMPLETED -
ELIGIBLE -
IN_PROGRESS -
NOT_ELIGIBLE -
PENDING_UPDATE
sourceimpl AwsElasticsearchDomainServiceSoftwareOptions
impl AwsElasticsearchDomainServiceSoftwareOptions
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElasticsearchDomainServiceSoftwareOptions.