Struct aws_sdk_securityhub::model::AwsElbAppCookieStickinessPolicy [−][src]
#[non_exhaustive]pub struct AwsElbAppCookieStickinessPolicy {
pub cookie_name: Option<String>,
pub policy_name: Option<String>,
}Expand description
Contains information about a stickiness policy that was created using
CreateAppCookieStickinessPolicy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The name of the application cookie used for stickiness.
policy_name: Option<String>The mnemonic name for the policy being created. The name must be unique within the set of policies for the load balancer.
Implementations
The name of the application cookie used for stickiness.
The mnemonic name for the policy being created. The name must be unique within the set of policies for the load balancer.
Creates a new builder-style object to manufacture AwsElbAppCookieStickinessPolicy