#[non_exhaustive]pub struct AwsElbLoadBalancerAttributes { /* private fields */ }Expand description
Contains attributes for the load balancer.
Implementations
sourceimpl AwsElbLoadBalancerAttributes
impl AwsElbLoadBalancerAttributes
sourcepub fn access_log(&self) -> Option<&AwsElbLoadBalancerAccessLog>
pub fn access_log(&self) -> Option<&AwsElbLoadBalancerAccessLog>
Information about the access log configuration for the load balancer.
If the access log is enabled, the load balancer captures detailed information about all requests. It delivers the information to a specified S3 bucket.
sourcepub fn connection_draining(
&self
) -> Option<&AwsElbLoadBalancerConnectionDraining>
pub fn connection_draining(
&self
) -> Option<&AwsElbLoadBalancerConnectionDraining>
Information about the connection draining configuration for the load balancer.
If connection draining is enabled, the load balancer allows existing requests to complete before it shifts traffic away from a deregistered or unhealthy instance.
sourcepub fn connection_settings(
&self
) -> Option<&AwsElbLoadBalancerConnectionSettings>
pub fn connection_settings(
&self
) -> Option<&AwsElbLoadBalancerConnectionSettings>
Connection settings for the load balancer.
If an idle timeout is configured, the load balancer allows connections to remain idle for the specified duration. When a connection is idle, no data is sent over the connection.
sourcepub fn cross_zone_load_balancing(
&self
) -> Option<&AwsElbLoadBalancerCrossZoneLoadBalancing>
pub fn cross_zone_load_balancing(
&self
) -> Option<&AwsElbLoadBalancerCrossZoneLoadBalancing>
Cross-zone load balancing settings for the load balancer.
If cross-zone load balancing is enabled, the load balancer routes the request traffic evenly across all instances regardless of the Availability Zones.
sourcepub fn additional_attributes(
&self
) -> Option<&[AwsElbLoadBalancerAdditionalAttribute]>
pub fn additional_attributes(
&self
) -> Option<&[AwsElbLoadBalancerAdditionalAttribute]>
Any additional attributes for a load balancer.
sourceimpl AwsElbLoadBalancerAttributes
impl AwsElbLoadBalancerAttributes
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElbLoadBalancerAttributes.