#[non_exhaustive]pub struct AwsElbLoadBalancerDetails { /* private fields */ }Expand description
Contains details about a Classic Load Balancer.
Implementations
sourceimpl AwsElbLoadBalancerDetails
impl AwsElbLoadBalancerDetails
sourcepub fn availability_zones(&self) -> Option<&[String]>
pub fn availability_zones(&self) -> Option<&[String]>
The list of Availability Zones for the load balancer.
sourcepub fn backend_server_descriptions(
&self
) -> Option<&[AwsElbLoadBalancerBackendServerDescription]>
pub fn backend_server_descriptions(
&self
) -> Option<&[AwsElbLoadBalancerBackendServerDescription]>
Information about the configuration of the EC2 instances.
sourcepub fn canonical_hosted_zone_name(&self) -> Option<&str>
pub fn canonical_hosted_zone_name(&self) -> Option<&str>
The name of the Amazon Route 53 hosted zone for the load balancer.
sourcepub fn canonical_hosted_zone_name_id(&self) -> Option<&str>
pub fn canonical_hosted_zone_name_id(&self) -> Option<&str>
The ID of the Amazon Route 53 hosted zone for the load balancer.
sourcepub fn created_time(&self) -> Option<&str>
pub fn created_time(&self) -> Option<&str>
Indicates when the load balancer was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn health_check(&self) -> Option<&AwsElbLoadBalancerHealthCheck>
pub fn health_check(&self) -> Option<&AwsElbLoadBalancerHealthCheck>
Information about the health checks that are conducted on the load balancer.
sourcepub fn instances(&self) -> Option<&[AwsElbLoadBalancerInstance]>
pub fn instances(&self) -> Option<&[AwsElbLoadBalancerInstance]>
List of EC2 instances for the load balancer.
sourcepub fn listener_descriptions(
&self
) -> Option<&[AwsElbLoadBalancerListenerDescription]>
pub fn listener_descriptions(
&self
) -> Option<&[AwsElbLoadBalancerListenerDescription]>
The policies that are enabled for the load balancer listeners.
sourcepub fn load_balancer_attributes(&self) -> Option<&AwsElbLoadBalancerAttributes>
pub fn load_balancer_attributes(&self) -> Option<&AwsElbLoadBalancerAttributes>
The attributes for a load balancer.
sourcepub fn load_balancer_name(&self) -> Option<&str>
pub fn load_balancer_name(&self) -> Option<&str>
The name of the load balancer.
sourcepub fn policies(&self) -> Option<&AwsElbLoadBalancerPolicies>
pub fn policies(&self) -> Option<&AwsElbLoadBalancerPolicies>
The policies for a load balancer.
sourcepub fn scheme(&self) -> Option<&str>
pub fn scheme(&self) -> Option<&str>
The type of load balancer. Only provided if the load balancer is in a VPC.
If Scheme is internet-facing, the load balancer has a public DNS name that resolves to a public IP address.
If Scheme is internal, the load balancer has a public DNS name that resolves to a private IP address.
sourcepub fn security_groups(&self) -> Option<&[String]>
pub fn security_groups(&self) -> Option<&[String]>
The security groups for the load balancer. Only provided if the load balancer is in a VPC.
sourcepub fn source_security_group(
&self
) -> Option<&AwsElbLoadBalancerSourceSecurityGroup>
pub fn source_security_group(
&self
) -> Option<&AwsElbLoadBalancerSourceSecurityGroup>
Information about the security group for the load balancer. This is the security group that is used for inbound rules.
sourceimpl AwsElbLoadBalancerDetails
impl AwsElbLoadBalancerDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElbLoadBalancerDetails.