#[non_exhaustive]pub struct AwsElbLoadBalancerHealthCheck { /* private fields */ }Expand description
Contains information about the health checks that are conducted on the load balancer.
Implementations
sourceimpl AwsElbLoadBalancerHealthCheck
impl AwsElbLoadBalancerHealthCheck
sourcepub fn healthy_threshold(&self) -> i32
pub fn healthy_threshold(&self) -> i32
The number of consecutive health check successes required before the instance is moved to the Healthy state.
sourcepub fn interval(&self) -> i32
pub fn interval(&self) -> i32
The approximate interval, in seconds, between health checks of an individual instance.
sourcepub fn target(&self) -> Option<&str>
pub fn target(&self) -> Option<&str>
The instance that is being checked. The target specifies the protocol and port. The available protocols are TCP, SSL, HTTP, and HTTPS. The range of valid ports is 1 through 65535.
For the HTTP and HTTPS protocols, the target also specifies the ping path.
For the TCP protocol, the target is specified as TCP:
.
For the SSL protocol, the target is specified as SSL.
.
For the HTTP and HTTPS protocols, the target is specified as
.
sourcepub fn timeout(&self) -> i32
pub fn timeout(&self) -> i32
The amount of time, in seconds, during which no response means a failed health check.
sourcepub fn unhealthy_threshold(&self) -> i32
pub fn unhealthy_threshold(&self) -> i32
The number of consecutive health check failures that must occur before the instance is moved to the Unhealthy state.
sourceimpl AwsElbLoadBalancerHealthCheck
impl AwsElbLoadBalancerHealthCheck
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElbLoadBalancerHealthCheck.