#[non_exhaustive]
pub struct AwsElbv2LoadBalancerDetails { /* private fields */ }
Information about a load balancer.

Implementations

The Availability Zones for the load balancer.

The ID of the Amazon Route 53 hosted zone associated with the load balancer.

Indicates when the load balancer was created.

Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.

The public DNS name of the load balancer.

The type of IP addresses used by the subnets for your load balancer. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses).

The nodes of an Internet-facing load balancer have public IP addresses.

The IDs of the security groups for the load balancer.

The state of the load balancer.

The type of load balancer.

The ID of the VPC for the load balancer.

Attributes of the load balancer.

Creates a new builder-style object to manufacture AwsElbv2LoadBalancerDetails.