Struct aws_sdk_securityhub::model::AwsIamAccessKeyDetails
source · [−]#[non_exhaustive]pub struct AwsIamAccessKeyDetails { /* private fields */ }Expand description
IAM access key details related to a finding.
Implementations
sourceimpl AwsIamAccessKeyDetails
impl AwsIamAccessKeyDetails
sourcepub fn user_name(&self) -> Option<&str>
👎Deprecated: This filter is deprecated. Instead, use PrincipalName.
pub fn user_name(&self) -> Option<&str>
This filter is deprecated. Instead, use PrincipalName.
The user associated with the IAM access key related to a finding.
The UserName parameter has been replaced with the PrincipalName parameter because access keys can also be assigned to principals that are not IAM users.
sourcepub fn status(&self) -> Option<&AwsIamAccessKeyStatus>
pub fn status(&self) -> Option<&AwsIamAccessKeyStatus>
The status of the IAM access key related to a finding.
sourcepub fn created_at(&self) -> Option<&str>
pub fn created_at(&self) -> Option<&str>
Indicates when the IAM access key was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn principal_id(&self) -> Option<&str>
pub fn principal_id(&self) -> Option<&str>
The ID of the principal associated with an access key.
sourcepub fn principal_type(&self) -> Option<&str>
pub fn principal_type(&self) -> Option<&str>
The type of principal associated with an access key.
sourcepub fn principal_name(&self) -> Option<&str>
pub fn principal_name(&self) -> Option<&str>
The name of the principal.
sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The Amazon Web Services account ID of the account for the key.
sourcepub fn access_key_id(&self) -> Option<&str>
pub fn access_key_id(&self) -> Option<&str>
The identifier of the access key.
sourcepub fn session_context(&self) -> Option<&AwsIamAccessKeySessionContext>
pub fn session_context(&self) -> Option<&AwsIamAccessKeySessionContext>
Information about the session that the key was used for.
sourceimpl AwsIamAccessKeyDetails
impl AwsIamAccessKeyDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsIamAccessKeyDetails.