Struct aws_sdk_securityhub::model::AwsIamAccessKeySessionContextSessionIssuer [−][src]
#[non_exhaustive]pub struct AwsIamAccessKeySessionContextSessionIssuer {
pub type: Option<String>,
pub principal_id: Option<String>,
pub arn: Option<String>,
pub account_id: Option<String>,
pub user_name: Option<String>,
}Expand description
Information about the entity that created the session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<String>The type of principal (user, role, or group) that created the session.
principal_id: Option<String>The principal ID of the principal (user, role, or group) that created the session.
arn: Option<String>The ARN of the session.
account_id: Option<String>The identifier of the Amazon Web Services account that created the session.
user_name: Option<String>The name of the principal that created the session.
Implementations
Creates a new builder-style object to manufacture AwsIamAccessKeySessionContextSessionIssuer