Struct aws_sdk_securityhub::model::AwsIamGroupDetails
source · [−]#[non_exhaustive]pub struct AwsIamGroupDetails { /* private fields */ }Expand description
Contains details about an IAM group.
Implementations
sourceimpl AwsIamGroupDetails
impl AwsIamGroupDetails
sourcepub fn attached_managed_policies(
&self
) -> Option<&[AwsIamAttachedManagedPolicy]>
pub fn attached_managed_policies(
&self
) -> Option<&[AwsIamAttachedManagedPolicy]>
A list of the managed policies that are attached to the IAM group.
sourcepub fn create_date(&self) -> Option<&str>
pub fn create_date(&self) -> Option<&str>
Indicates when the IAM group was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn group_name(&self) -> Option<&str>
pub fn group_name(&self) -> Option<&str>
The name of the IAM group.
sourcepub fn group_policy_list(&self) -> Option<&[AwsIamGroupPolicy]>
pub fn group_policy_list(&self) -> Option<&[AwsIamGroupPolicy]>
The list of inline policies that are embedded in the group.
sourceimpl AwsIamGroupDetails
impl AwsIamGroupDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsIamGroupDetails.