#[non_exhaustive]pub struct AwsIamInstanceProfileRole { /* private fields */ }Expand description
Information about a role associated with an instance profile.
Implementations
sourceimpl AwsIamInstanceProfileRole
impl AwsIamInstanceProfileRole
sourcepub fn assume_role_policy_document(&self) -> Option<&str>
pub fn assume_role_policy_document(&self) -> Option<&str>
The policy that grants an entity permission to assume the role.
sourcepub fn create_date(&self) -> Option<&str>
pub fn create_date(&self) -> Option<&str>
Indicates when the role was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourceimpl AwsIamInstanceProfileRole
impl AwsIamInstanceProfileRole
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsIamInstanceProfileRole.