#[non_exhaustive]pub struct AwsLambdaFunctionDetails { /* private fields */ }Expand description
Details about a function's configuration.
Implementations
sourceimpl AwsLambdaFunctionDetails
impl AwsLambdaFunctionDetails
sourcepub fn code(&self) -> Option<&AwsLambdaFunctionCode>
pub fn code(&self) -> Option<&AwsLambdaFunctionCode>
An AwsLambdaFunctionCode object.
sourcepub fn code_sha256(&self) -> Option<&str>
pub fn code_sha256(&self) -> Option<&str>
The SHA256 hash of the function's deployment package.
sourcepub fn dead_letter_config(&self) -> Option<&AwsLambdaFunctionDeadLetterConfig>
pub fn dead_letter_config(&self) -> Option<&AwsLambdaFunctionDeadLetterConfig>
The function's dead letter queue.
sourcepub fn environment(&self) -> Option<&AwsLambdaFunctionEnvironment>
pub fn environment(&self) -> Option<&AwsLambdaFunctionEnvironment>
The function's environment variables.
sourcepub fn function_name(&self) -> Option<&str>
pub fn function_name(&self) -> Option<&str>
The name of the function.
sourcepub fn handler(&self) -> Option<&str>
pub fn handler(&self) -> Option<&str>
The function that Lambda calls to begin executing your function.
sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The KMS key that is used to encrypt the function's environment variables. This key is only returned if you've configured a customer managed customer managed key.
sourcepub fn last_modified(&self) -> Option<&str>
pub fn last_modified(&self) -> Option<&str>
Indicates when the function was last updated.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn layers(&self) -> Option<&[AwsLambdaFunctionLayer]>
pub fn layers(&self) -> Option<&[AwsLambdaFunctionLayer]>
The function's layers.
sourcepub fn master_arn(&self) -> Option<&str>
pub fn master_arn(&self) -> Option<&str>
For Lambda@Edge functions, the ARN of the master function.
sourcepub fn memory_size(&self) -> i32
pub fn memory_size(&self) -> i32
The memory that is allocated to the function.
sourcepub fn revision_id(&self) -> Option<&str>
pub fn revision_id(&self) -> Option<&str>
The latest updated revision of the function or alias.
sourcepub fn timeout(&self) -> i32
pub fn timeout(&self) -> i32
The amount of time that Lambda allows a function to run before stopping it.
sourcepub fn tracing_config(&self) -> Option<&AwsLambdaFunctionTracingConfig>
pub fn tracing_config(&self) -> Option<&AwsLambdaFunctionTracingConfig>
The function's X-Ray tracing configuration.
sourcepub fn vpc_config(&self) -> Option<&AwsLambdaFunctionVpcConfig>
pub fn vpc_config(&self) -> Option<&AwsLambdaFunctionVpcConfig>
The function's networking configuration.
sourceimpl AwsLambdaFunctionDetails
impl AwsLambdaFunctionDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsLambdaFunctionDetails.