Struct aws_sdk_securityhub::model::AwsMountPoint
source · [−]#[non_exhaustive]pub struct AwsMountPoint { /* private fields */ }Expand description
Details for a volume mount point that's used in a container definition.
Implementations
sourceimpl AwsMountPoint
impl AwsMountPoint
sourcepub fn source_volume(&self) -> Option<&str>
pub fn source_volume(&self) -> Option<&str>
The name of the volume to mount. Must be a volume name referenced in the name parameter of task definition volume.
sourcepub fn container_path(&self) -> Option<&str>
pub fn container_path(&self) -> Option<&str>
The path on the container to mount the host volume at.
sourceimpl AwsMountPoint
impl AwsMountPoint
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsMountPoint.