#[non_exhaustive]pub struct AwsNetworkFirewallFirewallDetails { /* private fields */ }Expand description
Details about an Network Firewall firewall.
Implementations
sourceimpl AwsNetworkFirewallFirewallDetails
impl AwsNetworkFirewallFirewallDetails
sourcepub fn delete_protection(&self) -> bool
pub fn delete_protection(&self) -> bool
Whether the firewall is protected from deletion. If set to true, then the firewall cannot be deleted.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the firewall.
sourcepub fn firewall_arn(&self) -> Option<&str>
pub fn firewall_arn(&self) -> Option<&str>
The ARN of the firewall.
sourcepub fn firewall_id(&self) -> Option<&str>
pub fn firewall_id(&self) -> Option<&str>
The identifier of the firewall.
sourcepub fn firewall_name(&self) -> Option<&str>
pub fn firewall_name(&self) -> Option<&str>
A descriptive name of the firewall.
sourcepub fn firewall_policy_arn(&self) -> Option<&str>
pub fn firewall_policy_arn(&self) -> Option<&str>
The ARN of the firewall policy.
sourcepub fn firewall_policy_change_protection(&self) -> bool
pub fn firewall_policy_change_protection(&self) -> bool
Whether the firewall is protected from a change to the firewall policy. If set to true, you cannot associate a different policy with the firewall.
sourcepub fn subnet_change_protection(&self) -> bool
pub fn subnet_change_protection(&self) -> bool
Whether the firewall is protected from a change to the subnet associations. If set to true, you cannot map different subnets to the firewall.
sourcepub fn subnet_mappings(
&self
) -> Option<&[AwsNetworkFirewallFirewallSubnetMappingsDetails]>
pub fn subnet_mappings(
&self
) -> Option<&[AwsNetworkFirewallFirewallSubnetMappingsDetails]>
The public subnets that Network Firewall uses for the firewall. Each subnet must belong to a different Availability Zone.
sourceimpl AwsNetworkFirewallFirewallDetails
impl AwsNetworkFirewallFirewallDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsNetworkFirewallFirewallDetails.