#[non_exhaustive]pub struct AwsOpenSearchServiceDomainDetails { /* private fields */ }Expand description
Information about an Amazon OpenSearch Service domain.
Implementations
sourceimpl AwsOpenSearchServiceDomainDetails
impl AwsOpenSearchServiceDomainDetails
sourcepub fn access_policies(&self) -> Option<&str>
pub fn access_policies(&self) -> Option<&str>
IAM policy document that specifies the access policies for the OpenSearch Service domain.
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The name of the endpoint.
sourcepub fn domain_endpoint(&self) -> Option<&str>
pub fn domain_endpoint(&self) -> Option<&str>
The domain endpoint.
sourcepub fn engine_version(&self) -> Option<&str>
pub fn engine_version(&self) -> Option<&str>
The version of the domain engine.
sourcepub fn encryption_at_rest_options(
&self
) -> Option<&AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetails>
pub fn encryption_at_rest_options(
&self
) -> Option<&AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetails>
Details about the configuration for encryption at rest.
sourcepub fn node_to_node_encryption_options(
&self
) -> Option<&AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetails>
pub fn node_to_node_encryption_options(
&self
) -> Option<&AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetails>
Details about the configuration for node-to-node encryption.
sourcepub fn service_software_options(
&self
) -> Option<&AwsOpenSearchServiceDomainServiceSoftwareOptionsDetails>
pub fn service_software_options(
&self
) -> Option<&AwsOpenSearchServiceDomainServiceSoftwareOptionsDetails>
Information about the status of a domain relative to the latest service software.
sourcepub fn cluster_config(
&self
) -> Option<&AwsOpenSearchServiceDomainClusterConfigDetails>
pub fn cluster_config(
&self
) -> Option<&AwsOpenSearchServiceDomainClusterConfigDetails>
Details about the configuration of an OpenSearch cluster.
sourcepub fn domain_endpoint_options(
&self
) -> Option<&AwsOpenSearchServiceDomainDomainEndpointOptionsDetails>
pub fn domain_endpoint_options(
&self
) -> Option<&AwsOpenSearchServiceDomainDomainEndpointOptionsDetails>
Additional options for the domain endpoint.
sourcepub fn vpc_options(
&self
) -> Option<&AwsOpenSearchServiceDomainVpcOptionsDetails>
pub fn vpc_options(
&self
) -> Option<&AwsOpenSearchServiceDomainVpcOptionsDetails>
Information that OpenSearch Service derives based on VPCOptions for the domain.
sourcepub fn log_publishing_options(
&self
) -> Option<&AwsOpenSearchServiceDomainLogPublishingOptionsDetails>
pub fn log_publishing_options(
&self
) -> Option<&AwsOpenSearchServiceDomainLogPublishingOptionsDetails>
Configures the CloudWatch Logs to publish for the OpenSearch domain.
sourcepub fn domain_endpoints(&self) -> Option<&HashMap<String, String>>
pub fn domain_endpoints(&self) -> Option<&HashMap<String, String>>
The domain endpoints. Used if the OpenSearch domain resides in a VPC.
This is a map of key-value pairs. The key is always vpc. The value is the endpoint.
sourcepub fn advanced_security_options(
&self
) -> Option<&AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails>
pub fn advanced_security_options(
&self
) -> Option<&AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails>
Specifies options for fine-grained access control.
sourceimpl AwsOpenSearchServiceDomainDetails
impl AwsOpenSearchServiceDomainDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsOpenSearchServiceDomainDetails.