Struct aws_sdk_securityhub::model::AwsOpenSearchServiceDomainDomainEndpointOptionsDetails [−][src]
#[non_exhaustive]pub struct AwsOpenSearchServiceDomainDomainEndpointOptionsDetails {
pub custom_endpoint_certificate_arn: Option<String>,
pub custom_endpoint_enabled: bool,
pub enforce_https: bool,
pub custom_endpoint: Option<String>,
pub tls_security_policy: Option<String>,
}Expand description
Information about additional options for the domain endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.custom_endpoint_certificate_arn: Option<String>The ARN for the security certificate. The certificate is managed in ACM.
custom_endpoint_enabled: boolWhether to enable a custom endpoint for the domain.
enforce_https: boolWhether to require that all traffic to the domain arrive over HTTPS.
custom_endpoint: Option<String>The fully qualified URL for the custom endpoint.
tls_security_policy: Option<String>The TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.
Implementations
Creates a new builder-style object to manufacture AwsOpenSearchServiceDomainDomainEndpointOptionsDetails