Struct aws_sdk_securityhub::model::AwsRdsDbClusterDetails
source · [−]#[non_exhaustive]pub struct AwsRdsDbClusterDetails { /* private fields */ }Expand description
Information about an Amazon RDS DB cluster.
Implementations
sourceimpl AwsRdsDbClusterDetails
impl AwsRdsDbClusterDetails
sourcepub fn allocated_storage(&self) -> i32
pub fn allocated_storage(&self) -> i32
For all database engines except Aurora, specifies the allocated storage size in gibibytes (GiB).
sourcepub fn availability_zones(&self) -> Option<&[String]>
pub fn availability_zones(&self) -> Option<&[String]>
A list of Availability Zones (AZs) where instances in the DB cluster can be created.
sourcepub fn backup_retention_period(&self) -> i32
pub fn backup_retention_period(&self) -> i32
The number of days for which automated backups are retained.
sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database.
sourcepub fn endpoint(&self) -> Option<&str>
pub fn endpoint(&self) -> Option<&str>
The connection endpoint for the primary instance of the DB cluster.
sourcepub fn reader_endpoint(&self) -> Option<&str>
pub fn reader_endpoint(&self) -> Option<&str>
The reader endpoint for the DB cluster.
sourcepub fn custom_endpoints(&self) -> Option<&[String]>
pub fn custom_endpoints(&self) -> Option<&[String]>
A list of custom endpoints for the DB cluster.
sourcepub fn multi_az(&self) -> bool
pub fn multi_az(&self) -> bool
Whether the DB cluster has instances in multiple Availability Zones.
sourcepub fn engine(&self) -> Option<&str>
pub fn engine(&self) -> Option<&str>
The name of the database engine to use for this DB cluster. Valid values are as follows:
-
aurora -
aurora-mysql -
aurora-postgresql
sourcepub fn engine_version(&self) -> Option<&str>
pub fn engine_version(&self) -> Option<&str>
The version number of the database engine to use.
sourcepub fn port(&self) -> i32
pub fn port(&self) -> i32
The port number on which the DB instances in the DB cluster accept connections.
sourcepub fn master_username(&self) -> Option<&str>
pub fn master_username(&self) -> Option<&str>
The name of the master user for the DB cluster.
sourcepub fn preferred_backup_window(&self) -> Option<&str>
pub fn preferred_backup_window(&self) -> Option<&str>
The range of time each day when automated backups are created, if automated backups are enabled.
Uses the format HH:MM-HH:MM. For example, 04:52-05:22.
sourcepub fn preferred_maintenance_window(&self) -> Option<&str>
pub fn preferred_maintenance_window(&self) -> Option<&str>
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
Uses the format
.
For the day values, use mon|tue|wed|thu|fri|sat|sun.
For example, sun:09:32-sun:10:02.
sourcepub fn read_replica_identifiers(&self) -> Option<&[String]>
pub fn read_replica_identifiers(&self) -> Option<&[String]>
The identifiers of the read replicas that are associated with this DB cluster.
sourcepub fn vpc_security_groups(&self) -> Option<&[AwsRdsDbInstanceVpcSecurityGroup]>
pub fn vpc_security_groups(&self) -> Option<&[AwsRdsDbInstanceVpcSecurityGroup]>
A list of VPC security groups that the DB cluster belongs to.
sourcepub fn hosted_zone_id(&self) -> Option<&str>
pub fn hosted_zone_id(&self) -> Option<&str>
Specifies the identifier that Amazon Route 53 assigns when you create a hosted zone.
sourcepub fn storage_encrypted(&self) -> bool
pub fn storage_encrypted(&self) -> bool
Whether the DB cluster is encrypted.
sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of the KMS master key that is used to encrypt the database instances in the DB cluster.
sourcepub fn db_cluster_resource_id(&self) -> Option<&str>
pub fn db_cluster_resource_id(&self) -> Option<&str>
The identifier of the DB cluster. The identifier must be unique within each Amazon Web Services Region and is immutable.
sourcepub fn associated_roles(&self) -> Option<&[AwsRdsDbClusterAssociatedRole]>
pub fn associated_roles(&self) -> Option<&[AwsRdsDbClusterAssociatedRole]>
A list of the IAM roles that are associated with the DB cluster.
sourcepub fn cluster_create_time(&self) -> Option<&str>
pub fn cluster_create_time(&self) -> Option<&str>
Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn enabled_cloud_watch_logs_exports(&self) -> Option<&[String]>
pub fn enabled_cloud_watch_logs_exports(&self) -> Option<&[String]>
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
sourcepub fn engine_mode(&self) -> Option<&str>
pub fn engine_mode(&self) -> Option<&str>
The database engine mode of the DB cluster.Valid values are as follows:
-
global -
multimaster -
parallelquery -
provisioned -
serverless
sourcepub fn deletion_protection(&self) -> bool
pub fn deletion_protection(&self) -> bool
Whether the DB cluster has deletion protection enabled.
sourcepub fn http_endpoint_enabled(&self) -> bool
pub fn http_endpoint_enabled(&self) -> bool
Whether the HTTP endpoint for an Aurora Serverless DB cluster is enabled.
sourcepub fn activity_stream_status(&self) -> Option<&str>
pub fn activity_stream_status(&self) -> Option<&str>
The status of the database activity stream. Valid values are as follows:
-
started -
starting -
stopped -
stopping
Whether tags are copied from the DB cluster to snapshots of the DB cluster.
sourcepub fn cross_account_clone(&self) -> bool
pub fn cross_account_clone(&self) -> bool
Whether the DB cluster is a clone of a DB cluster owned by a different Amazon Web Services account.
sourcepub fn domain_memberships(&self) -> Option<&[AwsRdsDbDomainMembership]>
pub fn domain_memberships(&self) -> Option<&[AwsRdsDbDomainMembership]>
The Active Directory domain membership records that are associated with the DB cluster.
sourcepub fn db_cluster_parameter_group(&self) -> Option<&str>
pub fn db_cluster_parameter_group(&self) -> Option<&str>
The name of the DB cluster parameter group for the DB cluster.
sourcepub fn db_subnet_group(&self) -> Option<&str>
pub fn db_subnet_group(&self) -> Option<&str>
The subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
sourcepub fn db_cluster_option_group_memberships(
&self
) -> Option<&[AwsRdsDbClusterOptionGroupMembership]>
pub fn db_cluster_option_group_memberships(
&self
) -> Option<&[AwsRdsDbClusterOptionGroupMembership]>
The list of option group memberships for this DB cluster.
sourcepub fn db_cluster_identifier(&self) -> Option<&str>
pub fn db_cluster_identifier(&self) -> Option<&str>
The DB cluster identifier that the user assigned to the cluster. This identifier is the unique key that identifies a DB cluster.
sourcepub fn db_cluster_members(&self) -> Option<&[AwsRdsDbClusterMember]>
pub fn db_cluster_members(&self) -> Option<&[AwsRdsDbClusterMember]>
The list of instances that make up the DB cluster.
sourcepub fn iam_database_authentication_enabled(&self) -> bool
pub fn iam_database_authentication_enabled(&self) -> bool
Whether the mapping of IAM accounts to database accounts is enabled.
sourceimpl AwsRdsDbClusterDetails
impl AwsRdsDbClusterDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRdsDbClusterDetails.