#[non_exhaustive]pub struct AwsRdsDbDomainMembership { /* private fields */ }Expand description
Information about an Active Directory domain membership record associated with the DB instance.
Implementations
sourceimpl AwsRdsDbDomainMembership
impl AwsRdsDbDomainMembership
sourcepub fn status(&self) -> Option<&str>
pub fn status(&self) -> Option<&str>
The status of the Active Directory Domain membership for the DB instance.
sourcepub fn fqdn(&self) -> Option<&str>
pub fn fqdn(&self) -> Option<&str>
The fully qualified domain name of the Active Directory domain.
sourcepub fn iam_role_name(&self) -> Option<&str>
pub fn iam_role_name(&self) -> Option<&str>
The name of the IAM role to use when making API calls to the Directory Service.
sourceimpl AwsRdsDbDomainMembership
impl AwsRdsDbDomainMembership
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRdsDbDomainMembership.