#[non_exhaustive]pub struct AwsRdsDbPendingModifiedValues { /* private fields */ }Expand description
Changes to a DB instance that are currently pending.
Implementations
sourceimpl AwsRdsDbPendingModifiedValues
impl AwsRdsDbPendingModifiedValues
sourcepub fn db_instance_class(&self) -> Option<&str>
pub fn db_instance_class(&self) -> Option<&str>
The new DB instance class for the DB instance.
sourcepub fn allocated_storage(&self) -> i32
pub fn allocated_storage(&self) -> i32
The new value of the allocated storage for the DB instance.
sourcepub fn master_user_password(&self) -> Option<&str>
pub fn master_user_password(&self) -> Option<&str>
The new master user password for the DB instance.
sourcepub fn backup_retention_period(&self) -> i32
pub fn backup_retention_period(&self) -> i32
The new backup retention period for the DB instance.
sourcepub fn multi_az(&self) -> bool
pub fn multi_az(&self) -> bool
Indicates that a single Availability Zone DB instance is changing to a multiple Availability Zone deployment.
sourcepub fn engine_version(&self) -> Option<&str>
pub fn engine_version(&self) -> Option<&str>
The new engine version for the DB instance.
sourcepub fn license_model(&self) -> Option<&str>
pub fn license_model(&self) -> Option<&str>
The new license model value for the DB instance.
sourcepub fn db_instance_identifier(&self) -> Option<&str>
pub fn db_instance_identifier(&self) -> Option<&str>
The new DB instance identifier for the DB instance.
sourcepub fn storage_type(&self) -> Option<&str>
pub fn storage_type(&self) -> Option<&str>
The new storage type for the DB instance.
sourcepub fn ca_certificate_identifier(&self) -> Option<&str>
pub fn ca_certificate_identifier(&self) -> Option<&str>
The new CA certificate identifier for the DB instance.
sourcepub fn db_subnet_group_name(&self) -> Option<&str>
pub fn db_subnet_group_name(&self) -> Option<&str>
The name of the new subnet group for the DB instance.
sourcepub fn pending_cloud_watch_logs_exports(
&self
) -> Option<&AwsRdsPendingCloudWatchLogsExports>
pub fn pending_cloud_watch_logs_exports(
&self
) -> Option<&AwsRdsPendingCloudWatchLogsExports>
A list of log types that are being enabled or disabled.
sourcepub fn processor_features(&self) -> Option<&[AwsRdsDbProcessorFeature]>
pub fn processor_features(&self) -> Option<&[AwsRdsDbProcessorFeature]>
Processor features that are being updated.
sourceimpl AwsRdsDbPendingModifiedValues
impl AwsRdsDbPendingModifiedValues
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRdsDbPendingModifiedValues.