#[non_exhaustive]pub struct AwsRdsDbSubnetGroupSubnet { /* private fields */ }Expand description
Information about a subnet in a subnet group.
Implementations
sourceimpl AwsRdsDbSubnetGroupSubnet
impl AwsRdsDbSubnetGroupSubnet
sourcepub fn subnet_identifier(&self) -> Option<&str>
pub fn subnet_identifier(&self) -> Option<&str>
The identifier of a subnet in the subnet group.
sourcepub fn subnet_availability_zone(
&self
) -> Option<&AwsRdsDbSubnetGroupSubnetAvailabilityZone>
pub fn subnet_availability_zone(
&self
) -> Option<&AwsRdsDbSubnetGroupSubnetAvailabilityZone>
Information about the Availability Zone for a subnet in the subnet group.
sourcepub fn subnet_status(&self) -> Option<&str>
pub fn subnet_status(&self) -> Option<&str>
The status of a subnet in the subnet group.
sourceimpl AwsRdsDbSubnetGroupSubnet
impl AwsRdsDbSubnetGroupSubnet
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRdsDbSubnetGroupSubnet.