#[non_exhaustive]pub struct AwsRdsEventSubscriptionDetails { /* private fields */ }Expand description
Details about an Amazon RDS event notification subscription. The subscription allows Amazon RDS to post events to an SNS topic.
Implementations
sourceimpl AwsRdsEventSubscriptionDetails
impl AwsRdsEventSubscriptionDetails
sourcepub fn cust_subscription_id(&self) -> Option<&str>
pub fn cust_subscription_id(&self) -> Option<&str>
The identifier of the account that is associated with the event notification subscription.
sourcepub fn customer_aws_id(&self) -> Option<&str>
pub fn customer_aws_id(&self) -> Option<&str>
The identifier of the event notification subscription.
sourcepub fn event_categories_list(&self) -> Option<&[String]>
pub fn event_categories_list(&self) -> Option<&[String]>
The list of event categories for the event notification subscription.
sourcepub fn event_subscription_arn(&self) -> Option<&str>
pub fn event_subscription_arn(&self) -> Option<&str>
The ARN of the event notification subscription.
sourcepub fn sns_topic_arn(&self) -> Option<&str>
pub fn sns_topic_arn(&self) -> Option<&str>
The ARN of the SNS topic to post the event notifications to.
sourcepub fn source_ids_list(&self) -> Option<&[String]>
pub fn source_ids_list(&self) -> Option<&[String]>
A list of source identifiers for the event notification subscription.
sourcepub fn source_type(&self) -> Option<&str>
pub fn source_type(&self) -> Option<&str>
The source type for the event notification subscription.
sourcepub fn status(&self) -> Option<&str>
pub fn status(&self) -> Option<&str>
The status of the event notification subscription.
Valid values: creating | modifying | deleting | active | no-permission | topic-not-exist
sourcepub fn subscription_creation_time(&self) -> Option<&str>
pub fn subscription_creation_time(&self) -> Option<&str>
The datetime when the event notification subscription was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourceimpl AwsRdsEventSubscriptionDetails
impl AwsRdsEventSubscriptionDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRdsEventSubscriptionDetails.