Struct aws_sdk_securityhub::model::AwsRdsPendingCloudWatchLogsExports [−][src]
#[non_exhaustive]pub struct AwsRdsPendingCloudWatchLogsExports {
pub log_types_to_enable: Option<Vec<String>>,
pub log_types_to_disable: Option<Vec<String>>,
}Expand description
Identifies the log types to enable and disable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_types_to_enable: Option<Vec<String>>A list of log types that are being enabled.
log_types_to_disable: Option<Vec<String>>A list of log types that are being disabled.
Implementations
Creates a new builder-style object to manufacture AwsRdsPendingCloudWatchLogsExports