#[non_exhaustive]pub struct AwsRedshiftClusterClusterParameterStatus { /* private fields */ }Expand description
The status of a parameter in a cluster parameter group for an Amazon Redshift cluster.
Implementations
sourceimpl AwsRedshiftClusterClusterParameterStatus
impl AwsRedshiftClusterClusterParameterStatus
sourcepub fn parameter_name(&self) -> Option<&str>
pub fn parameter_name(&self) -> Option<&str>
The name of the parameter.
sourcepub fn parameter_apply_status(&self) -> Option<&str>
pub fn parameter_apply_status(&self) -> Option<&str>
The status of the parameter. Indicates whether the parameter is in sync with the database, waiting for a cluster reboot, or encountered an error when it was applied.
Valid values: in-sync | pending-reboot | applying | invalid-parameter | apply-deferred | apply-error | unknown-error
sourcepub fn parameter_apply_error_description(&self) -> Option<&str>
pub fn parameter_apply_error_description(&self) -> Option<&str>
The error that prevented the parameter from being applied to the database.
sourceimpl AwsRedshiftClusterClusterParameterStatus
impl AwsRedshiftClusterClusterParameterStatus
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRedshiftClusterClusterParameterStatus.