#[non_exhaustive]pub struct AwsRedshiftClusterDeferredMaintenanceWindow { /* private fields */ }Expand description
A time windows during which maintenance was deferred for an Amazon Redshift cluster.
Implementations
sourceimpl AwsRedshiftClusterDeferredMaintenanceWindow
impl AwsRedshiftClusterDeferredMaintenanceWindow
sourcepub fn defer_maintenance_end_time(&self) -> Option<&str>
pub fn defer_maintenance_end_time(&self) -> Option<&str>
The end of the time window for which maintenance was deferred.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn defer_maintenance_identifier(&self) -> Option<&str>
pub fn defer_maintenance_identifier(&self) -> Option<&str>
The identifier of the maintenance window.
sourcepub fn defer_maintenance_start_time(&self) -> Option<&str>
pub fn defer_maintenance_start_time(&self) -> Option<&str>
The start of the time window for which maintenance was deferred.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourceimpl AwsRedshiftClusterDeferredMaintenanceWindow
impl AwsRedshiftClusterDeferredMaintenanceWindow
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRedshiftClusterDeferredMaintenanceWindow.