#[non_exhaustive]pub struct AwsRedshiftClusterLoggingStatus { /* private fields */ }Expand description
Provides information about the logging status of the cluster.
Implementations
sourceimpl AwsRedshiftClusterLoggingStatus
impl AwsRedshiftClusterLoggingStatus
sourcepub fn bucket_name(&self) -> Option<&str>
pub fn bucket_name(&self) -> Option<&str>
The name of the S3 bucket where the log files are stored.
sourcepub fn last_failure_message(&self) -> Option<&str>
pub fn last_failure_message(&self) -> Option<&str>
The message indicating that the logs failed to be delivered.
sourcepub fn last_failure_time(&self) -> Option<&str>
pub fn last_failure_time(&self) -> Option<&str>
The last time when logs failed to be delivered.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn last_successful_delivery_time(&self) -> Option<&str>
pub fn last_successful_delivery_time(&self) -> Option<&str>
The last time that logs were delivered successfully.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn logging_enabled(&self) -> bool
pub fn logging_enabled(&self) -> bool
Indicates whether logging is enabled.
sourcepub fn s3_key_prefix(&self) -> Option<&str>
pub fn s3_key_prefix(&self) -> Option<&str>
Provides the prefix applied to the log file names.
sourceimpl AwsRedshiftClusterLoggingStatus
impl AwsRedshiftClusterLoggingStatus
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRedshiftClusterLoggingStatus.