#[non_exhaustive]pub struct AwsRedshiftClusterPendingModifiedValues { /* private fields */ }Expand description
Changes to the Amazon Redshift cluster that are currently pending.
Implementations
sourceimpl AwsRedshiftClusterPendingModifiedValues
impl AwsRedshiftClusterPendingModifiedValues
sourcepub fn automated_snapshot_retention_period(&self) -> i32
pub fn automated_snapshot_retention_period(&self) -> i32
The pending or in-progress change to the automated snapshot retention period.
sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The pending or in-progress change to the identifier for the cluster.
sourcepub fn cluster_type(&self) -> Option<&str>
pub fn cluster_type(&self) -> Option<&str>
The pending or in-progress change to the cluster type.
sourcepub fn cluster_version(&self) -> Option<&str>
pub fn cluster_version(&self) -> Option<&str>
The pending or in-progress change to the service version.
sourcepub fn encryption_type(&self) -> Option<&str>
pub fn encryption_type(&self) -> Option<&str>
The encryption type for a cluster.
sourcepub fn enhanced_vpc_routing(&self) -> bool
pub fn enhanced_vpc_routing(&self) -> bool
Indicates whether to create the cluster with enhanced VPC routing enabled.
sourcepub fn maintenance_track_name(&self) -> Option<&str>
pub fn maintenance_track_name(&self) -> Option<&str>
The name of the maintenance track that the cluster changes to during the next maintenance window.
sourcepub fn master_user_password(&self) -> Option<&str>
pub fn master_user_password(&self) -> Option<&str>
The pending or in-progress change to the master user password for the cluster.
sourcepub fn node_type(&self) -> Option<&str>
pub fn node_type(&self) -> Option<&str>
The pending or in-progress change to the cluster's node type.
sourcepub fn number_of_nodes(&self) -> i32
pub fn number_of_nodes(&self) -> i32
The pending or in-progress change to the number of nodes in the cluster.
sourcepub fn publicly_accessible(&self) -> bool
pub fn publicly_accessible(&self) -> bool
The pending or in-progress change to whether the cluster can be connected to from the public network.
sourceimpl AwsRedshiftClusterPendingModifiedValues
impl AwsRedshiftClusterPendingModifiedValues
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsRedshiftClusterPendingModifiedValues.