#[non_exhaustive]pub struct AwsS3AccountPublicAccessBlockDetails { /* private fields */ }Expand description
provides information about the Amazon S3 Public Access Block configuration for accounts.
Implementations
sourceimpl AwsS3AccountPublicAccessBlockDetails
impl AwsS3AccountPublicAccessBlockDetails
sourcepub fn block_public_acls(&self) -> bool
pub fn block_public_acls(&self) -> bool
Indicates whether to reject calls to update an S3 bucket if the calls include a public access control list (ACL).
sourcepub fn block_public_policy(&self) -> bool
pub fn block_public_policy(&self) -> bool
Indicates whether to reject calls to update the access policy for an S3 bucket or access point if the policy allows public access.
sourcepub fn ignore_public_acls(&self) -> bool
pub fn ignore_public_acls(&self) -> bool
Indicates whether Amazon S3 ignores public ACLs that are associated with an S3 bucket.
sourcepub fn restrict_public_buckets(&self) -> bool
pub fn restrict_public_buckets(&self) -> bool
Indicates whether to restrict access to an access point or S3 bucket that has a public policy to only Amazon Web Services service principals and authorized users within the S3 bucket owner's account.
sourceimpl AwsS3AccountPublicAccessBlockDetails
impl AwsS3AccountPublicAccessBlockDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3AccountPublicAccessBlockDetails.