#[non_exhaustive]
pub struct AwsS3BucketBucketLifecycleConfigurationRulesDetails { /* private fields */ }
Configuration for a lifecycle rule.

Implementations

How Amazon S3 responds when a multipart upload is incomplete. Specifically, provides a number of days before Amazon S3 cancels the entire upload.

The date when objects are moved or deleted.

Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.

The length in days of the lifetime for objects that are subject to the rule.

Whether Amazon S3 removes a delete marker that has no noncurrent versions. If set to true, the delete marker is expired. If set to false, the policy takes no action.

If you provide ExpiredObjectDeleteMarker, you cannot provide ExpirationInDays or ExpirationDate.

Identifies the objects that a rule applies to.

The unique identifier of the rule.

The number of days that an object is noncurrent before Amazon S3 can perform the associated action.

Transition rules that describe when noncurrent objects transition to a specified storage class.

A prefix that identifies one or more objects that the rule applies to.

The current status of the rule. Indicates whether the rule is currently being applied.

Transition rules that indicate when objects transition to a specified storage class.

Creates a new builder-style object to manufacture AwsS3BucketBucketLifecycleConfigurationRulesDetails.