#[non_exhaustive]
pub struct AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetails { /* private fields */ }
A transition rule that describes when noncurrent objects transition to a specified storage class.

Implementations

The number of days that an object is noncurrent before Amazon S3 can perform the associated action.

The class of storage to change the object to after the object is noncurrent for the specified number of days.