#[non_exhaustive]
pub struct AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails { /* private fields */ }
A rule for when objects transition to specific storage classes.

Implementations

A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.

Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.

The number of days after which to transition the object to the specified storage class. If you provide Days, you cannot provide Date.

The storage class to transition the object to. Valid values are as follows:

  • DEEP_ARCHIVE

  • GLACIER

  • INTELLIGENT_TIERING

  • ONEZONE_IA

  • STANDARD_IA

Creates a new builder-style object to manufacture AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails.