Struct aws_sdk_securityhub::model::AwsS3BucketDetails
source · [−]#[non_exhaustive]pub struct AwsS3BucketDetails { /* private fields */ }Expand description
The details of an Amazon S3 bucket.
Implementations
sourceimpl AwsS3BucketDetails
impl AwsS3BucketDetails
sourcepub fn owner_name(&self) -> Option<&str>
pub fn owner_name(&self) -> Option<&str>
The display name of the owner of the S3 bucket.
sourcepub fn owner_account_id(&self) -> Option<&str>
pub fn owner_account_id(&self) -> Option<&str>
The Amazon Web Services account identifier of the account that owns the S3 bucket.
sourcepub fn created_at(&self) -> Option<&str>
pub fn created_at(&self) -> Option<&str>
Indicates when the S3 bucket was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn server_side_encryption_configuration(
&self
) -> Option<&AwsS3BucketServerSideEncryptionConfiguration>
pub fn server_side_encryption_configuration(
&self
) -> Option<&AwsS3BucketServerSideEncryptionConfiguration>
The encryption rules that are applied to the S3 bucket.
sourcepub fn bucket_lifecycle_configuration(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationDetails>
pub fn bucket_lifecycle_configuration(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationDetails>
The lifecycle configuration for objects in the S3 bucket.
sourcepub fn public_access_block_configuration(
&self
) -> Option<&AwsS3AccountPublicAccessBlockDetails>
pub fn public_access_block_configuration(
&self
) -> Option<&AwsS3AccountPublicAccessBlockDetails>
Provides information about the Amazon S3 Public Access Block configuration for the S3 bucket.
sourcepub fn access_control_list(&self) -> Option<&str>
pub fn access_control_list(&self) -> Option<&str>
The access control list for the S3 bucket.
sourcepub fn bucket_logging_configuration(
&self
) -> Option<&AwsS3BucketLoggingConfiguration>
pub fn bucket_logging_configuration(
&self
) -> Option<&AwsS3BucketLoggingConfiguration>
The logging configuration for the S3 bucket.
sourcepub fn bucket_website_configuration(
&self
) -> Option<&AwsS3BucketWebsiteConfiguration>
pub fn bucket_website_configuration(
&self
) -> Option<&AwsS3BucketWebsiteConfiguration>
The website configuration parameters for the S3 bucket.
sourcepub fn bucket_notification_configuration(
&self
) -> Option<&AwsS3BucketNotificationConfiguration>
pub fn bucket_notification_configuration(
&self
) -> Option<&AwsS3BucketNotificationConfiguration>
The notification configuration for the S3 bucket.
sourcepub fn bucket_versioning_configuration(
&self
) -> Option<&AwsS3BucketBucketVersioningConfiguration>
pub fn bucket_versioning_configuration(
&self
) -> Option<&AwsS3BucketBucketVersioningConfiguration>
The versioning state of an S3 bucket.
sourceimpl AwsS3BucketDetails
impl AwsS3BucketDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketDetails.