#[non_exhaustive]pub struct AwsS3BucketServerSideEncryptionByDefault { /* private fields */ }Expand description
Specifies the default server-side encryption to apply to new objects in the bucket.
Implementations
sourceimpl AwsS3BucketServerSideEncryptionByDefault
impl AwsS3BucketServerSideEncryptionByDefault
sourcepub fn sse_algorithm(&self) -> Option<&str>
pub fn sse_algorithm(&self) -> Option<&str>
Server-side encryption algorithm to use for the default encryption. Valid values are aws: kms or AES256.
sourcepub fn kms_master_key_id(&self) -> Option<&str>
pub fn kms_master_key_id(&self) -> Option<&str>
KMS key ID to use for the default encryption.
sourceimpl AwsS3BucketServerSideEncryptionByDefault
impl AwsS3BucketServerSideEncryptionByDefault
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketServerSideEncryptionByDefault.