#[non_exhaustive]pub struct AwsS3BucketWebsiteConfiguration { /* private fields */ }Expand description
Website parameters for the S3 bucket.
Implementations
sourceimpl AwsS3BucketWebsiteConfiguration
impl AwsS3BucketWebsiteConfiguration
sourcepub fn error_document(&self) -> Option<&str>
pub fn error_document(&self) -> Option<&str>
The name of the error document for the website.
sourcepub fn index_document_suffix(&self) -> Option<&str>
pub fn index_document_suffix(&self) -> Option<&str>
The name of the index document for the website.
sourcepub fn redirect_all_requests_to(
&self
) -> Option<&AwsS3BucketWebsiteConfigurationRedirectTo>
pub fn redirect_all_requests_to(
&self
) -> Option<&AwsS3BucketWebsiteConfigurationRedirectTo>
The redirect behavior for requests to the website.
sourcepub fn routing_rules(
&self
) -> Option<&[AwsS3BucketWebsiteConfigurationRoutingRule]>
pub fn routing_rules(
&self
) -> Option<&[AwsS3BucketWebsiteConfigurationRoutingRule]>
The rules for applying redirects for requests to the website.
sourceimpl AwsS3BucketWebsiteConfiguration
impl AwsS3BucketWebsiteConfiguration
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfiguration.