Struct aws_sdk_securityhub::model::AwsS3BucketWebsiteConfigurationRoutingRule [−][src]
#[non_exhaustive]pub struct AwsS3BucketWebsiteConfigurationRoutingRule {
pub condition: Option<AwsS3BucketWebsiteConfigurationRoutingRuleCondition>,
pub redirect: Option<AwsS3BucketWebsiteConfigurationRoutingRuleRedirect>,
}Expand description
A rule for redirecting requests to the website.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.condition: Option<AwsS3BucketWebsiteConfigurationRoutingRuleCondition>Provides the condition that must be met in order to apply the routing rule.
redirect: Option<AwsS3BucketWebsiteConfigurationRoutingRuleRedirect>Provides the rules to redirect the request if the condition in Condition is
met.
Implementations
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfigurationRoutingRule