#[non_exhaustive]pub struct AwsS3BucketWebsiteConfigurationRoutingRuleCondition { /* private fields */ }Expand description
The condition that must be met in order to apply the routing rule.
Implementations
sourceimpl AwsS3BucketWebsiteConfigurationRoutingRuleCondition
impl AwsS3BucketWebsiteConfigurationRoutingRuleCondition
sourcepub fn http_error_code_returned_equals(&self) -> Option<&str>
pub fn http_error_code_returned_equals(&self) -> Option<&str>
Indicates to redirect the request if the HTTP error code matches this value.
sourcepub fn key_prefix_equals(&self) -> Option<&str>
pub fn key_prefix_equals(&self) -> Option<&str>
Indicates to redirect the request if the key prefix matches this value.
sourceimpl AwsS3BucketWebsiteConfigurationRoutingRuleCondition
impl AwsS3BucketWebsiteConfigurationRoutingRuleCondition
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfigurationRoutingRuleCondition.