#[non_exhaustive]pub struct AwsS3BucketWebsiteConfigurationRoutingRuleRedirect { /* private fields */ }Expand description
The rules to redirect the request if the condition in Condition is met.
Implementations
sourceimpl AwsS3BucketWebsiteConfigurationRoutingRuleRedirect
impl AwsS3BucketWebsiteConfigurationRoutingRuleRedirect
sourcepub fn http_redirect_code(&self) -> Option<&str>
pub fn http_redirect_code(&self) -> Option<&str>
The HTTP redirect code to use in the response.
sourcepub fn protocol(&self) -> Option<&str>
pub fn protocol(&self) -> Option<&str>
The protocol to use to redirect the request. By default, uses the protocol from the original request.
sourcepub fn replace_key_prefix_with(&self) -> Option<&str>
pub fn replace_key_prefix_with(&self) -> Option<&str>
The object key prefix to use in the redirect request.
Cannot be provided if ReplaceKeyWith is present.
sourcepub fn replace_key_with(&self) -> Option<&str>
pub fn replace_key_with(&self) -> Option<&str>
The specific object key to use in the redirect request.
Cannot be provided if ReplaceKeyPrefixWith is present.
sourceimpl AwsS3BucketWebsiteConfigurationRoutingRuleRedirect
impl AwsS3BucketWebsiteConfigurationRoutingRuleRedirect
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfigurationRoutingRuleRedirect.