Struct aws_sdk_securityhub::model::AwsS3ObjectDetails
source · [−]#[non_exhaustive]pub struct AwsS3ObjectDetails { /* private fields */ }Expand description
Details about an Amazon S3 object.
Implementations
sourceimpl AwsS3ObjectDetails
impl AwsS3ObjectDetails
sourcepub fn last_modified(&self) -> Option<&str>
pub fn last_modified(&self) -> Option<&str>
Indicates when the object was last modified.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn e_tag(&self) -> Option<&str>
pub fn e_tag(&self) -> Option<&str>
The opaque identifier assigned by a web server to a specific version of a resource found at a URL.
sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
The version of the object.
sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
A standard MIME type describing the format of the object data.
sourcepub fn server_side_encryption(&self) -> Option<&str>
pub fn server_side_encryption(&self) -> Option<&str>
If the object is stored using server-side encryption, the value of the server-side encryption algorithm used when storing this object in Amazon S3.
sourcepub fn ssekms_key_id(&self) -> Option<&str>
pub fn ssekms_key_id(&self) -> Option<&str>
The identifier of the KMS symmetric customer managed key that was used for the object.
sourceimpl AwsS3ObjectDetails
impl AwsS3ObjectDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3ObjectDetails.