#[non_exhaustive]pub struct AwsSecurityFindingIdentifier { /* private fields */ }Expand description
Identifies a finding to update using BatchUpdateFindings.
Implementations
sourceimpl AwsSecurityFindingIdentifier
impl AwsSecurityFindingIdentifier
sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
The identifier of the finding that was specified by the finding provider.
sourcepub fn product_arn(&self) -> Option<&str>
pub fn product_arn(&self) -> Option<&str>
The ARN generated by Security Hub that uniquely identifies a product that generates findings. This can be the ARN for a third-party product that is integrated with Security Hub, or the ARN for a custom integration.
sourceimpl AwsSecurityFindingIdentifier
impl AwsSecurityFindingIdentifier
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsSecurityFindingIdentifier.