Struct aws_sdk_securityhub::model::AwsSnsTopicDetails
source · [−]#[non_exhaustive]pub struct AwsSnsTopicDetails { /* private fields */ }Expand description
Provides information about an Amazon SNS topic to which notifications can be published.
Implementations
sourceimpl AwsSnsTopicDetails
impl AwsSnsTopicDetails
sourcepub fn kms_master_key_id(&self) -> Option<&str>
pub fn kms_master_key_id(&self) -> Option<&str>
The ID of an Amazon Web Services managed key for Amazon SNS or a customer managed key.
sourcepub fn subscription(&self) -> Option<&[AwsSnsTopicSubscription]>
pub fn subscription(&self) -> Option<&[AwsSnsTopicSubscription]>
Subscription is an embedded property that describes the subscription endpoints of an Amazon SNS topic.
sourcepub fn topic_name(&self) -> Option<&str>
pub fn topic_name(&self) -> Option<&str>
The name of the Amazon SNS topic.
sourcepub fn sqs_success_feedback_role_arn(&self) -> Option<&str>
pub fn sqs_success_feedback_role_arn(&self) -> Option<&str>
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
sourcepub fn sqs_failure_feedback_role_arn(&self) -> Option<&str>
pub fn sqs_failure_feedback_role_arn(&self) -> Option<&str>
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
sourcepub fn application_success_feedback_role_arn(&self) -> Option<&str>
pub fn application_success_feedback_role_arn(&self) -> Option<&str>
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to a platform application endpoint.
sourcepub fn firehose_success_feedback_role_arn(&self) -> Option<&str>
pub fn firehose_success_feedback_role_arn(&self) -> Option<&str>
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
sourcepub fn firehose_failure_feedback_role_arn(&self) -> Option<&str>
pub fn firehose_failure_feedback_role_arn(&self) -> Option<&str>
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
sourcepub fn http_success_feedback_role_arn(&self) -> Option<&str>
pub fn http_success_feedback_role_arn(&self) -> Option<&str>
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
sourcepub fn http_failure_feedback_role_arn(&self) -> Option<&str>
pub fn http_failure_feedback_role_arn(&self) -> Option<&str>
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
sourceimpl AwsSnsTopicDetails
impl AwsSnsTopicDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsSnsTopicDetails.