Struct aws_sdk_securityhub::model::AwsSsmPatchComplianceDetails [−][src]
#[non_exhaustive]pub struct AwsSsmPatchComplianceDetails {
pub patch: Option<AwsSsmPatch>,
}Expand description
Provides information about the state of a patch on an instance based on the patch baseline that was used to patch the instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.patch: Option<AwsSsmPatch>Information about the status of a patch.
Implementations
Creates a new builder-style object to manufacture AwsSsmPatchComplianceDetails