#[non_exhaustive]pub struct AwsWafRegionalRateBasedRuleDetails { /* private fields */ }Expand description
contains details about a rate-based rule for Regional resources. A rate-based rule provides settings to indicate when to allow, block, or count a request. Rate-based rules include the number of requests that arrive over a specified period of time.
Implementations
sourceimpl AwsWafRegionalRateBasedRuleDetails
impl AwsWafRegionalRateBasedRuleDetails
sourcepub fn metric_name(&self) -> Option<&str>
pub fn metric_name(&self) -> Option<&str>
The name of the metrics for the rate-based rule.
sourcepub fn rate_key(&self) -> Option<&str>
pub fn rate_key(&self) -> Option<&str>
The field that WAF uses to determine whether requests are likely arriving from single source and are subject to rate monitoring.
sourcepub fn rate_limit(&self) -> i64
pub fn rate_limit(&self) -> i64
The maximum number of requests that have an identical value for the field specified in RateKey that are allowed within a five-minute period. If the number of requests exceeds RateLimit and the other predicates specified in the rule are met, WAF triggers the action for the rule.
sourcepub fn match_predicates(
&self
) -> Option<&[AwsWafRegionalRateBasedRuleMatchPredicate]>
pub fn match_predicates(
&self
) -> Option<&[AwsWafRegionalRateBasedRuleMatchPredicate]>
The predicates to include in the rate-based rule.
sourceimpl AwsWafRegionalRateBasedRuleDetails
impl AwsWafRegionalRateBasedRuleDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsWafRegionalRateBasedRuleDetails.