Struct aws_sdk_securityhub::model::AwsWafRuleDetails
source · [−]#[non_exhaustive]pub struct AwsWafRuleDetails { /* private fields */ }Expand description
Provides information about a WAF rule. This rule specifies the web requests that you want to allow, block, or count.
Implementations
sourceimpl AwsWafRuleDetails
impl AwsWafRuleDetails
sourcepub fn metric_name(&self) -> Option<&str>
pub fn metric_name(&self) -> Option<&str>
The name of the metrics for this rule.
sourcepub fn predicate_list(&self) -> Option<&[AwsWafRulePredicateListDetails]>
pub fn predicate_list(&self) -> Option<&[AwsWafRulePredicateListDetails]>
Specifies the ByteMatchSet, IPSet, SqlInjectionMatchSet, XssMatchSet, RegexMatchSet, GeoMatchSet, and SizeConstraintSet objects that you want to add to a rule and, for each object, indicates whether you want to negate the settings.
sourceimpl AwsWafRuleDetails
impl AwsWafRuleDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsWafRuleDetails.