#[non_exhaustive]pub struct AwsWafRulePredicateListDetails { /* private fields */ }Expand description
Provides details about the ByteMatchSet, IPSet, SqlInjectionMatchSet, XssMatchSet, RegexMatchSet, GeoMatchSet, and SizeConstraintSet objects that you want to add to a rule and, for each object, indicates whether you want to negate the settings.
Implementations
sourceimpl AwsWafRulePredicateListDetails
impl AwsWafRulePredicateListDetails
sourcepub fn data_id(&self) -> Option<&str>
pub fn data_id(&self) -> Option<&str>
A unique identifier for a predicate in a rule, such as ByteMatchSetId or IPSetId.
sourceimpl AwsWafRulePredicateListDetails
impl AwsWafRulePredicateListDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsWafRulePredicateListDetails.