Struct aws_sdk_securityhub::model::AwsWafWebAclDetails
source · [−]#[non_exhaustive]pub struct AwsWafWebAclDetails { /* private fields */ }Expand description
Provides information about an WAF web access control list (web ACL).
Implementations
sourceimpl AwsWafWebAclDetails
impl AwsWafWebAclDetails
sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
A friendly name or description of the web ACL. You can't change the name of a web ACL after you create it.
sourcepub fn default_action(&self) -> Option<&str>
pub fn default_action(&self) -> Option<&str>
The action to perform if none of the rules contained in the web ACL match.
sourcepub fn rules(&self) -> Option<&[AwsWafWebAclRule]>
pub fn rules(&self) -> Option<&[AwsWafWebAclRule]>
An array that contains the action for each rule in a web ACL, the priority of the rule, and the ID of the rule.
sourcepub fn web_acl_id(&self) -> Option<&str>
pub fn web_acl_id(&self) -> Option<&str>
A unique identifier for a web ACL.
sourceimpl AwsWafWebAclDetails
impl AwsWafWebAclDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsWafWebAclDetails.