Struct aws_sdk_securityhub::model::AwsWafWebAclRule
source · #[non_exhaustive]pub struct AwsWafWebAclRule { /* private fields */ }Expand description
Details for a rule in an WAF web ACL.
Implementations
sourceimpl AwsWafWebAclRule
impl AwsWafWebAclRule
sourcepub fn action(&self) -> Option<&WafAction>
pub fn action(&self) -> Option<&WafAction>
Specifies the action that CloudFront or WAF takes when a web request matches the conditions in the rule.
sourcepub fn excluded_rules(&self) -> Option<&[WafExcludedRule]>
pub fn excluded_rules(&self) -> Option<&[WafExcludedRule]>
Rules to exclude from a rule group.
sourcepub fn override_action(&self) -> Option<&WafOverrideAction>
pub fn override_action(&self) -> Option<&WafOverrideAction>
Use the OverrideAction to test your RuleGroup.
Any rule in a RuleGroup can potentially block a request. If you set the OverrideAction to None, the RuleGroup blocks a request if any individual rule in the RuleGroup matches the request and is configured to block that request.
However, if you first want to test the RuleGroup, set the OverrideAction to Count. The RuleGroup then overrides any block action specified by individual rules contained within the group. Instead of blocking matching requests, those requests are counted.
ActivatedRule|OverrideAction applies only when updating or adding a RuleGroup to a web ACL. In this case you do not use ActivatedRule Action. For all other update requests, ActivatedRule Action is used instead of ActivatedRule OverrideAction.
sourcepub fn priority(&self) -> i32
pub fn priority(&self) -> i32
Specifies the order in which the rules in a web ACL are evaluated. Rules with a lower value for Priority are evaluated before rules with a higher value. The value must be a unique integer. If you add multiple rules to a web ACL, the values do not need to be consecutive.
sourceimpl AwsWafWebAclRule
impl AwsWafWebAclRule
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsWafWebAclRule.