#[non_exhaustive]pub struct BatchUpdateFindingsUnprocessedFinding { /* private fields */ }Expand description
A finding from a BatchUpdateFindings request that Security Hub was unable to update.
Implementations
sourceimpl BatchUpdateFindingsUnprocessedFinding
impl BatchUpdateFindingsUnprocessedFinding
sourcepub fn finding_identifier(&self) -> Option<&AwsSecurityFindingIdentifier>
pub fn finding_identifier(&self) -> Option<&AwsSecurityFindingIdentifier>
The identifier of the finding that was not updated.
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
sourceimpl BatchUpdateFindingsUnprocessedFinding
impl BatchUpdateFindingsUnprocessedFinding
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture BatchUpdateFindingsUnprocessedFinding.