Struct aws_sdk_securityhub::model::Compliance
source · [−]#[non_exhaustive]pub struct Compliance { /* private fields */ }Expand description
Contains finding details that are specific to control-based findings. Only returned for findings generated from controls.
Implementations
sourceimpl Compliance
impl Compliance
sourcepub fn status(&self) -> Option<&ComplianceStatus>
pub fn status(&self) -> Option<&ComplianceStatus>
The result of a standards check.
The valid values for Status are as follows.
-
-
PASSED- Standards check passed for all evaluated resources. -
WARNING- Some information is missing or this check is not supported for your configuration. -
FAILED- Standards check failed for at least one evaluated resource. -
NOT_AVAILABLE- Check could not be performed due to a service outage, API error, or because the result of the Config evaluation wasNOT_APPLICABLE. If the Config evaluation result wasNOT_APPLICABLE, then after 3 days, Security Hub automatically archives the finding.
-
For a control, the industry or regulatory framework requirements that are related to the control. The check for that control is aligned with these requirements.
sourcepub fn status_reasons(&self) -> Option<&[StatusReason]>
pub fn status_reasons(&self) -> Option<&[StatusReason]>
For findings generated from controls, a list of reasons behind the value of Status. For the list of status reason codes and their meanings, see Standards-related information in the ASFF in the Security Hub User Guide.
sourceimpl Compliance
impl Compliance
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture Compliance.