Struct aws_sdk_securityhub::model::ContainerDetails
source · [−]#[non_exhaustive]pub struct ContainerDetails { /* private fields */ }Expand description
Container details related to a finding.
Implementations
sourceimpl ContainerDetails
impl ContainerDetails
sourcepub fn container_runtime(&self) -> Option<&str>
pub fn container_runtime(&self) -> Option<&str>
The runtime of the container.
sourcepub fn image_id(&self) -> Option<&str>
pub fn image_id(&self) -> Option<&str>
The identifier of the container image related to a finding.
sourcepub fn image_name(&self) -> Option<&str>
pub fn image_name(&self) -> Option<&str>
The name of the container image related to a finding.
sourcepub fn launched_at(&self) -> Option<&str>
pub fn launched_at(&self) -> Option<&str>
Indicates when the container started.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn volume_mounts(&self) -> Option<&[VolumeMount]>
pub fn volume_mounts(&self) -> Option<&[VolumeMount]>
Provides information about the mounting of a volume in a container.
sourcepub fn privileged(&self) -> bool
pub fn privileged(&self) -> bool
When this parameter is true, the container is given elevated privileges on the host container instance (similar to the root user).
sourceimpl ContainerDetails
impl ContainerDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ContainerDetails.