#[non_exhaustive]pub struct CustomDataIdentifiersDetections { /* private fields */ }Expand description
The list of detected instances of sensitive data.
Implementations
sourceimpl CustomDataIdentifiersDetections
impl CustomDataIdentifiersDetections
sourcepub fn count(&self) -> i64
pub fn count(&self) -> i64
The total number of occurrences of sensitive data that were detected.
sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The ARN of the custom identifier that was used to detect the sensitive data.
sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
he name of the custom identifier that detected the sensitive data.
sourcepub fn occurrences(&self) -> Option<&Occurrences>
pub fn occurrences(&self) -> Option<&Occurrences>
Details about the sensitive data that was detected.
sourceimpl CustomDataIdentifiersDetections
impl CustomDataIdentifiersDetections
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CustomDataIdentifiersDetections.