Struct aws_sdk_securityhub::model::FilePaths
source · [−]#[non_exhaustive]pub struct FilePaths { /* private fields */ }Expand description
Provides information about the file paths that were affected by the threat.
Implementations
sourceimpl FilePaths
impl FilePaths
sourcepub fn file_path(&self) -> Option<&str>
pub fn file_path(&self) -> Option<&str>
Path to the infected or suspicious file on the resource it was detected on.
sourcepub fn file_name(&self) -> Option<&str>
pub fn file_name(&self) -> Option<&str>
The name of the infected or suspicious file corresponding to the hash.
sourcepub fn resource_id(&self) -> Option<&str>
pub fn resource_id(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the resource on which the threat was detected.