Struct aws_sdk_securityhub::model::FindingAggregator
source · [−]#[non_exhaustive]pub struct FindingAggregator { /* private fields */ }Expand description
A finding aggregator. A finding aggregator contains the configuration for finding aggregation.
Implementations
sourceimpl FindingAggregator
impl FindingAggregator
sourcepub fn finding_aggregator_arn(&self) -> Option<&str>
pub fn finding_aggregator_arn(&self) -> Option<&str>
The ARN of the finding aggregator. You use the finding aggregator ARN to retrieve details for, update, and delete the finding aggregator.
sourceimpl FindingAggregator
impl FindingAggregator
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FindingAggregator.