Struct aws_sdk_securityhub::model::FindingProviderFields
source · [−]#[non_exhaustive]pub struct FindingProviderFields { /* private fields */ }Expand description
In a BatchImportFindings request, finding providers use FindingProviderFields to provide and update values for confidence, criticality, related findings, severity, and types.
Implementations
sourceimpl FindingProviderFields
impl FindingProviderFields
sourcepub fn confidence(&self) -> i32
pub fn confidence(&self) -> i32
A finding's confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
sourcepub fn criticality(&self) -> i32
pub fn criticality(&self) -> i32
The level of importance assigned to the resources associated with the finding.
A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources.
A list of findings that are related to the current finding.
sourcepub fn severity(&self) -> Option<&FindingProviderSeverity>
pub fn severity(&self) -> Option<&FindingProviderSeverity>
The severity of a finding.
sourceimpl FindingProviderFields
impl FindingProviderFields
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FindingProviderFields.