Struct aws_sdk_securityhub::model::FirewallPolicyDetails
source · [−]#[non_exhaustive]pub struct FirewallPolicyDetails { /* private fields */ }Expand description
Defines the behavior of the firewall.
Implementations
sourceimpl FirewallPolicyDetails
impl FirewallPolicyDetails
sourcepub fn stateful_rule_group_references(
&self
) -> Option<&[FirewallPolicyStatefulRuleGroupReferencesDetails]>
pub fn stateful_rule_group_references(
&self
) -> Option<&[FirewallPolicyStatefulRuleGroupReferencesDetails]>
The stateful rule groups that are used in the firewall policy.
sourcepub fn stateless_custom_actions(
&self
) -> Option<&[FirewallPolicyStatelessCustomActionsDetails]>
pub fn stateless_custom_actions(
&self
) -> Option<&[FirewallPolicyStatelessCustomActionsDetails]>
The custom action definitions that are available to use in the firewall policy's StatelessDefaultActions setting.
sourcepub fn stateless_default_actions(&self) -> Option<&[String]>
pub fn stateless_default_actions(&self) -> Option<&[String]>
The actions to take on a packet if it doesn't match any of the stateless rules in the policy.
You must specify a standard action (aws:pass, aws:drop, aws:forward_to_sfe), and can optionally include a custom action from StatelessCustomActions.
sourcepub fn stateless_fragment_default_actions(&self) -> Option<&[String]>
pub fn stateless_fragment_default_actions(&self) -> Option<&[String]>
The actions to take on a fragmented UDP packet if it doesn't match any of the stateless rules in the policy.
You must specify a standard action (aws:pass, aws:drop, aws:forward_to_sfe), and can optionally include a custom action from StatelessCustomActions.
sourcepub fn stateless_rule_group_references(
&self
) -> Option<&[FirewallPolicyStatelessRuleGroupReferencesDetails]>
pub fn stateless_rule_group_references(
&self
) -> Option<&[FirewallPolicyStatelessRuleGroupReferencesDetails]>
The stateless rule groups that are used in the firewall policy.
sourceimpl FirewallPolicyDetails
impl FirewallPolicyDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FirewallPolicyDetails.