Struct aws_sdk_securityhub::model::ImportFindingsError
source · [−]#[non_exhaustive]pub struct ImportFindingsError { /* private fields */ }Expand description
The list of the findings that cannot be imported. For each finding, the list provides the error.
Implementations
sourceimpl ImportFindingsError
impl ImportFindingsError
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The code of the error returned by the BatchImportFindings operation.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The message of the error returned by the BatchImportFindings operation.
sourceimpl ImportFindingsError
impl ImportFindingsError
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ImportFindingsError.