Struct aws_sdk_securityhub::model::Invitation
source · [−]#[non_exhaustive]pub struct Invitation { /* private fields */ }Expand description
Details about an invitation.
Implementations
sourceimpl Invitation
impl Invitation
sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The account ID of the Security Hub administrator account that the invitation was sent from.
sourcepub fn invitation_id(&self) -> Option<&str>
pub fn invitation_id(&self) -> Option<&str>
The ID of the invitation sent to the member account.
sourcepub fn invited_at(&self) -> Option<&DateTime>
pub fn invited_at(&self) -> Option<&DateTime>
The timestamp of when the invitation was sent.
sourcepub fn member_status(&self) -> Option<&str>
pub fn member_status(&self) -> Option<&str>
The current status of the association between the member and administrator accounts.
sourceimpl Invitation
impl Invitation
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture Invitation.