Struct aws_sdk_securityhub::model::NetworkPathComponent
source · [−]#[non_exhaustive]pub struct NetworkPathComponent { /* private fields */ }Expand description
Information about a network path component.
Implementations
sourceimpl NetworkPathComponent
impl NetworkPathComponent
sourcepub fn component_id(&self) -> Option<&str>
pub fn component_id(&self) -> Option<&str>
The identifier of a component in the network path.
sourcepub fn component_type(&self) -> Option<&str>
pub fn component_type(&self) -> Option<&str>
The type of component.
sourcepub fn egress(&self) -> Option<&NetworkHeader>
pub fn egress(&self) -> Option<&NetworkHeader>
Information about the component that comes after the current component in the network path.
sourcepub fn ingress(&self) -> Option<&NetworkHeader>
pub fn ingress(&self) -> Option<&NetworkHeader>
Information about the component that comes before the current node in the network path.
sourceimpl NetworkPathComponent
impl NetworkPathComponent
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture NetworkPathComponent.