Struct aws_sdk_securityhub::model::Occurrences
source · [−]#[non_exhaustive]pub struct Occurrences { /* private fields */ }Expand description
The detected occurrences of sensitive data.
Implementations
sourceimpl Occurrences
impl Occurrences
sourcepub fn line_ranges(&self) -> Option<&[Range]>
pub fn line_ranges(&self) -> Option<&[Range]>
Occurrences of sensitive data detected in a non-binary text file or a Microsoft Word file. Non-binary text files include files such as HTML, XML, JSON, and TXT files.
sourcepub fn offset_ranges(&self) -> Option<&[Range]>
pub fn offset_ranges(&self) -> Option<&[Range]>
Occurrences of sensitive data detected in a binary text file.
sourcepub fn pages(&self) -> Option<&[Page]>
pub fn pages(&self) -> Option<&[Page]>
Occurrences of sensitive data in an Adobe Portable Document Format (PDF) file.
sourceimpl Occurrences
impl Occurrences
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture Occurrences.