Struct aws_sdk_securityhub::model::PatchSummary
source · [−]#[non_exhaustive]pub struct PatchSummary { /* private fields */ }Expand description
Provides an overview of the patch compliance status for an instance against a selected compliance standard.
Implementations
sourceimpl PatchSummary
impl PatchSummary
sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
The identifier of the compliance standard that was used to determine the patch compliance status.
sourcepub fn installed_count(&self) -> i32
pub fn installed_count(&self) -> i32
The number of patches from the compliance standard that were installed successfully.
sourcepub fn missing_count(&self) -> i32
pub fn missing_count(&self) -> i32
The number of patches that are part of the compliance standard but are not installed. The count includes patches that failed to install.
sourcepub fn failed_count(&self) -> i32
pub fn failed_count(&self) -> i32
The number of patches from the compliance standard that failed to install.
sourcepub fn installed_other_count(&self) -> i32
pub fn installed_other_count(&self) -> i32
The number of installed patches that are not part of the compliance standard.
sourcepub fn installed_rejected_count(&self) -> i32
pub fn installed_rejected_count(&self) -> i32
The number of patches that are installed but are also on a list of patches that the customer rejected.
sourcepub fn installed_pending_reboot(&self) -> i32
pub fn installed_pending_reboot(&self) -> i32
The number of patches that were applied, but that require the instance to be rebooted in order to be marked as installed.
sourcepub fn operation_start_time(&self) -> Option<&str>
pub fn operation_start_time(&self) -> Option<&str>
Indicates when the operation started.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn operation_end_time(&self) -> Option<&str>
pub fn operation_end_time(&self) -> Option<&str>
Indicates when the operation completed.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn reboot_option(&self) -> Option<&str>
pub fn reboot_option(&self) -> Option<&str>
The reboot option specified for the instance.
sourceimpl PatchSummary
impl PatchSummary
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture PatchSummary.