Struct aws_sdk_securityhub::model::Record [−][src]
An occurrence of sensitive data in an Apache Avro object container or an Apache Parquet file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.json_path: Option<String>The path, as a JSONPath expression, to the field in the record that contains the data. If the field name is longer than 20 characters, it is truncated. If the path is longer than 250 characters, it is truncated.
record_index: i64The record index, starting from 0, for the record that contains the data.
Implementations