#[non_exhaustive]pub struct RuleGroupSourceListDetails { /* private fields */ }Expand description
Stateful inspection criteria for a domain list rule group.
Implementations
sourceimpl RuleGroupSourceListDetails
impl RuleGroupSourceListDetails
sourcepub fn generated_rules_type(&self) -> Option<&str>
pub fn generated_rules_type(&self) -> Option<&str>
Indicates whether to allow or deny access to the domains listed in Targets.
sourcepub fn target_types(&self) -> Option<&[String]>
pub fn target_types(&self) -> Option<&[String]>
The protocols that you want to inspect. Specify LS_SNI for HTTPS. Specify HTTP_HOST for HTTP. You can specify either or both.
sourceimpl RuleGroupSourceListDetails
impl RuleGroupSourceListDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture RuleGroupSourceListDetails.