#[non_exhaustive]pub struct RuleGroupSourceStatefulRulesDetails { /* private fields */ }Expand description
A Suricata rule specification.
Implementations
sourceimpl RuleGroupSourceStatefulRulesDetails
impl RuleGroupSourceStatefulRulesDetails
sourcepub fn action(&self) -> Option<&str>
pub fn action(&self) -> Option<&str>
Defines what Network Firewall should do with the packets in a traffic flow when the flow matches the stateful rule criteria.
sourcepub fn header(&self) -> Option<&RuleGroupSourceStatefulRulesHeaderDetails>
pub fn header(&self) -> Option<&RuleGroupSourceStatefulRulesHeaderDetails>
The stateful inspection criteria for the rule.
sourcepub fn rule_options(
&self
) -> Option<&[RuleGroupSourceStatefulRulesOptionsDetails]>
pub fn rule_options(
&self
) -> Option<&[RuleGroupSourceStatefulRulesOptionsDetails]>
Additional options for the rule.
sourceimpl RuleGroupSourceStatefulRulesDetails
impl RuleGroupSourceStatefulRulesDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture RuleGroupSourceStatefulRulesDetails.