#[non_exhaustive]pub struct RuleGroupSourceStatelessRuleDefinition { /* private fields */ }Expand description
The definition of the stateless rule.
Implementations
sourceimpl RuleGroupSourceStatelessRuleDefinition
impl RuleGroupSourceStatelessRuleDefinition
sourcepub fn actions(&self) -> Option<&[String]>
pub fn actions(&self) -> Option<&[String]>
The actions to take on a packet that matches one of the stateless rule definition's match attributes. You must specify a standard action (aws:pass, aws:drop, or aws:forward_to_sfe). You can then add custom actions.
sourcepub fn match_attributes(
&self
) -> Option<&RuleGroupSourceStatelessRuleMatchAttributes>
pub fn match_attributes(
&self
) -> Option<&RuleGroupSourceStatelessRuleMatchAttributes>
The criteria for Network Firewall to use to inspect an individual packet in a stateless rule inspection.
sourceimpl RuleGroupSourceStatelessRuleDefinition
impl RuleGroupSourceStatelessRuleDefinition
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture RuleGroupSourceStatelessRuleDefinition.