Struct aws_sdk_securityhub::model::SensitiveDataResult
source · [−]#[non_exhaustive]pub struct SensitiveDataResult { /* private fields */ }Expand description
Contains a detected instance of sensitive data that are based on built-in identifiers.
Implementations
sourceimpl SensitiveDataResult
impl SensitiveDataResult
sourcepub fn category(&self) -> Option<&str>
pub fn category(&self) -> Option<&str>
The category of sensitive data that was detected. For example, the category can indicate that the sensitive data involved credentials, financial information, or personal information.
sourcepub fn detections(&self) -> Option<&[SensitiveDataDetections]>
pub fn detections(&self) -> Option<&[SensitiveDataDetections]>
The list of detected instances of sensitive data.
sourcepub fn total_count(&self) -> i64
pub fn total_count(&self) -> i64
The total number of occurrences of sensitive data.
sourceimpl SensitiveDataResult
impl SensitiveDataResult
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture SensitiveDataResult.