Struct aws_sdk_securityhub::model::StandardsStatusReason
source · [−]#[non_exhaustive]pub struct StandardsStatusReason { /* private fields */ }Expand description
The reason for the current status of a standard subscription.
Implementations
sourceimpl StandardsStatusReason
impl StandardsStatusReason
sourcepub fn status_reason_code(&self) -> Option<&StatusReasonCode>
pub fn status_reason_code(&self) -> Option<&StatusReasonCode>
The reason code that represents the reason for the current status of a standard subscription.
sourceimpl StandardsStatusReason
impl StandardsStatusReason
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture StandardsStatusReason.