Struct aws_sdk_securityhub::model::StandardsSubscription
source · [−]#[non_exhaustive]pub struct StandardsSubscription { /* private fields */ }Expand description
A resource that represents your subscription to a supported standard.
Implementations
sourceimpl StandardsSubscription
impl StandardsSubscription
sourcepub fn standards_subscription_arn(&self) -> Option<&str>
pub fn standards_subscription_arn(&self) -> Option<&str>
The ARN of a resource that represents your subscription to a supported standard.
sourcepub fn standards_arn(&self) -> Option<&str>
pub fn standards_arn(&self) -> Option<&str>
The ARN of a standard.
sourcepub fn standards_input(&self) -> Option<&HashMap<String, String>>
pub fn standards_input(&self) -> Option<&HashMap<String, String>>
A key-value pair of input for the standard.
sourcepub fn standards_status(&self) -> Option<&StandardsStatus>
pub fn standards_status(&self) -> Option<&StandardsStatus>
The status of the standard subscription.
The status values are as follows:
-
PENDING- Standard is in the process of being enabled. -
READY- Standard is enabled. -
INCOMPLETE- Standard could not be enabled completely. Some controls may not be available. -
DELETING- Standard is in the process of being disabled. -
FAILED- Standard could not be disabled.
sourcepub fn standards_status_reason(&self) -> Option<&StandardsStatusReason>
pub fn standards_status_reason(&self) -> Option<&StandardsStatusReason>
The reason for the current status.
sourceimpl StandardsSubscription
impl StandardsSubscription
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture StandardsSubscription.