Struct aws_sdk_securityhub::model::StatusReason
source · [−]#[non_exhaustive]pub struct StatusReason { /* private fields */ }Expand description
Provides additional context for the value of Compliance.Status.
Implementations
sourceimpl StatusReason
impl StatusReason
sourcepub fn reason_code(&self) -> Option<&str>
pub fn reason_code(&self) -> Option<&str>
A code that represents a reason for the control status. For the list of status reason codes and their meanings, see Standards-related information in the ASFF in the Security Hub User Guide.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The corresponding description for the status reason code.
sourceimpl StatusReason
impl StatusReason
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture StatusReason.