#[non_exhaustive]pub struct VpcInfoPeeringOptionsDetails { /* private fields */ }Expand description
Provides information about the VPC peering connection options for the accepter or requester VPC.
Implementations
sourceimpl VpcInfoPeeringOptionsDetails
impl VpcInfoPeeringOptionsDetails
sourcepub fn allow_dns_resolution_from_remote_vpc(&self) -> bool
pub fn allow_dns_resolution_from_remote_vpc(&self) -> bool
Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
sourcepub fn allow_egress_from_local_classic_link_to_remote_vpc(&self) -> bool
pub fn allow_egress_from_local_classic_link_to_remote_vpc(&self) -> bool
Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
sourcepub fn allow_egress_from_local_vpc_to_remote_classic_link(&self) -> bool
pub fn allow_egress_from_local_vpc_to_remote_classic_link(&self) -> bool
Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
sourceimpl VpcInfoPeeringOptionsDetails
impl VpcInfoPeeringOptionsDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture VpcInfoPeeringOptionsDetails.