Struct aws_sdk_securityhub::model::Vulnerability
source · [−]#[non_exhaustive]pub struct Vulnerability { /* private fields */ }Expand description
A vulnerability associated with a finding.
Implementations
sourceimpl Vulnerability
impl Vulnerability
sourcepub fn vulnerable_packages(&self) -> Option<&[SoftwarePackage]>
pub fn vulnerable_packages(&self) -> Option<&[SoftwarePackage]>
List of software packages that have the vulnerability.
sourcepub fn cvss(&self) -> Option<&[Cvss]>
pub fn cvss(&self) -> Option<&[Cvss]>
CVSS scores from the advisory related to the vulnerability.
List of vulnerabilities that are related to this vulnerability.
sourcepub fn vendor(&self) -> Option<&VulnerabilityVendor>
pub fn vendor(&self) -> Option<&VulnerabilityVendor>
Information about the vendor that generates the vulnerability report.
sourcepub fn reference_urls(&self) -> Option<&[String]>
pub fn reference_urls(&self) -> Option<&[String]>
A list of URLs that provide additional information about the vulnerability.
sourcepub fn fix_available(&self) -> Option<&VulnerabilityFixAvailable>
pub fn fix_available(&self) -> Option<&VulnerabilityFixAvailable>
Specifies if all vulnerable packages in a finding have a value for FixedInVersion and Remediation. This field is evaluated for each vulnerability Id based on the number of vulnerable packages that have a value for both FixedInVersion and Remediation. Valid values are as follows:
-
YESif all vulnerable packages have a value for bothFixedInVersionandRemediation -
NOif no vulnerable packages have a value forFixedInVersionandRemediation -
PARTIALotherwise
sourceimpl Vulnerability
impl Vulnerability
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture Vulnerability.