#[non_exhaustive]pub struct DeclineInvitationsOutput {
pub unprocessed_accounts: Option<Vec<Result>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.unprocessed_accounts: Option<Vec<Result>>The list of Amazon Web Services accounts that were not processed. For each account, the list includes the account ID and the email address.
Implementations
sourceimpl DeclineInvitationsOutput
impl DeclineInvitationsOutput
sourcepub fn unprocessed_accounts(&self) -> &[Result]
pub fn unprocessed_accounts(&self) -> &[Result]
The list of Amazon Web Services accounts that were not processed. For each account, the list includes the account ID and the email address.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .unprocessed_accounts.is_none().
sourceimpl DeclineInvitationsOutput
impl DeclineInvitationsOutput
sourcepub fn builder() -> DeclineInvitationsOutputBuilder
pub fn builder() -> DeclineInvitationsOutputBuilder
Creates a new builder-style object to manufacture DeclineInvitationsOutput.