pub struct EnableSecurityHubFeatureV2FluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to EnableSecurityHubFeatureV2.
Enables an opt-in feature for the calling account in the current Amazon Web Services Region. The service must be enabled before you can enable a feature. The operation is idempotent. If the feature is already enabled, no changes are made. You cannot enable a feature that is managed by an organization policy.
Implementations
Sourceimpl EnableSecurityHubFeatureV2FluentBuilder
impl EnableSecurityHubFeatureV2FluentBuilder
Sourcepub fn as_input(&self) -> &EnableSecurityHubFeatureV2InputBuilder
pub fn as_input(&self) -> &EnableSecurityHubFeatureV2InputBuilder
Access the EnableSecurityHubFeatureV2 as a reference.
Sourcepub async fn send(
self,
) -> Result<EnableSecurityHubFeatureV2Output, SdkError<EnableSecurityHubFeatureV2Error, HttpResponse>>
pub async fn send( self, ) -> Result<EnableSecurityHubFeatureV2Output, SdkError<EnableSecurityHubFeatureV2Error, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<EnableSecurityHubFeatureV2Output, EnableSecurityHubFeatureV2Error, Self>
pub fn customize( self, ) -> CustomizableOperation<EnableSecurityHubFeatureV2Output, EnableSecurityHubFeatureV2Error, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn feature_name(self, input: FeatureName) -> Self
pub fn feature_name(self, input: FeatureName) -> Self
The name of the feature to enable.
Sourcepub fn set_feature_name(self, input: Option<FeatureName>) -> Self
pub fn set_feature_name(self, input: Option<FeatureName>) -> Self
The name of the feature to enable.
Sourcepub fn get_feature_name(&self) -> &Option<FeatureName>
pub fn get_feature_name(&self) -> &Option<FeatureName>
The name of the feature to enable.