#[non_exhaustive]pub struct GetConnectorOutputBuilder { /* private fields */ }Expand description
A builder for GetConnectorOutput.
Implementations
Sourceimpl GetConnectorOutputBuilder
impl GetConnectorOutputBuilder
Sourcepub fn connector_arn(self, input: impl Into<String>) -> Self
pub fn connector_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the connector.
Sourcepub fn set_connector_arn(self, input: Option<String>) -> Self
pub fn set_connector_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the connector.
Sourcepub fn get_connector_arn(&self) -> &Option<String>
pub fn get_connector_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the connector.
Sourcepub fn connector_id(self, input: impl Into<String>) -> Self
pub fn connector_id(self, input: impl Into<String>) -> Self
The unique identifier of the connector.
This field is required.Sourcepub fn set_connector_id(self, input: Option<String>) -> Self
pub fn set_connector_id(self, input: Option<String>) -> Self
The unique identifier of the connector.
Sourcepub fn get_connector_id(&self) -> &Option<String>
pub fn get_connector_id(&self) -> &Option<String>
The unique identifier of the connector.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the connector.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the connector.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the connector.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the connector.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The ISO 8601 UTC timestamp indicating when the connector was created.
This field is required.Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The ISO 8601 UTC timestamp indicating when the connector was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The ISO 8601 UTC timestamp indicating when the connector was created.
Sourcepub fn last_updated_at(self, input: DateTime) -> Self
pub fn last_updated_at(self, input: DateTime) -> Self
The ISO 8601 UTC timestamp indicating when the connector was last updated.
This field is required.Sourcepub fn set_last_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_last_updated_at(self, input: Option<DateTime>) -> Self
The ISO 8601 UTC timestamp indicating when the connector was last updated.
Sourcepub fn get_last_updated_at(&self) -> &Option<DateTime>
pub fn get_last_updated_at(&self) -> &Option<DateTime>
The ISO 8601 UTC timestamp indicating when the connector was last updated.
Sourcepub fn health(self, input: CspmHealthCheck) -> Self
pub fn health(self, input: CspmHealthCheck) -> Self
The health status of the connector, including connectivity status and last check time.
This field is required.Sourcepub fn set_health(self, input: Option<CspmHealthCheck>) -> Self
pub fn set_health(self, input: Option<CspmHealthCheck>) -> Self
The health status of the connector, including connectivity status and last check time.
Sourcepub fn get_health(&self) -> &Option<CspmHealthCheck>
pub fn get_health(&self) -> &Option<CspmHealthCheck>
The health status of the connector, including connectivity status and last check time.
Sourcepub fn provider_detail(self, input: CspmProviderDetail) -> Self
pub fn provider_detail(self, input: CspmProviderDetail) -> Self
The cloud provider configuration details for the connector.
This field is required.Sourcepub fn set_provider_detail(self, input: Option<CspmProviderDetail>) -> Self
pub fn set_provider_detail(self, input: Option<CspmProviderDetail>) -> Self
The cloud provider configuration details for the connector.
Sourcepub fn get_provider_detail(&self) -> &Option<CspmProviderDetail>
pub fn get_provider_detail(&self) -> &Option<CspmProviderDetail>
The cloud provider configuration details for the connector.
Sourcepub fn created_by(self, input: impl Into<String>) -> Self
pub fn created_by(self, input: impl Into<String>) -> Self
The service principal that created the connector.
Sourcepub fn set_created_by(self, input: Option<String>) -> Self
pub fn set_created_by(self, input: Option<String>) -> Self
The service principal that created the connector.
Sourcepub fn get_created_by(&self) -> &Option<String>
pub fn get_created_by(&self) -> &Option<String>
The service principal that created the connector.
Sourcepub fn enablement_status(self, input: CspmEnablementStatus) -> Self
pub fn enablement_status(self, input: CspmEnablementStatus) -> Self
The enablement status of the connector.
Sourcepub fn set_enablement_status(self, input: Option<CspmEnablementStatus>) -> Self
pub fn set_enablement_status(self, input: Option<CspmEnablementStatus>) -> Self
The enablement status of the connector.
Sourcepub fn get_enablement_status(&self) -> &Option<CspmEnablementStatus>
pub fn get_enablement_status(&self) -> &Option<CspmEnablementStatus>
The enablement status of the connector.
Sourcepub fn build(self) -> GetConnectorOutput
pub fn build(self) -> GetConnectorOutput
Consumes the builder and constructs a GetConnectorOutput.