GetConnectorOutput

Struct GetConnectorOutput 

#[non_exhaustive]
pub struct GetConnectorOutput { pub connector_arn: Option<String>, pub connector_id: Option<String>, pub name: Option<String>, pub description: Option<String>, pub created_at: Option<DateTime>, pub last_updated_at: Option<DateTime>, pub health: Option<CspmHealthCheck>, pub provider_detail: Option<CspmProviderDetail>, pub created_by: Option<String>, pub enablement_status: Option<CspmEnablementStatus>, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
connector_arn: Option<String>

The Amazon Resource Name (ARN) of the connector.

connector_id: Option<String>

The unique identifier of the connector.

name: Option<String>

The name of the connector.

description: Option<String>

The description of the connector.

created_at: Option<DateTime>

The ISO 8601 UTC timestamp indicating when the connector was created.

last_updated_at: Option<DateTime>

The ISO 8601 UTC timestamp indicating when the connector was last updated.

health: Option<CspmHealthCheck>

The health status of the connector, including connectivity status and last check time.

provider_detail: Option<CspmProviderDetail>

The cloud provider configuration details for the connector.

created_by: Option<String>

The service principal that created the connector.

enablement_status: Option<CspmEnablementStatus>

The enablement status of the connector.

Implementations

Source

impl GetConnectorOutput

pub fn connector_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the connector.

pub fn connector_id(&self) -> Option<&str>

The unique identifier of the connector.

pub fn name(&self) -> Option<&str>

The name of the connector.

pub fn description(&self) -> Option<&str>

The description of the connector.

pub fn created_at(&self) -> Option<&DateTime>

The ISO 8601 UTC timestamp indicating when the connector was created.

pub fn last_updated_at(&self) -> Option<&DateTime>

The ISO 8601 UTC timestamp indicating when the connector was last updated.

pub fn health(&self) -> Option<&CspmHealthCheck>

The health status of the connector, including connectivity status and last check time.

pub fn provider_detail(&self) -> Option<&CspmProviderDetail>

The cloud provider configuration details for the connector.

pub fn created_by(&self) -> Option<&str>

The service principal that created the connector.

pub fn enablement_status(&self) -> Option<&CspmEnablementStatus>

The enablement status of the connector.

Source

impl GetConnectorOutput

pub fn builder() -> GetConnectorOutputBuilder

Creates a new builder-style object to manufacture GetConnectorOutput.