pub struct GetFindingStatisticsV2FluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetFindingStatisticsV2.
Returns aggregated statistical data about findings.
You can use the Scopes parameter to define the data boundary for the query. Currently, Scopes supports AwsOrganizations, which lets you aggregate findings from your entire organization or from specific organizational units. Only the delegated administrator account can use Scopes.
GetFindingStatisticsV2 uses securityhub:GetAdhocInsightResults in the Action element of an IAM policy statement. You must have permission to perform the securityhub:GetAdhocInsightResults action.
Implementations
Sourceimpl GetFindingStatisticsV2FluentBuilder
impl GetFindingStatisticsV2FluentBuilder
Sourcepub fn as_input(&self) -> &GetFindingStatisticsV2InputBuilder
pub fn as_input(&self) -> &GetFindingStatisticsV2InputBuilder
Access the GetFindingStatisticsV2 as a reference.
Sourcepub async fn send(
self,
) -> Result<GetFindingStatisticsV2Output, SdkError<GetFindingStatisticsV2Error, HttpResponse>>
pub async fn send( self, ) -> Result<GetFindingStatisticsV2Output, SdkError<GetFindingStatisticsV2Error, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetFindingStatisticsV2Output, GetFindingStatisticsV2Error, Self>
pub fn customize( self, ) -> CustomizableOperation<GetFindingStatisticsV2Output, GetFindingStatisticsV2Error, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn group_by_rules(self, input: GroupByRule) -> Self
pub fn group_by_rules(self, input: GroupByRule) -> Self
Appends an item to GroupByRules.
To override the contents of this collection use set_group_by_rules.
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn set_group_by_rules(self, input: Option<Vec<GroupByRule>>) -> Self
pub fn set_group_by_rules(self, input: Option<Vec<GroupByRule>>) -> Self
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn get_group_by_rules(&self) -> &Option<Vec<GroupByRule>>
pub fn get_group_by_rules(&self) -> &Option<Vec<GroupByRule>>
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn scopes(self, input: FindingScopes) -> Self
pub fn scopes(self, input: FindingScopes) -> Self
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn set_scopes(self, input: Option<FindingScopes>) -> Self
pub fn set_scopes(self, input: Option<FindingScopes>) -> Self
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn get_scopes(&self) -> &Option<FindingScopes>
pub fn get_scopes(&self) -> &Option<FindingScopes>
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn sort_order(self, input: SortOrder) -> Self
pub fn sort_order(self, input: SortOrder) -> Self
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn set_sort_order(self, input: Option<SortOrder>) -> Self
pub fn set_sort_order(self, input: Option<SortOrder>) -> Self
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn get_sort_order(&self) -> &Option<SortOrder>
pub fn get_sort_order(&self) -> &Option<SortOrder>
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn max_statistic_results(self, input: i32) -> Self
pub fn max_statistic_results(self, input: i32) -> Self
The maximum number of results to be returned.
Sourcepub fn set_max_statistic_results(self, input: Option<i32>) -> Self
pub fn set_max_statistic_results(self, input: Option<i32>) -> Self
The maximum number of results to be returned.
Sourcepub fn get_max_statistic_results(&self) -> &Option<i32>
pub fn get_max_statistic_results(&self) -> &Option<i32>
The maximum number of results to be returned.