#[non_exhaustive]pub struct GetFindingStatisticsV2InputBuilder { /* private fields */ }Expand description
A builder for GetFindingStatisticsV2Input.
Implementations
Sourceimpl GetFindingStatisticsV2InputBuilder
impl GetFindingStatisticsV2InputBuilder
Sourcepub fn group_by_rules(self, input: GroupByRule) -> Self
pub fn group_by_rules(self, input: GroupByRule) -> Self
Appends an item to group_by_rules.
To override the contents of this collection use set_group_by_rules.
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn set_group_by_rules(self, input: Option<Vec<GroupByRule>>) -> Self
pub fn set_group_by_rules(self, input: Option<Vec<GroupByRule>>) -> Self
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn get_group_by_rules(&self) -> &Option<Vec<GroupByRule>>
pub fn get_group_by_rules(&self) -> &Option<Vec<GroupByRule>>
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
Sourcepub fn scopes(self, input: FindingScopes) -> Self
pub fn scopes(self, input: FindingScopes) -> Self
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn set_scopes(self, input: Option<FindingScopes>) -> Self
pub fn set_scopes(self, input: Option<FindingScopes>) -> Self
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn get_scopes(&self) -> &Option<FindingScopes>
pub fn get_scopes(&self) -> &Option<FindingScopes>
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn sort_order(self, input: SortOrder) -> Self
pub fn sort_order(self, input: SortOrder) -> Self
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn set_sort_order(self, input: Option<SortOrder>) -> Self
pub fn set_sort_order(self, input: Option<SortOrder>) -> Self
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn get_sort_order(&self) -> &Option<SortOrder>
pub fn get_sort_order(&self) -> &Option<SortOrder>
Orders the aggregation count in descending or ascending order. Descending order is the default.
Sourcepub fn max_statistic_results(self, input: i32) -> Self
pub fn max_statistic_results(self, input: i32) -> Self
The maximum number of results to be returned.
Sourcepub fn set_max_statistic_results(self, input: Option<i32>) -> Self
pub fn set_max_statistic_results(self, input: Option<i32>) -> Self
The maximum number of results to be returned.
Sourcepub fn get_max_statistic_results(&self) -> &Option<i32>
pub fn get_max_statistic_results(&self) -> &Option<i32>
The maximum number of results to be returned.
Sourcepub fn build(self) -> Result<GetFindingStatisticsV2Input, BuildError>
pub fn build(self) -> Result<GetFindingStatisticsV2Input, BuildError>
Consumes the builder and constructs a GetFindingStatisticsV2Input.
Sourceimpl GetFindingStatisticsV2InputBuilder
impl GetFindingStatisticsV2InputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetFindingStatisticsV2Output, SdkError<GetFindingStatisticsV2Error, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetFindingStatisticsV2Output, SdkError<GetFindingStatisticsV2Error, HttpResponse>>
Sends a request with this input using the given client.