#[non_exhaustive]pub struct GetResourcesV2InputBuilder { /* private fields */ }Expand description
A builder for GetResourcesV2Input.
Implementations
Sourceimpl GetResourcesV2InputBuilder
impl GetResourcesV2InputBuilder
Sourcepub fn filters(self, input: ResourcesFilters) -> Self
pub fn filters(self, input: ResourcesFilters) -> Self
Filters resources based on a set of criteria.
Sourcepub fn set_filters(self, input: Option<ResourcesFilters>) -> Self
pub fn set_filters(self, input: Option<ResourcesFilters>) -> Self
Filters resources based on a set of criteria.
Sourcepub fn get_filters(&self) -> &Option<ResourcesFilters>
pub fn get_filters(&self) -> &Option<ResourcesFilters>
Filters resources based on a set of criteria.
Sourcepub fn scopes(self, input: ResourceScopes) -> Self
pub fn scopes(self, input: ResourceScopes) -> Self
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn set_scopes(self, input: Option<ResourceScopes>) -> Self
pub fn set_scopes(self, input: Option<ResourceScopes>) -> Self
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn get_scopes(&self) -> &Option<ResourceScopes>
pub fn get_scopes(&self) -> &Option<ResourceScopes>
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
Sourcepub fn sort_criteria(self, input: SortCriterion) -> Self
pub fn sort_criteria(self, input: SortCriterion) -> Self
Appends an item to sort_criteria.
To override the contents of this collection use set_sort_criteria.
The resource attributes used to sort the list of returned resources.
Sourcepub fn set_sort_criteria(self, input: Option<Vec<SortCriterion>>) -> Self
pub fn set_sort_criteria(self, input: Option<Vec<SortCriterion>>) -> Self
The resource attributes used to sort the list of returned resources.
Sourcepub fn get_sort_criteria(&self) -> &Option<Vec<SortCriterion>>
pub fn get_sort_criteria(&self) -> &Option<Vec<SortCriterion>>
The resource attributes used to sort the list of returned resources.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return.
Sourcepub fn build(self) -> Result<GetResourcesV2Input, BuildError>
pub fn build(self) -> Result<GetResourcesV2Input, BuildError>
Consumes the builder and constructs a GetResourcesV2Input.
Sourceimpl GetResourcesV2InputBuilder
impl GetResourcesV2InputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetResourcesV2Output, SdkError<GetResourcesV2Error, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetResourcesV2Output, SdkError<GetResourcesV2Error, HttpResponse>>
Sends a request with this input using the given client.