#[non_exhaustive]pub struct ListConnectorsInputBuilder { /* private fields */ }Expand description
A builder for ListConnectorsInput.
Implementations
Sourceimpl ListConnectorsInputBuilder
impl ListConnectorsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The pagination token to request the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The pagination token to request the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The pagination token to request the next page of results.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return.
Sourcepub fn provider_name(self, input: CspmConnectorProviderName) -> Self
pub fn provider_name(self, input: CspmConnectorProviderName) -> Self
The name of the cloud provider to filter connectors by.
Sourcepub fn set_provider_name(self, input: Option<CspmConnectorProviderName>) -> Self
pub fn set_provider_name(self, input: Option<CspmConnectorProviderName>) -> Self
The name of the cloud provider to filter connectors by.
Sourcepub fn get_provider_name(&self) -> &Option<CspmConnectorProviderName>
pub fn get_provider_name(&self) -> &Option<CspmConnectorProviderName>
The name of the cloud provider to filter connectors by.
Sourcepub fn connector_status(self, input: CspmConnectorStatus) -> Self
pub fn connector_status(self, input: CspmConnectorStatus) -> Self
The connectivity status to filter connectors by.
Sourcepub fn set_connector_status(self, input: Option<CspmConnectorStatus>) -> Self
pub fn set_connector_status(self, input: Option<CspmConnectorStatus>) -> Self
The connectivity status to filter connectors by.
Sourcepub fn get_connector_status(&self) -> &Option<CspmConnectorStatus>
pub fn get_connector_status(&self) -> &Option<CspmConnectorStatus>
The connectivity status to filter connectors by.
Sourcepub fn enablement_status(self, input: CspmEnablementStatus) -> Self
pub fn enablement_status(self, input: CspmEnablementStatus) -> Self
The enablement status to filter connectors by.
Sourcepub fn set_enablement_status(self, input: Option<CspmEnablementStatus>) -> Self
pub fn set_enablement_status(self, input: Option<CspmEnablementStatus>) -> Self
The enablement status to filter connectors by.
Sourcepub fn get_enablement_status(&self) -> &Option<CspmEnablementStatus>
pub fn get_enablement_status(&self) -> &Option<CspmEnablementStatus>
The enablement status to filter connectors by.
Sourcepub fn build(self) -> Result<ListConnectorsInput, BuildError>
pub fn build(self) -> Result<ListConnectorsInput, BuildError>
Consumes the builder and constructs a ListConnectorsInput.
Sourceimpl ListConnectorsInputBuilder
impl ListConnectorsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListConnectorsOutput, SdkError<ListConnectorsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListConnectorsOutput, SdkError<ListConnectorsError, HttpResponse>>
Sends a request with this input using the given client.