#[non_exhaustive]pub struct ListConnectorsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub provider_name: Option<CspmConnectorProviderName>,
pub connector_status: Option<CspmConnectorStatus>,
pub enablement_status: Option<CspmEnablementStatus>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The pagination token to request the next page of results.
max_results: Option<i32>The maximum number of results to return.
provider_name: Option<CspmConnectorProviderName>The name of the cloud provider to filter connectors by.
connector_status: Option<CspmConnectorStatus>The connectivity status to filter connectors by.
enablement_status: Option<CspmEnablementStatus>The enablement status to filter connectors by.
Implementations
Sourceimpl ListConnectorsInput
impl ListConnectorsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token to request the next page of results.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return.
Sourcepub fn provider_name(&self) -> Option<&CspmConnectorProviderName>
pub fn provider_name(&self) -> Option<&CspmConnectorProviderName>
The name of the cloud provider to filter connectors by.
Sourcepub fn connector_status(&self) -> Option<&CspmConnectorStatus>
pub fn connector_status(&self) -> Option<&CspmConnectorStatus>
The connectivity status to filter connectors by.
Sourcepub fn enablement_status(&self) -> Option<&CspmEnablementStatus>
pub fn enablement_status(&self) -> Option<&CspmEnablementStatus>
The enablement status to filter connectors by.
Sourceimpl ListConnectorsInput
impl ListConnectorsInput
Sourcepub fn builder() -> ListConnectorsInputBuilder
pub fn builder() -> ListConnectorsInputBuilder
Creates a new builder-style object to manufacture ListConnectorsInput.