pub struct Builder { /* private fields */ }Expand description
A builder for BatchDisableStandardsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
pub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The details of the standards subscriptions that were disabled.
sourcepub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
pub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
The details of the standards subscriptions that were disabled.
sourcepub fn build(self) -> BatchDisableStandardsOutput
pub fn build(self) -> BatchDisableStandardsOutput
Consumes the builder and constructs a BatchDisableStandardsOutput.