pub struct Builder { /* private fields */ }Expand description
A builder for BatchEnableStandardsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
pub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The details of the standards subscriptions that were enabled.
sourcepub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
pub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
The details of the standards subscriptions that were enabled.
sourcepub fn build(self) -> BatchEnableStandardsOutput
pub fn build(self) -> BatchEnableStandardsOutput
Consumes the builder and constructs a BatchEnableStandardsOutput.