Struct aws_sdk_securityhub::output::batch_update_findings_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchUpdateFindingsOutput
Implementations
Appends an item to processed_findings.
To override the contents of this collection use set_processed_findings.
The list of findings that were updated successfully.
The list of findings that were updated successfully.
pub fn unprocessed_findings(
self,
input: impl Into<BatchUpdateFindingsUnprocessedFinding>
) -> Self
pub fn unprocessed_findings(
self,
input: impl Into<BatchUpdateFindingsUnprocessedFinding>
) -> Self
Appends an item to unprocessed_findings.
To override the contents of this collection use set_unprocessed_findings.
The list of findings that were not updated.
pub fn set_unprocessed_findings(
self,
input: Option<Vec<BatchUpdateFindingsUnprocessedFinding>>
) -> Self
pub fn set_unprocessed_findings(
self,
input: Option<Vec<BatchUpdateFindingsUnprocessedFinding>>
) -> Self
The list of findings that were not updated.
Consumes the builder and constructs a BatchUpdateFindingsOutput