pub struct Builder { /* private fields */ }Expand description
A builder for DeclineInvitationsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn unprocessed_accounts(self, input: Result) -> Self
pub fn unprocessed_accounts(self, input: Result) -> Self
Appends an item to unprocessed_accounts.
To override the contents of this collection use set_unprocessed_accounts.
The list of Amazon Web Services accounts that were not processed. For each account, the list includes the account ID and the email address.
sourcepub fn set_unprocessed_accounts(self, input: Option<Vec<Result>>) -> Self
pub fn set_unprocessed_accounts(self, input: Option<Vec<Result>>) -> Self
The list of Amazon Web Services accounts that were not processed. For each account, the list includes the account ID and the email address.
sourcepub fn build(self) -> DeclineInvitationsOutput
pub fn build(self) -> DeclineInvitationsOutput
Consumes the builder and constructs a DeclineInvitationsOutput.