pub struct Builder { /* private fields */ }Expand description
A builder for DeleteInvitationsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn unprocessed_accounts(self, input: Result) -> Self
pub fn unprocessed_accounts(self, input: Result) -> Self
Appends an item to unprocessed_accounts.
To override the contents of this collection use set_unprocessed_accounts.
The list of Amazon Web Services accounts for which the invitations were not deleted. For each account, the list includes the account ID and the email address.
sourcepub fn set_unprocessed_accounts(self, input: Option<Vec<Result>>) -> Self
pub fn set_unprocessed_accounts(self, input: Option<Vec<Result>>) -> Self
The list of Amazon Web Services accounts for which the invitations were not deleted. For each account, the list includes the account ID and the email address.
sourcepub fn build(self) -> DeleteInvitationsOutput
pub fn build(self) -> DeleteInvitationsOutput
Consumes the builder and constructs a DeleteInvitationsOutput.