Struct aws_sdk_securityhub::output::delete_members_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeleteMembersOutput
Implementations
Appends an item to unprocessed_accounts.
To override the contents of this collection use set_unprocessed_accounts.
The list of Amazon Web Services accounts that were not deleted. For each account, the list includes the account ID and the email address.
The list of Amazon Web Services accounts that were not deleted. For each account, the list includes the account ID and the email address.
Consumes the builder and constructs a DeleteMembersOutput