Struct aws_sdk_securityhub::output::describe_hub_output::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for DescribeHubOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn hub_arn(self, input: impl Into<String>) -> Self
pub fn hub_arn(self, input: impl Into<String>) -> Self
The ARN of the Hub resource that was retrieved.
sourcepub fn set_hub_arn(self, input: Option<String>) -> Self
pub fn set_hub_arn(self, input: Option<String>) -> Self
The ARN of the Hub resource that was retrieved.
sourcepub fn subscribed_at(self, input: impl Into<String>) -> Self
pub fn subscribed_at(self, input: impl Into<String>) -> Self
The date and time when Security Hub was enabled in the account.
sourcepub fn set_subscribed_at(self, input: Option<String>) -> Self
pub fn set_subscribed_at(self, input: Option<String>) -> Self
The date and time when Security Hub was enabled in the account.
sourcepub fn auto_enable_controls(self, input: bool) -> Self
pub fn auto_enable_controls(self, input: bool) -> Self
Whether to automatically enable new controls when they are added to standards that are enabled.
If set to true, then new controls for enabled standards are enabled automatically. If set to false, then new controls are not enabled.
sourcepub fn set_auto_enable_controls(self, input: Option<bool>) -> Self
pub fn set_auto_enable_controls(self, input: Option<bool>) -> Self
Whether to automatically enable new controls when they are added to standards that are enabled.
If set to true, then new controls for enabled standards are enabled automatically. If set to false, then new controls are not enabled.
sourcepub fn build(self) -> DescribeHubOutput
pub fn build(self) -> DescribeHubOutput
Consumes the builder and constructs a DescribeHubOutput.