pub struct Builder { /* private fields */ }Expand description
A builder for GetEnabledStandardsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
pub fn standards_subscriptions(self, input: StandardsSubscription) -> Self
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The list of StandardsSubscriptions objects that include information about the enabled standards.
sourcepub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
pub fn set_standards_subscriptions(
self,
input: Option<Vec<StandardsSubscription>>
) -> Self
The list of StandardsSubscriptions objects that include information about the enabled standards.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The pagination token to use to request the next page of results.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The pagination token to use to request the next page of results.
sourcepub fn build(self) -> GetEnabledStandardsOutput
pub fn build(self) -> GetEnabledStandardsOutput
Consumes the builder and constructs a GetEnabledStandardsOutput.