Struct aws_sdk_securityhub::output::get_invitations_count_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetInvitationsCountOutput
Implementations
The number of all membership invitations sent to this Security Hub member account, not including the currently accepted invitation.
The number of all membership invitations sent to this Security Hub member account, not including the currently accepted invitation.
Consumes the builder and constructs a GetInvitationsCountOutput