pub struct Builder { /* private fields */ }Expand description
A builder for ListFindingAggregatorsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn finding_aggregators(self, input: FindingAggregator) -> Self
pub fn finding_aggregators(self, input: FindingAggregator) -> Self
Appends an item to finding_aggregators.
To override the contents of this collection use set_finding_aggregators.
The list of finding aggregators. This operation currently only returns a single result.
sourcepub fn set_finding_aggregators(
self,
input: Option<Vec<FindingAggregator>>
) -> Self
pub fn set_finding_aggregators(
self,
input: Option<Vec<FindingAggregator>>
) -> Self
The list of finding aggregators. This operation currently only returns a single result.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
sourcepub fn build(self) -> ListFindingAggregatorsOutput
pub fn build(self) -> ListFindingAggregatorsOutput
Consumes the builder and constructs a ListFindingAggregatorsOutput.