Struct aws_sdk_securityhub::output::list_invitations_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListInvitationsOutput
Implementations
Appends an item to invitations.
To override the contents of this collection use set_invitations.
The details of the invitations returned by the operation.
The details of the invitations returned by the operation.
The pagination token to use to request the next page of results.
The pagination token to use to request the next page of results.
Consumes the builder and constructs a ListInvitationsOutput