#[non_exhaustive]pub struct DeclineInvitationsOutput { /* private fields */ }Implementations
sourceimpl DeclineInvitationsOutput
impl DeclineInvitationsOutput
sourcepub fn unprocessed_accounts(&self) -> Option<&[Result]>
pub fn unprocessed_accounts(&self) -> Option<&[Result]>
The list of Amazon Web Services accounts that were not processed. For each account, the list includes the account ID and the email address.
sourceimpl DeclineInvitationsOutput
impl DeclineInvitationsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeclineInvitationsOutput.