Struct aws_sdk_securityhub::output::DeleteMembersOutput
source · [−]#[non_exhaustive]pub struct DeleteMembersOutput { /* private fields */ }Implementations
sourceimpl DeleteMembersOutput
impl DeleteMembersOutput
sourcepub fn unprocessed_accounts(&self) -> Option<&[Result]>
pub fn unprocessed_accounts(&self) -> Option<&[Result]>
The list of Amazon Web Services accounts that were not deleted. For each account, the list includes the account ID and the email address.
sourceimpl DeleteMembersOutput
impl DeleteMembersOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeleteMembersOutput.