#[non_exhaustive]pub struct DescribeActionTargetsOutput { /* private fields */ }Implementations
sourceimpl DescribeActionTargetsOutput
impl DescribeActionTargetsOutput
sourcepub fn action_targets(&self) -> Option<&[ActionTarget]>
pub fn action_targets(&self) -> Option<&[ActionTarget]>
A list of ActionTarget objects. Each object includes the ActionTargetArn, Description, and Name of a custom action target available in Security Hub.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token to use to request the next page of results.
sourceimpl DescribeActionTargetsOutput
impl DescribeActionTargetsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeActionTargetsOutput.