Struct aws_sdk_securityhub::output::DescribeHubOutput
source · #[non_exhaustive]pub struct DescribeHubOutput { /* private fields */ }Implementations
sourceimpl DescribeHubOutput
impl DescribeHubOutput
sourcepub fn subscribed_at(&self) -> Option<&str>
pub fn subscribed_at(&self) -> Option<&str>
The date and time when Security Hub was enabled in the account.
sourcepub fn auto_enable_controls(&self) -> bool
pub fn auto_enable_controls(&self) -> bool
Whether to automatically enable new controls when they are added to standards that are enabled.
If set to true, then new controls for enabled standards are enabled automatically. If set to false, then new controls are not enabled.
sourceimpl DescribeHubOutput
impl DescribeHubOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeHubOutput.