#[non_exhaustive]pub struct DescribeOrganizationConfigurationOutput { /* private fields */ }Implementations
sourceimpl DescribeOrganizationConfigurationOutput
impl DescribeOrganizationConfigurationOutput
sourcepub fn auto_enable(&self) -> bool
pub fn auto_enable(&self) -> bool
Whether to automatically enable Security Hub for new accounts in the organization.
If set to true, then Security Hub is enabled for new accounts. If set to false, then new accounts are not added automatically.
sourcepub fn member_account_limit_reached(&self) -> bool
pub fn member_account_limit_reached(&self) -> bool
Whether the maximum number of allowed member accounts are already associated with the Security Hub administrator account.
sourcepub fn auto_enable_standards(&self) -> Option<&AutoEnableStandards>
pub fn auto_enable_standards(&self) -> Option<&AutoEnableStandards>
Whether to automatically enable Security Hub default standards for new member accounts in the organization.
The default value of this parameter is equal to DEFAULT.
If equal to DEFAULT, then Security Hub default standards are automatically enabled for new member accounts. If equal to NONE, then default standards are not automatically enabled for new member accounts.
sourceimpl DescribeOrganizationConfigurationOutput
impl DescribeOrganizationConfigurationOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeOrganizationConfigurationOutput.