#[non_exhaustive]pub struct GetEnabledStandardsOutput { /* private fields */ }Implementations
sourceimpl GetEnabledStandardsOutput
impl GetEnabledStandardsOutput
sourcepub fn standards_subscriptions(&self) -> Option<&[StandardsSubscription]>
pub fn standards_subscriptions(&self) -> Option<&[StandardsSubscription]>
The list of StandardsSubscriptions objects that include information about the enabled standards.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token to use to request the next page of results.
sourceimpl GetEnabledStandardsOutput
impl GetEnabledStandardsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GetEnabledStandardsOutput.