#[non_exhaustive]pub struct GetFindingAggregatorOutput { /* private fields */ }Implementations
sourceimpl GetFindingAggregatorOutput
impl GetFindingAggregatorOutput
sourcepub fn finding_aggregator_arn(&self) -> Option<&str>
pub fn finding_aggregator_arn(&self) -> Option<&str>
The ARN of the finding aggregator.
sourcepub fn finding_aggregation_region(&self) -> Option<&str>
pub fn finding_aggregation_region(&self) -> Option<&str>
The aggregation Region.
sourcepub fn region_linking_mode(&self) -> Option<&str>
pub fn region_linking_mode(&self) -> Option<&str>
Indicates whether to link all Regions, all Regions except for a list of excluded Regions, or a list of included Regions.
sourceimpl GetFindingAggregatorOutput
impl GetFindingAggregatorOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GetFindingAggregatorOutput.