Struct aws_sdk_securityhub::output::GetFindingsOutput
source · #[non_exhaustive]pub struct GetFindingsOutput { /* private fields */ }Implementations
sourceimpl GetFindingsOutput
impl GetFindingsOutput
sourcepub fn findings(&self) -> Option<&[AwsSecurityFinding]>
pub fn findings(&self) -> Option<&[AwsSecurityFinding]>
The findings that matched the filters specified in the request.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token to use to request the next page of results.
sourceimpl GetFindingsOutput
impl GetFindingsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GetFindingsOutput.