#[non_exhaustive]
pub struct ListFindingAggregatorsOutput { /* private fields */ }

Implementations

The list of finding aggregators. This operation currently only returns a single result.

If there are more results, this is the token to provide in the next call to ListFindingAggregators.

This operation currently only returns a single result.

Creates a new builder-style object to manufacture ListFindingAggregatorsOutput.