Struct aws_sdk_securityhub::output::ListInvitationsOutput
source · [−]#[non_exhaustive]pub struct ListInvitationsOutput { /* private fields */ }Implementations
sourceimpl ListInvitationsOutput
impl ListInvitationsOutput
sourcepub fn invitations(&self) -> Option<&[Invitation]>
pub fn invitations(&self) -> Option<&[Invitation]>
The details of the invitations returned by the operation.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token to use to request the next page of results.
sourceimpl ListInvitationsOutput
impl ListInvitationsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListInvitationsOutput.