#[non_exhaustive]pub struct AccountFreeTrialStatusBuilder { /* private fields */ }Expand description
A builder for AccountFreeTrialStatus.
Implementations
Sourceimpl AccountFreeTrialStatusBuilder
impl AccountFreeTrialStatusBuilder
Sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account identifier that the free trial statuses apply to.
This field is required.Sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
The Amazon Web Services account identifier that the free trial statuses apply to.
Sourcepub fn get_account_id(&self) -> &Option<String>
pub fn get_account_id(&self) -> &Option<String>
The Amazon Web Services account identifier that the free trial statuses apply to.
Sourcepub fn evaluated_at(self, input: DateTime) -> Self
pub fn evaluated_at(self, input: DateTime) -> Self
The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.
Sourcepub fn set_evaluated_at(self, input: Option<DateTime>) -> Self
pub fn set_evaluated_at(self, input: Option<DateTime>) -> Self
The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.
Sourcepub fn get_evaluated_at(&self) -> &Option<DateTime>
pub fn get_evaluated_at(&self) -> &Option<DateTime>
The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.
Sourcepub fn free_trial_statuses(self, input: FreeTrialStatus) -> Self
pub fn free_trial_statuses(self, input: FreeTrialStatus) -> Self
Appends an item to free_trial_statuses.
To override the contents of this collection use set_free_trial_statuses.
An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.
Sourcepub fn set_free_trial_statuses(
self,
input: Option<Vec<FreeTrialStatus>>,
) -> Self
pub fn set_free_trial_statuses( self, input: Option<Vec<FreeTrialStatus>>, ) -> Self
An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.
Sourcepub fn get_free_trial_statuses(&self) -> &Option<Vec<FreeTrialStatus>>
pub fn get_free_trial_statuses(&self) -> &Option<Vec<FreeTrialStatus>>
An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.
Sourcepub fn build(self) -> AccountFreeTrialStatus
pub fn build(self) -> AccountFreeTrialStatus
Consumes the builder and constructs a AccountFreeTrialStatus.