#[non_exhaustive]pub struct AiDetailsBuilder { /* private fields */ }Expand description
A builder for AiDetails.
Implementations
Sourceimpl AiDetailsBuilder
impl AiDetailsBuilder
Sourcepub fn host_resource_guid(self, input: impl Into<String>) -> Self
pub fn host_resource_guid(self, input: impl Into<String>) -> Self
The identifier of the host resource that hosts the self-hosted AI resource. Present only on self-hosted AI resources.
Sourcepub fn set_host_resource_guid(self, input: Option<String>) -> Self
pub fn set_host_resource_guid(self, input: Option<String>) -> Self
The identifier of the host resource that hosts the self-hosted AI resource. Present only on self-hosted AI resources.
Sourcepub fn get_host_resource_guid(&self) -> &Option<String>
pub fn get_host_resource_guid(&self) -> &Option<String>
The identifier of the host resource that hosts the self-hosted AI resource. Present only on self-hosted AI resources.
Sourcepub fn host_resource_type(self, input: impl Into<String>) -> Self
pub fn host_resource_type(self, input: impl Into<String>) -> Self
The ResourceType of the host resource that hosts the self-hosted AI resource, such as AWS::EC2::Instance. Present only on self-hosted AI resources.
Sourcepub fn set_host_resource_type(self, input: Option<String>) -> Self
pub fn set_host_resource_type(self, input: Option<String>) -> Self
The ResourceType of the host resource that hosts the self-hosted AI resource, such as AWS::EC2::Instance. Present only on self-hosted AI resources.
Sourcepub fn get_host_resource_type(&self) -> &Option<String>
pub fn get_host_resource_type(&self) -> &Option<String>
The ResourceType of the host resource that hosts the self-hosted AI resource, such as AWS::EC2::Instance. Present only on self-hosted AI resources.
Sourcepub fn canonical_id(self, input: impl Into<String>) -> Self
pub fn canonical_id(self, input: impl Into<String>) -> Self
The canonical identifier for the AI resource, independent of where it is deployed. Multiple occurrences of the same resource on different hosts share the same CanonicalId. For model resources, the value follows the format model/, such as model/pkg:huggingface/meta-llama/llama-3-8b. Present only on self-hosted AI resources.
Sourcepub fn set_canonical_id(self, input: Option<String>) -> Self
pub fn set_canonical_id(self, input: Option<String>) -> Self
The canonical identifier for the AI resource, independent of where it is deployed. Multiple occurrences of the same resource on different hosts share the same CanonicalId. For model resources, the value follows the format model/, such as model/pkg:huggingface/meta-llama/llama-3-8b. Present only on self-hosted AI resources.
Sourcepub fn get_canonical_id(&self) -> &Option<String>
pub fn get_canonical_id(&self) -> &Option<String>
The canonical identifier for the AI resource, independent of where it is deployed. Multiple occurrences of the same resource on different hosts share the same CanonicalId. For model resources, the value follows the format model/, such as model/pkg:huggingface/meta-llama/llama-3-8b. Present only on self-hosted AI resources.
Sourcepub fn self_hosted_ai_model_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_model_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory Model detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_model_resource_count(self, input: Option<i32>) -> Self
pub fn set_self_hosted_ai_model_resource_count(self, input: Option<i32>) -> Self
The number of self-hosted AI resources of ResourceSubCategory Model detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_model_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_ai_model_resource_count(&self) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory Model detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_agent_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_agent_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory Agent detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_agent_resource_count(self, input: Option<i32>) -> Self
pub fn set_self_hosted_ai_agent_resource_count(self, input: Option<i32>) -> Self
The number of self-hosted AI resources of ResourceSubCategory Agent detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_agent_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_ai_agent_resource_count(&self) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory Agent detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_model_serving_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_model_serving_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory ModelServing detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_model_serving_resource_count(
self,
input: Option<i32>,
) -> Self
pub fn set_self_hosted_ai_model_serving_resource_count( self, input: Option<i32>, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory ModelServing detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_model_serving_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_ai_model_serving_resource_count(&self) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory ModelServing detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_external_endpoint_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_external_endpoint_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory ExternalEndpoint detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_external_endpoint_resource_count(
self,
input: Option<i32>,
) -> Self
pub fn set_self_hosted_ai_external_endpoint_resource_count( self, input: Option<i32>, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory ExternalEndpoint detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_external_endpoint_resource_count(
&self,
) -> &Option<i32>
pub fn get_self_hosted_ai_external_endpoint_resource_count( &self, ) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory ExternalEndpoint detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_development_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_development_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory Development detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_development_resource_count(
self,
input: Option<i32>,
) -> Self
pub fn set_self_hosted_ai_development_resource_count( self, input: Option<i32>, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory Development detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_development_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_ai_development_resource_count(&self) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory Development detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_agent_framework_resource_count(self, input: i32) -> Self
pub fn self_hosted_ai_agent_framework_resource_count(self, input: i32) -> Self
The number of self-hosted AI resources of ResourceSubCategory AgentFramework detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_agent_framework_resource_count(
self,
input: Option<i32>,
) -> Self
pub fn set_self_hosted_ai_agent_framework_resource_count( self, input: Option<i32>, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory AgentFramework detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_agent_framework_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_ai_agent_framework_resource_count(&self) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory AgentFramework detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_ai_agent_tools_and_identity_resource_count(
self,
input: i32,
) -> Self
pub fn self_hosted_ai_agent_tools_and_identity_resource_count( self, input: i32, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory AgentToolsAndIdentity detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_ai_agent_tools_and_identity_resource_count(
self,
input: Option<i32>,
) -> Self
pub fn set_self_hosted_ai_agent_tools_and_identity_resource_count( self, input: Option<i32>, ) -> Self
The number of self-hosted AI resources of ResourceSubCategory AgentToolsAndIdentity detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_ai_agent_tools_and_identity_resource_count(
&self,
) -> &Option<i32>
pub fn get_self_hosted_ai_agent_tools_and_identity_resource_count( &self, ) -> &Option<i32>
The number of self-hosted AI resources of ResourceSubCategory AgentToolsAndIdentity detected on the host resource. Present only on host resources.
Sourcepub fn self_hosted_total_ai_resource_count(self, input: i32) -> Self
pub fn self_hosted_total_ai_resource_count(self, input: i32) -> Self
The total number of all self-hosted AI resources detected on the host resource. Present only on host resources.
Sourcepub fn set_self_hosted_total_ai_resource_count(self, input: Option<i32>) -> Self
pub fn set_self_hosted_total_ai_resource_count(self, input: Option<i32>) -> Self
The total number of all self-hosted AI resources detected on the host resource. Present only on host resources.
Sourcepub fn get_self_hosted_total_ai_resource_count(&self) -> &Option<i32>
pub fn get_self_hosted_total_ai_resource_count(&self) -> &Option<i32>
The total number of all self-hosted AI resources detected on the host resource. Present only on host resources.