#[non_exhaustive]pub struct AwsOrganizationScopeBuilder { /* private fields */ }Expand description
A builder for AwsOrganizationScope.
Implementations
Sourceimpl AwsOrganizationScopeBuilder
impl AwsOrganizationScopeBuilder
Sourcepub fn organization_id(self, input: impl Into<String>) -> Self
pub fn organization_id(self, input: impl Into<String>) -> Self
The unique identifier (ID) of the organization (for example, o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provide OrganizationalUnitId, Security Hub uses the caller's organization ID.
Sourcepub fn set_organization_id(self, input: Option<String>) -> Self
pub fn set_organization_id(self, input: Option<String>) -> Self
The unique identifier (ID) of the organization (for example, o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provide OrganizationalUnitId, Security Hub uses the caller's organization ID.
Sourcepub fn get_organization_id(&self) -> &Option<String>
pub fn get_organization_id(&self) -> &Option<String>
The unique identifier (ID) of the organization (for example, o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provide OrganizationalUnitId, Security Hub uses the caller's organization ID.
Sourcepub fn organizational_unit_id(self, input: impl Into<String>) -> Self
pub fn organizational_unit_id(self, input: impl Into<String>) -> Self
The unique identifier (ID) of the organizational unit (OU) (for example, ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
Sourcepub fn set_organizational_unit_id(self, input: Option<String>) -> Self
pub fn set_organizational_unit_id(self, input: Option<String>) -> Self
The unique identifier (ID) of the organizational unit (OU) (for example, ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
Sourcepub fn get_organizational_unit_id(&self) -> &Option<String>
pub fn get_organizational_unit_id(&self) -> &Option<String>
The unique identifier (ID) of the organizational unit (OU) (for example, ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
Sourcepub fn build(self) -> AwsOrganizationScope
pub fn build(self) -> AwsOrganizationScope
Consumes the builder and constructs a AwsOrganizationScope.