#[non_exhaustive]pub struct AzureDetailBuilder { /* private fields */ }Expand description
A builder for AzureDetail.
Implementations
Sourceimpl AzureDetailBuilder
impl AzureDetailBuilder
Sourcepub fn aws_config_connector_arn(self, input: impl Into<String>) -> Self
pub fn aws_config_connector_arn(self, input: impl Into<String>) -> Self
The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
This field is required.Sourcepub fn set_aws_config_connector_arn(self, input: Option<String>) -> Self
pub fn set_aws_config_connector_arn(self, input: Option<String>) -> Self
The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
Sourcepub fn get_aws_config_connector_arn(&self) -> &Option<String>
pub fn get_aws_config_connector_arn(&self) -> &Option<String>
The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
Sourcepub fn scope_configuration(self, input: AzureScopeConfiguration) -> Self
pub fn scope_configuration(self, input: AzureScopeConfiguration) -> Self
The scope configuration that defines which Azure resources are monitored.
This field is required.Sourcepub fn set_scope_configuration(
self,
input: Option<AzureScopeConfiguration>,
) -> Self
pub fn set_scope_configuration( self, input: Option<AzureScopeConfiguration>, ) -> Self
The scope configuration that defines which Azure resources are monitored.
Sourcepub fn get_scope_configuration(&self) -> &Option<AzureScopeConfiguration>
pub fn get_scope_configuration(&self) -> &Option<AzureScopeConfiguration>
The scope configuration that defines which Azure resources are monitored.
Sourcepub fn azure_regions(self, input: impl Into<String>) -> Self
pub fn azure_regions(self, input: impl Into<String>) -> Self
Appends an item to azure_regions.
To override the contents of this collection use set_azure_regions.
The list of Azure regions being monitored.
Sourcepub fn set_azure_regions(self, input: Option<Vec<String>>) -> Self
pub fn set_azure_regions(self, input: Option<Vec<String>>) -> Self
The list of Azure regions being monitored.
Sourcepub fn get_azure_regions(&self) -> &Option<Vec<String>>
pub fn get_azure_regions(&self) -> &Option<Vec<String>>
The list of Azure regions being monitored.
Sourcepub fn build(self) -> AzureDetail
pub fn build(self) -> AzureDetail
Consumes the builder and constructs a AzureDetail.