#[non_exhaustive]pub struct AzureScopeConfigurationBuilder { /* private fields */ }Expand description
A builder for AzureScopeConfiguration.
Implementations
Sourceimpl AzureScopeConfigurationBuilder
impl AzureScopeConfigurationBuilder
Sourcepub fn scope_type(self, input: ScopeType) -> Self
pub fn scope_type(self, input: ScopeType) -> Self
The type of scope. Valid values are tenant and subscription.
Sourcepub fn set_scope_type(self, input: Option<ScopeType>) -> Self
pub fn set_scope_type(self, input: Option<ScopeType>) -> Self
The type of scope. Valid values are tenant and subscription.
Sourcepub fn get_scope_type(&self) -> &Option<ScopeType>
pub fn get_scope_type(&self) -> &Option<ScopeType>
The type of scope. Valid values are tenant and subscription.
Sourcepub fn scope_values(self, input: impl Into<String>) -> Self
pub fn scope_values(self, input: impl Into<String>) -> Self
Appends an item to scope_values.
To override the contents of this collection use set_scope_values.
The list of scope values, such as subscription IDs, when the scope type is subscription.
Sourcepub fn set_scope_values(self, input: Option<Vec<String>>) -> Self
pub fn set_scope_values(self, input: Option<Vec<String>>) -> Self
The list of scope values, such as subscription IDs, when the scope type is subscription.
Sourcepub fn get_scope_values(&self) -> &Option<Vec<String>>
pub fn get_scope_values(&self) -> &Option<Vec<String>>
The list of scope values, such as subscription IDs, when the scope type is subscription.
Sourcepub fn build(self) -> AzureScopeConfiguration
pub fn build(self) -> AzureScopeConfiguration
Consumes the builder and constructs a AzureScopeConfiguration.