#[non_exhaustive]pub struct CspmHealthCheckBuilder { /* private fields */ }Expand description
A builder for CspmHealthCheck.
Implementations
Sourceimpl CspmHealthCheckBuilder
impl CspmHealthCheckBuilder
Sourcepub fn connector_status(self, input: CspmConnectorStatus) -> Self
pub fn connector_status(self, input: CspmConnectorStatus) -> Self
The connectivity status of the connector.
This field is required.Sourcepub fn set_connector_status(self, input: Option<CspmConnectorStatus>) -> Self
pub fn set_connector_status(self, input: Option<CspmConnectorStatus>) -> Self
The connectivity status of the connector.
Sourcepub fn get_connector_status(&self) -> &Option<CspmConnectorStatus>
pub fn get_connector_status(&self) -> &Option<CspmConnectorStatus>
The connectivity status of the connector.
Sourcepub fn message(self, input: impl Into<String>) -> Self
pub fn message(self, input: impl Into<String>) -> Self
A message describing the reason for the current connector status.
Sourcepub fn set_message(self, input: Option<String>) -> Self
pub fn set_message(self, input: Option<String>) -> Self
A message describing the reason for the current connector status.
Sourcepub fn get_message(&self) -> &Option<String>
pub fn get_message(&self) -> &Option<String>
A message describing the reason for the current connector status.
Sourcepub fn last_checked_at(self, input: DateTime) -> Self
pub fn last_checked_at(self, input: DateTime) -> Self
The ISO 8601 UTC timestamp indicating when the health status was last checked.
This field is required.Sourcepub fn set_last_checked_at(self, input: Option<DateTime>) -> Self
pub fn set_last_checked_at(self, input: Option<DateTime>) -> Self
The ISO 8601 UTC timestamp indicating when the health status was last checked.
Sourcepub fn get_last_checked_at(&self) -> &Option<DateTime>
pub fn get_last_checked_at(&self) -> &Option<DateTime>
The ISO 8601 UTC timestamp indicating when the health status was last checked.
Sourcepub fn issues(self, input: HealthIssue) -> Self
pub fn issues(self, input: HealthIssue) -> Self
Appends an item to issues.
To override the contents of this collection use set_issues.
A list of health issues associated with the connector.
Sourcepub fn set_issues(self, input: Option<Vec<HealthIssue>>) -> Self
pub fn set_issues(self, input: Option<Vec<HealthIssue>>) -> Self
A list of health issues associated with the connector.
Sourcepub fn get_issues(&self) -> &Option<Vec<HealthIssue>>
pub fn get_issues(&self) -> &Option<Vec<HealthIssue>>
A list of health issues associated with the connector.
Sourcepub fn build(self) -> CspmHealthCheck
pub fn build(self) -> CspmHealthCheck
Consumes the builder and constructs a CspmHealthCheck.