#[non_exhaustive]pub struct FeatureDetailBuilder { /* private fields */ }Expand description
A builder for FeatureDetail.
Implementations
Sourceimpl FeatureDetailBuilder
impl FeatureDetailBuilder
Sourcepub fn feature_status(self, input: FeatureStatus) -> Self
pub fn feature_status(self, input: FeatureStatus) -> Self
The current enablement status of the feature. Valid values: ENABLED | DISABLED.
Sourcepub fn set_feature_status(self, input: Option<FeatureStatus>) -> Self
pub fn set_feature_status(self, input: Option<FeatureStatus>) -> Self
The current enablement status of the feature. Valid values: ENABLED | DISABLED.
Sourcepub fn get_feature_status(&self) -> &Option<FeatureStatus>
pub fn get_feature_status(&self) -> &Option<FeatureStatus>
The current enablement status of the feature. Valid values: ENABLED | DISABLED.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time when the feature status was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time when the feature status was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time when the feature status was last updated.
Sourcepub fn build(self) -> FeatureDetail
pub fn build(self) -> FeatureDetail
Consumes the builder and constructs a FeatureDetail.