#[non_exhaustive]pub struct FindingScopesBuilder { /* private fields */ }Expand description
A builder for FindingScopes.
Implementations
Sourceimpl FindingScopesBuilder
impl FindingScopesBuilder
Sourcepub fn aws_organizations(self, input: AwsOrganizationScope) -> Self
pub fn aws_organizations(self, input: AwsOrganizationScope) -> Self
Appends an item to aws_organizations.
To override the contents of this collection use set_aws_organizations.
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Sourcepub fn set_aws_organizations(
self,
input: Option<Vec<AwsOrganizationScope>>,
) -> Self
pub fn set_aws_organizations( self, input: Option<Vec<AwsOrganizationScope>>, ) -> Self
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Sourcepub fn get_aws_organizations(&self) -> &Option<Vec<AwsOrganizationScope>>
pub fn get_aws_organizations(&self) -> &Option<Vec<AwsOrganizationScope>>
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Sourcepub fn build(self) -> FindingScopes
pub fn build(self) -> FindingScopes
Consumes the builder and constructs a FindingScopes.