#[non_exhaustive]pub struct FreeTrialStatusBuilder { /* private fields */ }Expand description
A builder for FreeTrialStatus.
Implementations
Sourceimpl FreeTrialStatusBuilder
impl FreeTrialStatusBuilder
Sourcepub fn feature_type(self, input: FreeTrialType) -> Self
pub fn feature_type(self, input: FreeTrialType) -> Self
The feature that the free trial period applies to. Valid values:
-
SECURITY_HUB_V2specifies Security Hub. -
SECURITY_HUB_V2_MULTI_CLOUD_AZUREspecifies Security Hub coverage for Microsoft Azure resources.
Sourcepub fn set_feature_type(self, input: Option<FreeTrialType>) -> Self
pub fn set_feature_type(self, input: Option<FreeTrialType>) -> Self
The feature that the free trial period applies to. Valid values:
-
SECURITY_HUB_V2specifies Security Hub. -
SECURITY_HUB_V2_MULTI_CLOUD_AZUREspecifies Security Hub coverage for Microsoft Azure resources.
Sourcepub fn get_feature_type(&self) -> &Option<FreeTrialType>
pub fn get_feature_type(&self) -> &Option<FreeTrialType>
The feature that the free trial period applies to. Valid values:
-
SECURITY_HUB_V2specifies Security Hub. -
SECURITY_HUB_V2_MULTI_CLOUD_AZUREspecifies Security Hub coverage for Microsoft Azure resources.
Sourcepub fn status(self, input: FreeTrialStatusValue) -> Self
pub fn status(self, input: FreeTrialStatusValue) -> Self
Whether the free trial period is currently active. Valid values:
-
ACTIVEspecifies that the free trial period is ongoing. -
INACTIVEspecifies that the free trial period has ended, or that it never started.
To determine whether a trial has expired, compare ExpiresAt to the current time.
Sourcepub fn set_status(self, input: Option<FreeTrialStatusValue>) -> Self
pub fn set_status(self, input: Option<FreeTrialStatusValue>) -> Self
Whether the free trial period is currently active. Valid values:
-
ACTIVEspecifies that the free trial period is ongoing. -
INACTIVEspecifies that the free trial period has ended, or that it never started.
To determine whether a trial has expired, compare ExpiresAt to the current time.
Sourcepub fn get_status(&self) -> &Option<FreeTrialStatusValue>
pub fn get_status(&self) -> &Option<FreeTrialStatusValue>
Whether the free trial period is currently active. Valid values:
-
ACTIVEspecifies that the free trial period is ongoing. -
INACTIVEspecifies that the free trial period has ended, or that it never started.
To determine whether a trial has expired, compare ExpiresAt to the current time.
Sourcepub fn started_at(self, input: DateTime) -> Self
pub fn started_at(self, input: DateTime) -> Self
The date and time at which the free trial period began.
This field is required.Sourcepub fn set_started_at(self, input: Option<DateTime>) -> Self
pub fn set_started_at(self, input: Option<DateTime>) -> Self
The date and time at which the free trial period began.
Sourcepub fn get_started_at(&self) -> &Option<DateTime>
pub fn get_started_at(&self) -> &Option<DateTime>
The date and time at which the free trial period began.
Sourcepub fn expires_at(self, input: DateTime) -> Self
pub fn expires_at(self, input: DateTime) -> Self
The date and time at which the free trial period ends.
This field is required.Sourcepub fn set_expires_at(self, input: Option<DateTime>) -> Self
pub fn set_expires_at(self, input: Option<DateTime>) -> Self
The date and time at which the free trial period ends.
Sourcepub fn get_expires_at(&self) -> &Option<DateTime>
pub fn get_expires_at(&self) -> &Option<DateTime>
The date and time at which the free trial period ends.
Sourcepub fn build(self) -> FreeTrialStatus
pub fn build(self) -> FreeTrialStatus
Consumes the builder and constructs a FreeTrialStatus.