#[non_exhaustive]pub struct HealthIssueBuilder { /* private fields */ }Expand description
A builder for HealthIssue.
Implementations
Sourceimpl HealthIssueBuilder
impl HealthIssueBuilder
Sourcepub fn code(self, input: HealthIssueCode) -> Self
pub fn code(self, input: HealthIssueCode) -> Self
The error code that identifies the type of health issue.
This field is required.Sourcepub fn set_code(self, input: Option<HealthIssueCode>) -> Self
pub fn set_code(self, input: Option<HealthIssueCode>) -> Self
The error code that identifies the type of health issue.
Sourcepub fn get_code(&self) -> &Option<HealthIssueCode>
pub fn get_code(&self) -> &Option<HealthIssueCode>
The error code that identifies the type of health issue.
Sourcepub fn message(self, input: impl Into<String>) -> Self
pub fn message(self, input: impl Into<String>) -> Self
A human-readable message that describes the health issue.
This field is required.Sourcepub fn set_message(self, input: Option<String>) -> Self
pub fn set_message(self, input: Option<String>) -> Self
A human-readable message that describes the health issue.
Sourcepub fn get_message(&self) -> &Option<String>
pub fn get_message(&self) -> &Option<String>
A human-readable message that describes the health issue.
Sourcepub fn build(self) -> HealthIssue
pub fn build(self) -> HealthIssue
Consumes the builder and constructs a HealthIssue.