#[non_exhaustive]pub struct ResourceOwnerBuilder { /* private fields */ }Expand description
A builder for ResourceOwner.
Implementations
Sourceimpl ResourceOwnerBuilder
impl ResourceOwnerBuilder
Sourcepub fn account(self, input: ResourceOwnerAccount) -> Self
pub fn account(self, input: ResourceOwnerAccount) -> Self
Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
Sourcepub fn set_account(self, input: Option<ResourceOwnerAccount>) -> Self
pub fn set_account(self, input: Option<ResourceOwnerAccount>) -> Self
Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
Sourcepub fn get_account(&self) -> &Option<ResourceOwnerAccount>
pub fn get_account(&self) -> &Option<ResourceOwnerAccount>
Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
Sourcepub fn org(self, input: ResourceOwnerOrg) -> Self
pub fn org(self, input: ResourceOwnerOrg) -> Self
Information about the organization that owns the resource, for example, an Azure Tenant.
Sourcepub fn set_org(self, input: Option<ResourceOwnerOrg>) -> Self
pub fn set_org(self, input: Option<ResourceOwnerOrg>) -> Self
Information about the organization that owns the resource, for example, an Azure Tenant.
Sourcepub fn get_org(&self) -> &Option<ResourceOwnerOrg>
pub fn get_org(&self) -> &Option<ResourceOwnerOrg>
Information about the organization that owns the resource, for example, an Azure Tenant.
Sourcepub fn build(self) -> ResourceOwner
pub fn build(self) -> ResourceOwner
Consumes the builder and constructs a ResourceOwner.