#[non_exhaustive]pub struct ResourceOwnerOrgBuilder { /* private fields */ }Expand description
A builder for ResourceOwnerOrg.
Implementations
Sourceimpl ResourceOwnerOrgBuilder
impl ResourceOwnerOrgBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.
Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.
Sourcepub fn build(self) -> ResourceOwnerOrg
pub fn build(self) -> ResourceOwnerOrg
Consumes the builder and constructs a ResourceOwnerOrg.