#[non_exhaustive]pub struct UnusedPermissionsRecommendationStepBuilder { /* private fields */ }Expand description
A builder for UnusedPermissionsRecommendationStep.
Implementations
Sourceimpl UnusedPermissionsRecommendationStepBuilder
impl UnusedPermissionsRecommendationStepBuilder
Sourcepub fn recommended_action(self, input: impl Into<String>) -> Self
pub fn recommended_action(self, input: impl Into<String>) -> Self
A recommendation of whether to create or detach a policy for an unused permissions finding.
Sourcepub fn set_recommended_action(self, input: Option<String>) -> Self
pub fn set_recommended_action(self, input: Option<String>) -> Self
A recommendation of whether to create or detach a policy for an unused permissions finding.
Sourcepub fn get_recommended_action(&self) -> &Option<String>
pub fn get_recommended_action(&self) -> &Option<String>
A recommendation of whether to create or detach a policy for an unused permissions finding.
Sourcepub fn existing_policy(self, input: impl Into<String>) -> Self
pub fn existing_policy(self, input: impl Into<String>) -> Self
The contents of the existing policy identified by ExistingPolicyId which needs to be replaced, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn set_existing_policy(self, input: Option<String>) -> Self
pub fn set_existing_policy(self, input: Option<String>) -> Self
The contents of the existing policy identified by ExistingPolicyId which needs to be replaced, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn get_existing_policy(&self) -> &Option<String>
pub fn get_existing_policy(&self) -> &Option<String>
The contents of the existing policy identified by ExistingPolicyId which needs to be replaced, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn existing_policy_id(self, input: impl Into<String>) -> Self
pub fn existing_policy_id(self, input: impl Into<String>) -> Self
The ID of an existing policy to be replaced or detached.
Sourcepub fn set_existing_policy_id(self, input: Option<String>) -> Self
pub fn set_existing_policy_id(self, input: Option<String>) -> Self
The ID of an existing policy to be replaced or detached.
Sourcepub fn get_existing_policy_id(&self) -> &Option<String>
pub fn get_existing_policy_id(&self) -> &Option<String>
The ID of an existing policy to be replaced or detached.
Sourcepub fn policy_updated_at(self, input: DateTime) -> Self
pub fn policy_updated_at(self, input: DateTime) -> Self
The time at which the existing policy for the unused permissions finding was last updated.
Sourcepub fn set_policy_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_policy_updated_at(self, input: Option<DateTime>) -> Self
The time at which the existing policy for the unused permissions finding was last updated.
Sourcepub fn get_policy_updated_at(&self) -> &Option<DateTime>
pub fn get_policy_updated_at(&self) -> &Option<DateTime>
The time at which the existing policy for the unused permissions finding was last updated.
Sourcepub fn recommended_policy(self, input: impl Into<String>) -> Self
pub fn recommended_policy(self, input: impl Into<String>) -> Self
The contents of the least-privileged recommended replacement for ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn set_recommended_policy(self, input: Option<String>) -> Self
pub fn set_recommended_policy(self, input: Option<String>) -> Self
The contents of the least-privileged recommended replacement for ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn get_recommended_policy(&self) -> &Option<String>
pub fn get_recommended_policy(&self) -> &Option<String>
The contents of the least-privileged recommended replacement for ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn build(self) -> UnusedPermissionsRecommendationStep
pub fn build(self) -> UnusedPermissionsRecommendationStep
Consumes the builder and constructs a UnusedPermissionsRecommendationStep.