#[non_exhaustive]pub enum RecommendationStep {
UnusedPermissions(UnusedPermissionsRecommendationStep),
#[non_exhaustive] Unknown,
}Expand description
Contains information about a recommended step to remediate a Security Hub finding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
UnusedPermissions(UnusedPermissionsRecommendationStep)
A recommended step to remediate an unused permissions finding.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl RecommendationStep
impl RecommendationStep
Sourcepub fn as_unused_permissions(
&self,
) -> Result<&UnusedPermissionsRecommendationStep, &Self>
pub fn as_unused_permissions( &self, ) -> Result<&UnusedPermissionsRecommendationStep, &Self>
Tries to convert the enum instance into UnusedPermissions, extracting the inner UnusedPermissionsRecommendationStep.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unused_permissions(&self) -> bool
pub fn is_unused_permissions(&self) -> bool
Returns true if this is a UnusedPermissions.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.