#[non_exhaustive]pub struct AccountFreeTrialStatus {
pub account_id: Option<String>,
pub evaluated_at: Option<DateTime>,
pub free_trial_statuses: Option<Vec<FreeTrialStatus>>,
}Expand description
The free trial status of each Security Hub feature for an account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.account_id: Option<String>The Amazon Web Services account identifier that the free trial statuses apply to.
evaluated_at: Option<DateTime>The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.
free_trial_statuses: Option<Vec<FreeTrialStatus>>An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.
Implementations
Sourceimpl AccountFreeTrialStatus
impl AccountFreeTrialStatus
Sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The Amazon Web Services account identifier that the free trial statuses apply to.
Sourcepub fn evaluated_at(&self) -> Option<&DateTime>
pub fn evaluated_at(&self) -> Option<&DateTime>
The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.
Sourcepub fn free_trial_statuses(&self) -> &[FreeTrialStatus]
pub fn free_trial_statuses(&self) -> &[FreeTrialStatus]
An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .free_trial_statuses.is_none().
Sourceimpl AccountFreeTrialStatus
impl AccountFreeTrialStatus
Sourcepub fn builder() -> AccountFreeTrialStatusBuilder
pub fn builder() -> AccountFreeTrialStatusBuilder
Creates a new builder-style object to manufacture AccountFreeTrialStatus.