#[non_exhaustive]pub struct AwsAutoScalingAutoScalingGroupDetails {
pub launch_configuration_name: Option<String>,
pub load_balancer_names: Option<Vec<String>>,
pub health_check_type: Option<String>,
pub health_check_grace_period: Option<i32>,
pub created_time: Option<String>,
pub mixed_instances_policy: Option<AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>,
pub availability_zones: Option<Vec<AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails>>,
pub launch_template: Option<AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>,
pub capacity_rebalance: Option<bool>,
}Expand description
Provides details about an auto scaling group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.launch_configuration_name: Option<String>The name of the launch configuration.
load_balancer_names: Option<Vec<String>>The list of load balancers associated with the group.
health_check_type: Option<String>The service to use for the health checks. Valid values are EC2 or ELB.
health_check_grace_period: Option<i32>The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
created_time: Option<String>Indicates when the auto scaling group was created.
This field accepts only the specified formats. Timestamps can end with Z or ("+" / "-") time-hour \[":" time-minute\]. The time-secfrac after seconds is limited to a maximum of 9 digits. The offset is bounded by +/-18:00. Here are valid timestamp formats with examples:
-
YYYY-MM-DDTHH:MM:SSZ(for example,2019-01-31T23:00:00Z) -
YYYY-MM-DDTHH:MM:SS.mmmmmmmmmZ(for example,2019-01-31T23:00:00.123456789Z) -
YYYY-MM-DDTHH:MM:SS+HH:MM(for example,2024-01-04T15:25:10+17:59) -
YYYY-MM-DDTHH:MM:SS-HHMM(for example,2024-01-04T15:25:10-1759) -
YYYY-MM-DDTHH:MM:SS.mmmmmmmmm+HH:MM(for example,2024-01-04T15:25:10.123456789+17:59)
mixed_instances_policy: Option<AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>The mixed instances policy for the automatic scaling group.
availability_zones: Option<Vec<AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails>>The list of Availability Zones for the automatic scaling group.
launch_template: Option<AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>The launch template to use.
capacity_rebalance: Option<bool>Indicates whether capacity rebalancing is enabled.
Implementations
sourceimpl AwsAutoScalingAutoScalingGroupDetails
impl AwsAutoScalingAutoScalingGroupDetails
sourcepub fn launch_configuration_name(&self) -> Option<&str>
pub fn launch_configuration_name(&self) -> Option<&str>
The name of the launch configuration.
sourcepub fn load_balancer_names(&self) -> &[String]
pub fn load_balancer_names(&self) -> &[String]
The list of load balancers associated with the group.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .load_balancer_names.is_none().
sourcepub fn health_check_type(&self) -> Option<&str>
pub fn health_check_type(&self) -> Option<&str>
The service to use for the health checks. Valid values are EC2 or ELB.
sourcepub fn health_check_grace_period(&self) -> Option<i32>
pub fn health_check_grace_period(&self) -> Option<i32>
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
sourcepub fn created_time(&self) -> Option<&str>
pub fn created_time(&self) -> Option<&str>
Indicates when the auto scaling group was created.
This field accepts only the specified formats. Timestamps can end with Z or ("+" / "-") time-hour \[":" time-minute\]. The time-secfrac after seconds is limited to a maximum of 9 digits. The offset is bounded by +/-18:00. Here are valid timestamp formats with examples:
-
YYYY-MM-DDTHH:MM:SSZ(for example,2019-01-31T23:00:00Z) -
YYYY-MM-DDTHH:MM:SS.mmmmmmmmmZ(for example,2019-01-31T23:00:00.123456789Z) -
YYYY-MM-DDTHH:MM:SS+HH:MM(for example,2024-01-04T15:25:10+17:59) -
YYYY-MM-DDTHH:MM:SS-HHMM(for example,2024-01-04T15:25:10-1759) -
YYYY-MM-DDTHH:MM:SS.mmmmmmmmm+HH:MM(for example,2024-01-04T15:25:10.123456789+17:59)
sourcepub fn mixed_instances_policy(
&self,
) -> Option<&AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>
pub fn mixed_instances_policy( &self, ) -> Option<&AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>
The mixed instances policy for the automatic scaling group.
sourcepub fn availability_zones(
&self,
) -> &[AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails]
pub fn availability_zones( &self, ) -> &[AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails]
The list of Availability Zones for the automatic scaling group.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .availability_zones.is_none().
sourcepub fn launch_template(
&self,
) -> Option<&AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>
pub fn launch_template( &self, ) -> Option<&AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>
The launch template to use.
sourcepub fn capacity_rebalance(&self) -> Option<bool>
pub fn capacity_rebalance(&self) -> Option<bool>
Indicates whether capacity rebalancing is enabled.
sourceimpl AwsAutoScalingAutoScalingGroupDetails
impl AwsAutoScalingAutoScalingGroupDetails
sourcepub fn builder() -> AwsAutoScalingAutoScalingGroupDetailsBuilder
pub fn builder() -> AwsAutoScalingAutoScalingGroupDetailsBuilder
Creates a new builder-style object to manufacture AwsAutoScalingAutoScalingGroupDetails.