Struct aws_sdk_securityhub::types::AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
source · #[non_exhaustive]pub struct AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails {
pub capacity_reservation_id: Option<String>,
pub capacity_reservation_resource_group_arn: Option<String>,
}Expand description
Information about the target Capacity Reservation or Capacity Reservation group in which to run an Amazon EC2 instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capacity_reservation_id: Option<String>The ID of the Capacity Reservation in which to run the instance.
capacity_reservation_resource_group_arn: Option<String>The Amazon Resource Name (ARN) of the Capacity Reservation resource group in which to run the instance.
Implementations
sourceimpl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
impl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
sourcepub fn capacity_reservation_id(&self) -> Option<&str>
pub fn capacity_reservation_id(&self) -> Option<&str>
The ID of the Capacity Reservation in which to run the instance.
sourcepub fn capacity_reservation_resource_group_arn(&self) -> Option<&str>
pub fn capacity_reservation_resource_group_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Capacity Reservation resource group in which to run the instance.
sourceimpl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
impl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
sourcepub fn builder() -> AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetailsBuilder
pub fn builder() -> AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetailsBuilder
Creates a new builder-style object to manufacture AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails.