#[non_exhaustive]pub struct AwsOrganizationScope {
pub organization_id: Option<String>,
pub organizational_unit_id: Option<String>,
}Expand description
Specifies an Organizations scope. Data from the specified organization or organizational unit is included in the response.
To scope to a specific organizational unit, provide OrganizationalUnitId. You can optionally include OrganizationId. If you omit OrganizationId, Security Hub uses the caller's organization ID. To scope to the delegated administrator's entire organization, provide only OrganizationId.
The organization ID and organizational unit must belong to the delegated administrator's own organization. Each request must use one scoping approach: either scope to the entire organization by providing an AwsOrganizationScope entry with only OrganizationId, or scope to specific organizational units by providing AwsOrganizationScope entries with OrganizationalUnitId. You can't combine both approaches in the same request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.organization_id: Option<String>The unique identifier (ID) of the organization (for example, o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provide OrganizationalUnitId, Security Hub uses the caller's organization ID.
organizational_unit_id: Option<String>The unique identifier (ID) of the organizational unit (OU) (for example, ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
Implementations
Sourceimpl AwsOrganizationScope
impl AwsOrganizationScope
Sourcepub fn organization_id(&self) -> Option<&str>
pub fn organization_id(&self) -> Option<&str>
The unique identifier (ID) of the organization (for example, o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provide OrganizationalUnitId, Security Hub uses the caller's organization ID.
Sourcepub fn organizational_unit_id(&self) -> Option<&str>
pub fn organizational_unit_id(&self) -> Option<&str>
The unique identifier (ID) of the organizational unit (OU) (for example, ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
Sourceimpl AwsOrganizationScope
impl AwsOrganizationScope
Sourcepub fn builder() -> AwsOrganizationScopeBuilder
pub fn builder() -> AwsOrganizationScopeBuilder
Creates a new builder-style object to manufacture AwsOrganizationScope.