#[non_exhaustive]pub struct AzureProviderConfiguration {
pub aws_config_connector_arn: Option<String>,
pub scope_configuration: Option<AzureScopeConfiguration>,
pub azure_regions: Option<Vec<String>>,
}Expand description
The configuration for connecting to an Azure environment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aws_config_connector_arn: Option<String>The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
scope_configuration: Option<AzureScopeConfiguration>The scope configuration that defines which Azure resources are monitored.
azure_regions: Option<Vec<String>>The list of Azure regions to monitor.
Implementations
Sourceimpl AzureProviderConfiguration
impl AzureProviderConfiguration
Sourcepub fn aws_config_connector_arn(&self) -> Option<&str>
pub fn aws_config_connector_arn(&self) -> Option<&str>
The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
Sourcepub fn scope_configuration(&self) -> Option<&AzureScopeConfiguration>
pub fn scope_configuration(&self) -> Option<&AzureScopeConfiguration>
The scope configuration that defines which Azure resources are monitored.
Sourcepub fn azure_regions(&self) -> &[String]
pub fn azure_regions(&self) -> &[String]
The list of Azure regions to monitor.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .azure_regions.is_none().
Sourceimpl AzureProviderConfiguration
impl AzureProviderConfiguration
Sourcepub fn builder() -> AzureProviderConfigurationBuilder
pub fn builder() -> AzureProviderConfigurationBuilder
Creates a new builder-style object to manufacture AzureProviderConfiguration.