#[non_exhaustive]pub struct CspmConnectorSummary {
pub connector_arn: Option<String>,
pub connector_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub provider_summary: Option<CspmProviderSummary>,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
pub enablement_status: Option<CspmEnablementStatus>,
}Expand description
A summary of a CSPM connector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connector_arn: Option<String>The Amazon Resource Name (ARN) of the connector.
connector_id: Option<String>The unique identifier of the connector.
name: Option<String>The name of the connector.
description: Option<String>The description of the connector.
provider_summary: Option<CspmProviderSummary>A summary of the cloud provider configuration for the connector.
created_at: Option<DateTime>The ISO 8601 UTC timestamp indicating when the connector was created.
created_by: Option<String>The service principal that created the connector.
enablement_status: Option<CspmEnablementStatus>The enablement status of the connector.
Implementations
Sourceimpl CspmConnectorSummary
impl CspmConnectorSummary
Sourcepub fn connector_arn(&self) -> Option<&str>
pub fn connector_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the connector.
Sourcepub fn connector_id(&self) -> Option<&str>
pub fn connector_id(&self) -> Option<&str>
The unique identifier of the connector.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the connector.
Sourcepub fn provider_summary(&self) -> Option<&CspmProviderSummary>
pub fn provider_summary(&self) -> Option<&CspmProviderSummary>
A summary of the cloud provider configuration for the connector.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The ISO 8601 UTC timestamp indicating when the connector was created.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The service principal that created the connector.
Sourcepub fn enablement_status(&self) -> Option<&CspmEnablementStatus>
pub fn enablement_status(&self) -> Option<&CspmEnablementStatus>
The enablement status of the connector.
Sourceimpl CspmConnectorSummary
impl CspmConnectorSummary
Sourcepub fn builder() -> CspmConnectorSummaryBuilder
pub fn builder() -> CspmConnectorSummaryBuilder
Creates a new builder-style object to manufacture CspmConnectorSummary.