#[non_exhaustive]pub struct CspmHealthCheck {
pub connector_status: Option<CspmConnectorStatus>,
pub message: Option<String>,
pub last_checked_at: Option<DateTime>,
pub issues: Option<Vec<HealthIssue>>,
}Expand description
Information about the operational status and health of a CSPM connector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connector_status: Option<CspmConnectorStatus>The connectivity status of the connector.
message: Option<String>A message describing the reason for the current connector status.
last_checked_at: Option<DateTime>The ISO 8601 UTC timestamp indicating when the health status was last checked.
issues: Option<Vec<HealthIssue>>A list of health issues associated with the connector.
Implementations
Sourceimpl CspmHealthCheck
impl CspmHealthCheck
Sourcepub fn connector_status(&self) -> Option<&CspmConnectorStatus>
pub fn connector_status(&self) -> Option<&CspmConnectorStatus>
The connectivity status of the connector.
Sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
A message describing the reason for the current connector status.
Sourcepub fn last_checked_at(&self) -> Option<&DateTime>
pub fn last_checked_at(&self) -> Option<&DateTime>
The ISO 8601 UTC timestamp indicating when the health status was last checked.
Sourcepub fn issues(&self) -> &[HealthIssue]
pub fn issues(&self) -> &[HealthIssue]
A list of health issues associated with the connector.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .issues.is_none().
Sourceimpl CspmHealthCheck
impl CspmHealthCheck
Sourcepub fn builder() -> CspmHealthCheckBuilder
pub fn builder() -> CspmHealthCheckBuilder
Creates a new builder-style object to manufacture CspmHealthCheck.