#[non_exhaustive]pub struct FindingScopes {
pub aws_organizations: Option<Vec<AwsOrganizationScope>>,
}Expand description
Defines the data boundary for a findings query. Scopes determine which organizational units or organizations to retrieve data from.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aws_organizations: Option<Vec<AwsOrganizationScope>>A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Implementations
Sourceimpl FindingScopes
impl FindingScopes
Sourcepub fn aws_organizations(&self) -> &[AwsOrganizationScope]
pub fn aws_organizations(&self) -> &[AwsOrganizationScope]
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .aws_organizations.is_none().
Sourceimpl FindingScopes
impl FindingScopes
Sourcepub fn builder() -> FindingScopesBuilder
pub fn builder() -> FindingScopesBuilder
Creates a new builder-style object to manufacture FindingScopes.