#[non_exhaustive]pub struct HealthIssue {
pub code: Option<HealthIssueCode>,
pub message: Option<String>,
}Expand description
Represents a specific health issue detected for a connector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: Option<HealthIssueCode>The error code that identifies the type of health issue.
message: Option<String>A human-readable message that describes the health issue.
Implementations
Sourceimpl HealthIssue
impl HealthIssue
Sourceimpl HealthIssue
impl HealthIssue
Sourcepub fn builder() -> HealthIssueBuilder
pub fn builder() -> HealthIssueBuilder
Creates a new builder-style object to manufacture HealthIssue.