#[non_exhaustive]pub struct ResourceInfo {
pub ai_details: Option<AiDetails>,
}Expand description
Additional details about a resource that are specific to its category. For AI/ML resources and their host resources, this structure contains AIDetails.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ai_details: Option<AiDetails>Details that are specific to self-hosted AI resources and their host resources.
Implementations
Sourceimpl ResourceInfo
impl ResourceInfo
Sourcepub fn ai_details(&self) -> Option<&AiDetails>
pub fn ai_details(&self) -> Option<&AiDetails>
Details that are specific to self-hosted AI resources and their host resources.
Sourceimpl ResourceInfo
impl ResourceInfo
Sourcepub fn builder() -> ResourceInfoBuilder
pub fn builder() -> ResourceInfoBuilder
Creates a new builder-style object to manufacture ResourceInfo.