#[non_exhaustive]pub struct ResourceResult {Show 21 fields
pub resource_guid: Option<String>,
pub resource_id: Option<String>,
pub account_id: Option<String>,
pub account_name: Option<String>,
pub region: Option<String>,
pub resource_provider: Option<String>,
pub resource_owner_account_id: Option<String>,
pub resource_owner_org_id: Option<String>,
pub resource_cloud_partition: Option<String>,
pub resource_region: Option<String>,
pub resource_category: Option<ResourceCategory>,
pub resource_type: Option<String>,
pub resource_name: Option<String>,
pub resource_creation_time_dt: Option<String>,
pub resource_detail_capture_time_dt: Option<String>,
pub findings_summary: Option<Vec<ResourceFindingsSummary>>,
pub resource_tags: Option<Vec<ResourceTag>>,
pub resource_config: Option<Document>,
pub resource_sub_category: Option<ResourceSubCategory>,
pub discovery_type: Option<DiscoveryType>,
pub resource_info: Option<ResourceInfo>,
}Expand description
Provides comprehensive details about an Amazon Web Services resource and its associated security findings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_guid: Option<String>The global identifier used to identify a resource.
resource_id: Option<String>The unique identifier for a resource.
account_id: Option<String>The Amazon Web Services account that recorded the resource data in Security Hub.
account_name: Option<String>The name of the Amazon Web Services account that's associated with the resource.
region: Option<String>The Amazon Web Services Region that recorded the resource data in Security Hub.
resource_provider: Option<String>The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.
resource_owner_account_id: Option<String>The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
resource_owner_org_id: Option<String>The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
resource_cloud_partition: Option<String>The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.
resource_region: Option<String>The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.
resource_category: Option<ResourceCategory>The grouping where the resource belongs.
resource_type: Option<String>The type of resource.
resource_name: Option<String>The name of the resource.
resource_creation_time_dt: Option<String>The time when the resource was created.
resource_detail_capture_time_dt: Option<String>The timestamp when information about the resource was captured.
findings_summary: Option<Vec<ResourceFindingsSummary>>An aggregated view of security findings associated with a resource.
The key-value pairs associated with a resource.
resource_config: Option<Document>The configuration details of a resource.
resource_sub_category: Option<ResourceSubCategory>The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.
discovery_type: Option<DiscoveryType>Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.
resource_info: Option<ResourceInfo>Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.
Implementations
Sourceimpl ResourceResult
impl ResourceResult
Sourcepub fn resource_guid(&self) -> Option<&str>
pub fn resource_guid(&self) -> Option<&str>
The global identifier used to identify a resource.
Sourcepub fn resource_id(&self) -> Option<&str>
pub fn resource_id(&self) -> Option<&str>
The unique identifier for a resource.
Sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The Amazon Web Services account that recorded the resource data in Security Hub.
Sourcepub fn account_name(&self) -> Option<&str>
pub fn account_name(&self) -> Option<&str>
The name of the Amazon Web Services account that's associated with the resource.
Sourcepub fn region(&self) -> Option<&str>
pub fn region(&self) -> Option<&str>
The Amazon Web Services Region that recorded the resource data in Security Hub.
Sourcepub fn resource_provider(&self) -> Option<&str>
pub fn resource_provider(&self) -> Option<&str>
The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.
Sourcepub fn resource_owner_account_id(&self) -> Option<&str>
pub fn resource_owner_account_id(&self) -> Option<&str>
The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
Sourcepub fn resource_owner_org_id(&self) -> Option<&str>
pub fn resource_owner_org_id(&self) -> Option<&str>
The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
Sourcepub fn resource_cloud_partition(&self) -> Option<&str>
pub fn resource_cloud_partition(&self) -> Option<&str>
The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.
Sourcepub fn resource_region(&self) -> Option<&str>
pub fn resource_region(&self) -> Option<&str>
The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.
Sourcepub fn resource_category(&self) -> Option<&ResourceCategory>
pub fn resource_category(&self) -> Option<&ResourceCategory>
The grouping where the resource belongs.
Sourcepub fn resource_type(&self) -> Option<&str>
pub fn resource_type(&self) -> Option<&str>
The type of resource.
Sourcepub fn resource_name(&self) -> Option<&str>
pub fn resource_name(&self) -> Option<&str>
The name of the resource.
Sourcepub fn resource_creation_time_dt(&self) -> Option<&str>
pub fn resource_creation_time_dt(&self) -> Option<&str>
The time when the resource was created.
Sourcepub fn resource_detail_capture_time_dt(&self) -> Option<&str>
pub fn resource_detail_capture_time_dt(&self) -> Option<&str>
The timestamp when information about the resource was captured.
Sourcepub fn findings_summary(&self) -> &[ResourceFindingsSummary]
pub fn findings_summary(&self) -> &[ResourceFindingsSummary]
An aggregated view of security findings associated with a resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .findings_summary.is_none().
The key-value pairs associated with a resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .resource_tags.is_none().
Sourcepub fn resource_config(&self) -> Option<&Document>
pub fn resource_config(&self) -> Option<&Document>
The configuration details of a resource.
Sourcepub fn resource_sub_category(&self) -> Option<&ResourceSubCategory>
pub fn resource_sub_category(&self) -> Option<&ResourceSubCategory>
The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.
Sourcepub fn discovery_type(&self) -> Option<&DiscoveryType>
pub fn discovery_type(&self) -> Option<&DiscoveryType>
Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.
Sourcepub fn resource_info(&self) -> Option<&ResourceInfo>
pub fn resource_info(&self) -> Option<&ResourceInfo>
Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.
Sourceimpl ResourceResult
impl ResourceResult
Sourcepub fn builder() -> ResourceResultBuilder
pub fn builder() -> ResourceResultBuilder
Creates a new builder-style object to manufacture ResourceResult.