#[non_exhaustive]pub struct UnusedPermissionsRecommendationStep {
pub recommended_action: Option<String>,
pub existing_policy: Option<String>,
pub existing_policy_id: Option<String>,
pub policy_updated_at: Option<DateTime>,
pub recommended_policy: Option<String>,
}Expand description
Contains information about the action to take for a policy in an unused permissions finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recommended_action: Option<String>A recommendation of whether to create or detach a policy for an unused permissions finding.
existing_policy: Option<String>The contents of the existing policy identified by ExistingPolicyId which needs to be replaced, when the RecommendedAction is CREATE_POLICY.
existing_policy_id: Option<String>The ID of an existing policy to be replaced or detached.
policy_updated_at: Option<DateTime>The time at which the existing policy for the unused permissions finding was last updated.
recommended_policy: Option<String>The contents of the least-privileged recommended replacement for ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
Implementations
Sourceimpl UnusedPermissionsRecommendationStep
impl UnusedPermissionsRecommendationStep
Sourcepub fn recommended_action(&self) -> Option<&str>
pub fn recommended_action(&self) -> Option<&str>
A recommendation of whether to create or detach a policy for an unused permissions finding.
Sourcepub fn existing_policy(&self) -> Option<&str>
pub fn existing_policy(&self) -> Option<&str>
The contents of the existing policy identified by ExistingPolicyId which needs to be replaced, when the RecommendedAction is CREATE_POLICY.
Sourcepub fn existing_policy_id(&self) -> Option<&str>
pub fn existing_policy_id(&self) -> Option<&str>
The ID of an existing policy to be replaced or detached.
Sourcepub fn policy_updated_at(&self) -> Option<&DateTime>
pub fn policy_updated_at(&self) -> Option<&DateTime>
The time at which the existing policy for the unused permissions finding was last updated.
Sourcepub fn recommended_policy(&self) -> Option<&str>
pub fn recommended_policy(&self) -> Option<&str>
The contents of the least-privileged recommended replacement for ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
Sourceimpl UnusedPermissionsRecommendationStep
impl UnusedPermissionsRecommendationStep
Sourcepub fn builder() -> UnusedPermissionsRecommendationStepBuilder
pub fn builder() -> UnusedPermissionsRecommendationStepBuilder
Creates a new builder-style object to manufacture UnusedPermissionsRecommendationStep.