Struct aws_sdk_securityhub::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for SecurityHubAPIService.
This client allows ergonomic access to a SecurityHubAPIService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AcceptAdministratorInvitation operation.
See AcceptAdministratorInvitation for more information about the
operation and its arguments.
Constructs a fluent builder for the AcceptInvitation operation.
See AcceptInvitation for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchDisableStandards operation.
See BatchDisableStandards for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchEnableStandards operation.
See BatchEnableStandards for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchImportFindings operation.
See BatchImportFindings for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchUpdateFindings operation.
See BatchUpdateFindings for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateActionTarget operation.
See CreateActionTarget for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFindingAggregator operation.
See CreateFindingAggregator for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateInsight operation.
See CreateInsight for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateMembers operation.
See CreateMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the DeclineInvitations operation.
See DeclineInvitations for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteActionTarget operation.
See DeleteActionTarget for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFindingAggregator operation.
See DeleteFindingAggregator for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteInsight operation.
See DeleteInsight for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteInvitations operation.
See DeleteInvitations for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteMembers operation.
See DeleteMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeActionTargets operation.
See DescribeActionTargets for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeHub operation.
See DescribeHub for more information about the
operation and its arguments.
pub fn describe_organization_configuration(
&self
) -> DescribeOrganizationConfiguration<C, M, R>
pub fn describe_organization_configuration(
&self
) -> DescribeOrganizationConfiguration<C, M, R>
Constructs a fluent builder for the DescribeOrganizationConfiguration operation.
See DescribeOrganizationConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeProducts operation.
See DescribeProducts for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeStandards operation.
See DescribeStandards for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeStandardsControls operation.
See DescribeStandardsControls for more information about the
operation and its arguments.
Constructs a fluent builder for the DisableImportFindingsForProduct operation.
See DisableImportFindingsForProduct for more information about the
operation and its arguments.
Constructs a fluent builder for the DisableOrganizationAdminAccount operation.
See DisableOrganizationAdminAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the DisableSecurityHub operation.
See DisableSecurityHub for more information about the
operation and its arguments.
pub fn disassociate_from_administrator_account(
&self
) -> DisassociateFromAdministratorAccount<C, M, R>
pub fn disassociate_from_administrator_account(
&self
) -> DisassociateFromAdministratorAccount<C, M, R>
Constructs a fluent builder for the DisassociateFromAdministratorAccount operation.
See DisassociateFromAdministratorAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateFromMasterAccount operation.
See DisassociateFromMasterAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateMembers operation.
See DisassociateMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the EnableImportFindingsForProduct operation.
See EnableImportFindingsForProduct for more information about the
operation and its arguments.
Constructs a fluent builder for the EnableOrganizationAdminAccount operation.
See EnableOrganizationAdminAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the EnableSecurityHub operation.
See EnableSecurityHub for more information about the
operation and its arguments.
Constructs a fluent builder for the GetAdministratorAccount operation.
See GetAdministratorAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the GetEnabledStandards operation.
See GetEnabledStandards for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFindingAggregator operation.
See GetFindingAggregator for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFindings operation.
See GetFindings for more information about the
operation and its arguments.
Constructs a fluent builder for the GetInsightResults operation.
See GetInsightResults for more information about the
operation and its arguments.
Constructs a fluent builder for the GetInsights operation.
See GetInsights for more information about the
operation and its arguments.
Constructs a fluent builder for the GetInvitationsCount operation.
See GetInvitationsCount for more information about the
operation and its arguments.
Constructs a fluent builder for the GetMasterAccount operation.
See GetMasterAccount for more information about the
operation and its arguments.
Constructs a fluent builder for the GetMembers operation.
See GetMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the InviteMembers operation.
See InviteMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the ListEnabledProductsForImport operation.
See ListEnabledProductsForImport for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFindingAggregators operation.
See ListFindingAggregators for more information about the
operation and its arguments.
Constructs a fluent builder for the ListInvitations operation.
See ListInvitations for more information about the
operation and its arguments.
Constructs a fluent builder for the ListMembers operation.
See ListMembers for more information about the
operation and its arguments.
Constructs a fluent builder for the ListOrganizationAdminAccounts operation.
See ListOrganizationAdminAccounts for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateActionTarget operation.
See UpdateActionTarget for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFindingAggregator operation.
See UpdateFindingAggregator for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFindings operation.
See UpdateFindings for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateInsight operation.
See UpdateInsight for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateOrganizationConfiguration operation.
See UpdateOrganizationConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateSecurityHubConfiguration operation.
See UpdateSecurityHubConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateStandardsControl operation.
See UpdateStandardsControl for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.