Struct aws_sdk_securityhub::input::disassociate_members_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DisassociateMembersInput
Implementations
Appends an item to account_ids.
To override the contents of this collection use set_account_ids.
The account IDs of the member accounts to disassociate from the administrator account.
The account IDs of the member accounts to disassociate from the administrator account.
Consumes the builder and constructs a DisassociateMembersInput