Struct aws_sdk_securityhub::input::get_insights_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for GetInsightsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn insight_arns(self, input: impl Into<String>) -> Self
pub fn insight_arns(self, input: impl Into<String>) -> Self
Appends an item to insight_arns.
To override the contents of this collection use set_insight_arns.
The ARNs of the insights to describe. If you do not provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights.
sourcepub fn set_insight_arns(self, input: Option<Vec<String>>) -> Self
pub fn set_insight_arns(self, input: Option<Vec<String>>) -> Self
The ARNs of the insights to describe. If you do not provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of items to return in the response.
sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of items to return in the response.
sourcepub fn build(self) -> Result<GetInsightsInput, BuildError>
pub fn build(self) -> Result<GetInsightsInput, BuildError>
Consumes the builder and constructs a GetInsightsInput.