Struct aws_sdk_securityhub::input::list_invitations_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListInvitationsInput
Implementations
The maximum number of items to return in the response.
The maximum number of items to return in the response.
The token that is required for pagination. On your first call to the
ListInvitations operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
The token that is required for pagination. On your first call to the
ListInvitations operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
Consumes the builder and constructs a ListInvitationsInput