Struct aws_sdk_securityhub::input::DescribeProductsInput
source · [−]#[non_exhaustive]pub struct DescribeProductsInput { /* private fields */ }Implementations
sourceimpl DescribeProductsInput
impl DescribeProductsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeProducts, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeProducts, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeProducts>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeProductsInput.
sourceimpl DescribeProductsInput
impl DescribeProductsInput
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that is required for pagination. On your first call to the DescribeProducts operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
The maximum number of results to return.
sourcepub fn product_arn(&self) -> Option<&str>
pub fn product_arn(&self) -> Option<&str>
The ARN of the integration to return.