Struct aws_sdk_securityhub::input::EnableSecurityHubInput
source · [−]#[non_exhaustive]pub struct EnableSecurityHubInput { /* private fields */ }Implementations
sourceimpl EnableSecurityHubInput
impl EnableSecurityHubInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<EnableSecurityHub, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<EnableSecurityHub, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<EnableSecurityHub>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture EnableSecurityHubInput.
sourceimpl EnableSecurityHubInput
impl EnableSecurityHubInput
The tags to add to the hub resource when you enable Security Hub.
sourcepub fn enable_default_standards(&self) -> bool
pub fn enable_default_standards(&self) -> bool
Whether to enable the security standards that Security Hub has designated as automatically enabled. If you do not provide a value for EnableDefaultStandards, it is set to true. To not enable the automatically enabled standards, set EnableDefaultStandards to false.