Struct aws_sdk_securityhub::model::aws_ec2_eip_details::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for AwsEc2EipDetails.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the EC2 instance.
sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the EC2 instance.
sourcepub fn public_ip(self, input: impl Into<String>) -> Self
pub fn public_ip(self, input: impl Into<String>) -> Self
A public IP address that is associated with the EC2 instance.
sourcepub fn set_public_ip(self, input: Option<String>) -> Self
pub fn set_public_ip(self, input: Option<String>) -> Self
A public IP address that is associated with the EC2 instance.
sourcepub fn allocation_id(self, input: impl Into<String>) -> Self
pub fn allocation_id(self, input: impl Into<String>) -> Self
The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
sourcepub fn set_allocation_id(self, input: Option<String>) -> Self
pub fn set_allocation_id(self, input: Option<String>) -> Self
The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
sourcepub fn association_id(self, input: impl Into<String>) -> Self
pub fn association_id(self, input: impl Into<String>) -> Self
The identifier that represents the association of the Elastic IP address with an EC2 instance.
sourcepub fn set_association_id(self, input: Option<String>) -> Self
pub fn set_association_id(self, input: Option<String>) -> Self
The identifier that represents the association of the Elastic IP address with an EC2 instance.
sourcepub fn domain(self, input: impl Into<String>) -> Self
pub fn domain(self, input: impl Into<String>) -> Self
The domain in which to allocate the address.
If the address is for use with EC2 instances in a VPC, then Domain is vpc. Otherwise, Domain is standard.
sourcepub fn set_domain(self, input: Option<String>) -> Self
pub fn set_domain(self, input: Option<String>) -> Self
The domain in which to allocate the address.
If the address is for use with EC2 instances in a VPC, then Domain is vpc. Otherwise, Domain is standard.
sourcepub fn public_ipv4_pool(self, input: impl Into<String>) -> Self
pub fn public_ipv4_pool(self, input: impl Into<String>) -> Self
The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.
sourcepub fn set_public_ipv4_pool(self, input: Option<String>) -> Self
pub fn set_public_ipv4_pool(self, input: Option<String>) -> Self
The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.
sourcepub fn network_border_group(self, input: impl Into<String>) -> Self
pub fn network_border_group(self, input: impl Into<String>) -> Self
The name of the location from which the Elastic IP address is advertised.
sourcepub fn set_network_border_group(self, input: Option<String>) -> Self
pub fn set_network_border_group(self, input: Option<String>) -> Self
The name of the location from which the Elastic IP address is advertised.
sourcepub fn network_interface_id(self, input: impl Into<String>) -> Self
pub fn network_interface_id(self, input: impl Into<String>) -> Self
The identifier of the network interface.
sourcepub fn set_network_interface_id(self, input: Option<String>) -> Self
pub fn set_network_interface_id(self, input: Option<String>) -> Self
The identifier of the network interface.
sourcepub fn network_interface_owner_id(self, input: impl Into<String>) -> Self
pub fn network_interface_owner_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID of the owner of the network interface.
sourcepub fn set_network_interface_owner_id(self, input: Option<String>) -> Self
pub fn set_network_interface_owner_id(self, input: Option<String>) -> Self
The Amazon Web Services account ID of the owner of the network interface.
sourcepub fn private_ip_address(self, input: impl Into<String>) -> Self
pub fn private_ip_address(self, input: impl Into<String>) -> Self
The private IP address that is associated with the Elastic IP address.
sourcepub fn set_private_ip_address(self, input: Option<String>) -> Self
pub fn set_private_ip_address(self, input: Option<String>) -> Self
The private IP address that is associated with the Elastic IP address.
sourcepub fn build(self) -> AwsEc2EipDetails
pub fn build(self) -> AwsEc2EipDetails
Consumes the builder and constructs a AwsEc2EipDetails.