pub struct Builder { /* private fields */ }Expand description
A builder for Product.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn product_arn(self, input: impl Into<String>) -> Self
pub fn product_arn(self, input: impl Into<String>) -> Self
The ARN assigned to the product.
sourcepub fn set_product_arn(self, input: Option<String>) -> Self
pub fn set_product_arn(self, input: Option<String>) -> Self
The ARN assigned to the product.
sourcepub fn product_name(self, input: impl Into<String>) -> Self
pub fn product_name(self, input: impl Into<String>) -> Self
The name of the product.
sourcepub fn set_product_name(self, input: Option<String>) -> Self
pub fn set_product_name(self, input: Option<String>) -> Self
The name of the product.
sourcepub fn company_name(self, input: impl Into<String>) -> Self
pub fn company_name(self, input: impl Into<String>) -> Self
The name of the company that provides the product.
sourcepub fn set_company_name(self, input: Option<String>) -> Self
pub fn set_company_name(self, input: Option<String>) -> Self
The name of the company that provides the product.
sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the product.
sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the product.
sourcepub fn categories(self, input: impl Into<String>) -> Self
pub fn categories(self, input: impl Into<String>) -> Self
Appends an item to categories.
To override the contents of this collection use set_categories.
The categories assigned to the product.
sourcepub fn set_categories(self, input: Option<Vec<String>>) -> Self
pub fn set_categories(self, input: Option<Vec<String>>) -> Self
The categories assigned to the product.
sourcepub fn integration_types(self, input: IntegrationType) -> Self
pub fn integration_types(self, input: IntegrationType) -> Self
Appends an item to integration_types.
To override the contents of this collection use set_integration_types.
The types of integration that the product supports. Available values are the following.
-
SEND_FINDINGS_TO_SECURITY_HUB- The integration sends findings to Security Hub. -
RECEIVE_FINDINGS_FROM_SECURITY_HUB- The integration receives findings from Security Hub. -
UPDATE_FINDINGS_IN_SECURITY_HUB- The integration does not send new findings to Security Hub, but does make updates to the findings that it receives from Security Hub.
sourcepub fn set_integration_types(self, input: Option<Vec<IntegrationType>>) -> Self
pub fn set_integration_types(self, input: Option<Vec<IntegrationType>>) -> Self
The types of integration that the product supports. Available values are the following.
-
SEND_FINDINGS_TO_SECURITY_HUB- The integration sends findings to Security Hub. -
RECEIVE_FINDINGS_FROM_SECURITY_HUB- The integration receives findings from Security Hub. -
UPDATE_FINDINGS_IN_SECURITY_HUB- The integration does not send new findings to Security Hub, but does make updates to the findings that it receives from Security Hub.
sourcepub fn marketplace_url(self, input: impl Into<String>) -> Self
pub fn marketplace_url(self, input: impl Into<String>) -> Self
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
For integrations with third-party products, the Amazon Web Services Marketplace URL from which to subscribe to or purchase the product.
sourcepub fn set_marketplace_url(self, input: Option<String>) -> Self
pub fn set_marketplace_url(self, input: Option<String>) -> Self
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
For integrations with third-party products, the Amazon Web Services Marketplace URL from which to subscribe to or purchase the product.
sourcepub fn activation_url(self, input: impl Into<String>) -> Self
pub fn activation_url(self, input: impl Into<String>) -> Self
The URL to the service or product documentation about the integration with Security Hub, including how to activate the integration.
sourcepub fn set_activation_url(self, input: Option<String>) -> Self
pub fn set_activation_url(self, input: Option<String>) -> Self
The URL to the service or product documentation about the integration with Security Hub, including how to activate the integration.
sourcepub fn product_subscription_resource_policy(
self,
input: impl Into<String>
) -> Self
pub fn product_subscription_resource_policy(
self,
input: impl Into<String>
) -> Self
The resource policy associated with the product.
sourcepub fn set_product_subscription_resource_policy(
self,
input: Option<String>
) -> Self
pub fn set_product_subscription_resource_policy(
self,
input: Option<String>
) -> Self
The resource policy associated with the product.