Struct aws_sdk_securityhub::model::product::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Product
Implementations
The ARN assigned to the product.
The ARN assigned to the product.
The name of the product.
The name of the product.
The name of the company that provides the product.
The name of the company that provides the product.
A description of the product.
A description of the product.
Appends an item to categories.
To override the contents of this collection use set_categories.
The categories assigned to the product.
The categories assigned to the product.
Appends an item to integration_types.
To override the contents of this collection use set_integration_types.
The types of integration that the product supports. Available values are the following.
-
SEND_FINDINGS_TO_SECURITY_HUB- The integration sends findings to Security Hub. -
RECEIVE_FINDINGS_FROM_SECURITY_HUB- The integration receives findings from Security Hub. -
UPDATE_FINDINGS_IN_SECURITY_HUB- The integration does not send new findings to Security Hub, but does make updates to the findings that it receives from Security Hub.
The types of integration that the product supports. Available values are the following.
-
SEND_FINDINGS_TO_SECURITY_HUB- The integration sends findings to Security Hub. -
RECEIVE_FINDINGS_FROM_SECURITY_HUB- The integration receives findings from Security Hub. -
UPDATE_FINDINGS_IN_SECURITY_HUB- The integration does not send new findings to Security Hub, but does make updates to the findings that it receives from Security Hub.
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
For integrations with third-party products, the Amazon Web Services Marketplace URL from which to subscribe to or purchase the product.
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
For integrations with third-party products, the Amazon Web Services Marketplace URL from which to subscribe to or purchase the product.
The URL to the service or product documentation about the integration with Security Hub, including how to activate the integration.
The URL to the service or product documentation about the integration with Security Hub, including how to activate the integration.
The resource policy associated with the product.
The resource policy associated with the product.