pub struct Builder { /* private fields */ }Expand description
A builder for StandardsSubscriptionRequest.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn standards_arn(self, input: impl Into<String>) -> Self
pub fn standards_arn(self, input: impl Into<String>) -> Self
The ARN of the standard that you want to enable. To view the list of available standards and their ARNs, use the DescribeStandards operation.
sourcepub fn set_standards_arn(self, input: Option<String>) -> Self
pub fn set_standards_arn(self, input: Option<String>) -> Self
The ARN of the standard that you want to enable. To view the list of available standards and their ARNs, use the DescribeStandards operation.
sourcepub fn standards_input(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn standards_input(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to standards_input.
To override the contents of this collection use set_standards_input.
A key-value pair of input for the standard.
sourcepub fn set_standards_input(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_standards_input(self, input: Option<HashMap<String, String>>) -> Self
A key-value pair of input for the standard.
sourcepub fn build(self) -> StandardsSubscriptionRequest
pub fn build(self) -> StandardsSubscriptionRequest
Consumes the builder and constructs a StandardsSubscriptionRequest.