#[non_exhaustive]
pub struct AwsAutoScalingAutoScalingGroupDetails { /* private fields */ }
Provides details about an auto scaling group.

Implementations

The name of the launch configuration.

The list of load balancers associated with the group.

The service to use for the health checks. Valid values are EC2 or ELB.

The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.

Indicates when the auto scaling group was created.

Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.

The mixed instances policy for the automatic scaling group.

The list of Availability Zones for the automatic scaling group.

The launch template to use.

Indicates whether capacity rebalancing is enabled.

Creates a new builder-style object to manufacture AwsAutoScalingAutoScalingGroupDetails.