#[non_exhaustive]pub struct AwsAutoScalingAutoScalingGroupDetails { /* private fields */ }Expand description
Provides details about an auto scaling group.
Implementations
sourceimpl AwsAutoScalingAutoScalingGroupDetails
impl AwsAutoScalingAutoScalingGroupDetails
sourcepub fn launch_configuration_name(&self) -> Option<&str>
pub fn launch_configuration_name(&self) -> Option<&str>
The name of the launch configuration.
sourcepub fn load_balancer_names(&self) -> Option<&[String]>
pub fn load_balancer_names(&self) -> Option<&[String]>
The list of load balancers associated with the group.
sourcepub fn health_check_type(&self) -> Option<&str>
pub fn health_check_type(&self) -> Option<&str>
The service to use for the health checks. Valid values are EC2 or ELB.
sourcepub fn health_check_grace_period(&self) -> i32
pub fn health_check_grace_period(&self) -> i32
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
sourcepub fn created_time(&self) -> Option<&str>
pub fn created_time(&self) -> Option<&str>
Indicates when the auto scaling group was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn mixed_instances_policy(
&self
) -> Option<&AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>
pub fn mixed_instances_policy(
&self
) -> Option<&AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails>
The mixed instances policy for the automatic scaling group.
sourcepub fn availability_zones(
&self
) -> Option<&[AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails]>
pub fn availability_zones(
&self
) -> Option<&[AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails]>
The list of Availability Zones for the automatic scaling group.
sourcepub fn launch_template(
&self
) -> Option<&AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>
pub fn launch_template(
&self
) -> Option<&AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification>
The launch template to use.
sourcepub fn capacity_rebalance(&self) -> bool
pub fn capacity_rebalance(&self) -> bool
Indicates whether capacity rebalancing is enabled.
sourceimpl AwsAutoScalingAutoScalingGroupDetails
impl AwsAutoScalingAutoScalingGroupDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsAutoScalingAutoScalingGroupDetails.