Struct aws_sdk_securityhub::model::AwsAutoScalingAutoScalingGroupDetails [−][src]
#[non_exhaustive]pub struct AwsAutoScalingAutoScalingGroupDetails {
pub launch_configuration_name: Option<String>,
pub load_balancer_names: Option<Vec<String>>,
pub health_check_type: Option<String>,
pub health_check_grace_period: i32,
pub created_time: Option<String>,
}Expand description
Provides details about an auto scaling group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.launch_configuration_name: Option<String>The name of the launch configuration.
load_balancer_names: Option<Vec<String>>The list of load balancers associated with the group.
health_check_type: Option<String>The service to use for the health checks.
health_check_grace_period: i32The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
created_time: Option<String>Indicates when the auto scaling group was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
Implementations
The name of the launch configuration.
The list of load balancers associated with the group.
The service to use for the health checks.
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
Indicates when the auto scaling group was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
Creates a new builder-style object to manufacture AwsAutoScalingAutoScalingGroupDetails