Struct aws_sdk_securityhub::model::AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails [−][src]
#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails {
pub delete_on_termination: bool,
pub encrypted: bool,
pub iops: i32,
pub snapshot_id: Option<String>,
pub volume_size: i32,
pub volume_type: Option<String>,
}Expand description
Parameters that are used to automatically set up EBS volumes when an instance is launched.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delete_on_termination: boolWhether to delete the volume when the instance is terminated.
encrypted: boolWhether to encrypt the volume.
iops: i32The number of input/output (I/O) operations per second (IOPS) to provision for the volume.
Only supported for gp3 or io1 volumes. Required for io1 volumes. Not used with standard, gp2, st1, or sc1 volumes.
snapshot_id: Option<String>The snapshot ID of the volume to use.
You must specify either VolumeSize or SnapshotId.
volume_size: i32The volume size, in GiBs. The following are the supported volumes sizes for each volume type:
-
gp2 and gp3: 1-16,384
-
io1: 4-16,384
-
st1 and sc1: 125-16,384
-
standard: 1-1,024
You must specify either SnapshotId or VolumeSize. If you specify both SnapshotId and VolumeSize, the volume size must be equal or greater than the size of the snapshot.
volume_type: Option<String>The volume type.
Implementations
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails