Struct aws_sdk_securityhub::model::AwsAutoScalingLaunchConfigurationDetails [−][src]
#[non_exhaustive]pub struct AwsAutoScalingLaunchConfigurationDetails {Show 18 fields
pub associate_public_ip_address: bool,
pub block_device_mappings: Option<Vec<AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails>>,
pub classic_link_vpc_id: Option<String>,
pub classic_link_vpc_security_groups: Option<Vec<String>>,
pub created_time: Option<String>,
pub ebs_optimized: bool,
pub iam_instance_profile: Option<String>,
pub image_id: Option<String>,
pub instance_monitoring: Option<AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails>,
pub instance_type: Option<String>,
pub kernel_id: Option<String>,
pub key_name: Option<String>,
pub launch_configuration_name: Option<String>,
pub placement_tenancy: Option<String>,
pub ramdisk_id: Option<String>,
pub security_groups: Option<Vec<String>>,
pub spot_price: Option<String>,
pub user_data: Option<String>,
}Expand description
Details about a launch configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.associate_public_ip_address: boolFor Auto Scaling groups that run in a VPC, specifies whether to assign a public IP address to the group's instances.
block_device_mappings: Option<Vec<AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails>>Specifies the block devices for the instance.
classic_link_vpc_id: Option<String>The identifier of a ClassicLink-enabled VPC that EC2-Classic instances are linked to.
classic_link_vpc_security_groups: Option<Vec<String>>The identifiers of one or more security groups for the VPC that is specified in ClassicLinkVPCId.
created_time: Option<String>The creation date and time for the launch configuration.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
ebs_optimized: boolWhether the launch configuration is optimized for Amazon EBS I/O.
iam_instance_profile: Option<String>The name or the ARN of the instance profile associated with the IAM role for the instance. The instance profile contains the IAM role.
image_id: Option<String>The identifier of the Amazon Machine Image (AMI) that is used to launch EC2 instances.
instance_monitoring: Option<AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails>Indicates the type of monitoring for instances in the group.
instance_type: Option<String>The instance type for the instances.
kernel_id: Option<String>The identifier of the kernel associated with the AMI.
key_name: Option<String>The name of the key pair.
launch_configuration_name: Option<String>The name of the launch configuration.
placement_tenancy: Option<String>The tenancy of the instance. An instance with dedicated tenancy runs on
isolated, single-tenant hardware and can only be launched into a VPC.
ramdisk_id: Option<String>The identifier of the RAM disk associated with the AMI.
security_groups: Option<Vec<String>>The security groups to assign to the instances in the Auto Scaling group.
spot_price: Option<String>The maximum hourly price to be paid for any Spot Instance that is launched to fulfill the request.
user_data: Option<String>The user data to make available to the launched EC2 instances. Must be base64-encoded text.
Implementations
Creates a new builder-style object to manufacture AwsAutoScalingLaunchConfigurationDetails