Struct aws_sdk_securityhub::model::AwsCertificateManagerCertificateDomainValidationOption
source · [−]#[non_exhaustive]pub struct AwsCertificateManagerCertificateDomainValidationOption { /* private fields */ }Expand description
Contains information about one of the following:
-
The initial validation of each domain name that occurs as a result of the
RequestCertificaterequest -
The validation of each domain name in the certificate, as it pertains to Certificate Manager managed renewal
Implementations
sourceimpl AwsCertificateManagerCertificateDomainValidationOption
impl AwsCertificateManagerCertificateDomainValidationOption
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
A fully qualified domain name (FQDN) in the certificate.
sourcepub fn resource_record(
&self
) -> Option<&AwsCertificateManagerCertificateResourceRecord>
pub fn resource_record(
&self
) -> Option<&AwsCertificateManagerCertificateResourceRecord>
The CNAME record that is added to the DNS database for domain validation.
sourcepub fn validation_domain(&self) -> Option<&str>
pub fn validation_domain(&self) -> Option<&str>
The domain name that Certificate Manager uses to send domain validation emails.
sourcepub fn validation_emails(&self) -> Option<&[String]>
pub fn validation_emails(&self) -> Option<&[String]>
A list of email addresses that Certificate Manager uses to send domain validation emails.
sourcepub fn validation_method(&self) -> Option<&str>
pub fn validation_method(&self) -> Option<&str>
The method used to validate the domain name.
sourcepub fn validation_status(&self) -> Option<&str>
pub fn validation_status(&self) -> Option<&str>
The validation status of the domain name.
sourceimpl AwsCertificateManagerCertificateDomainValidationOption
impl AwsCertificateManagerCertificateDomainValidationOption
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsCertificateManagerCertificateDomainValidationOption.