Struct aws_sdk_securityhub::model::AwsCertificateManagerCertificateDomainValidationOption [−][src]
#[non_exhaustive]pub struct AwsCertificateManagerCertificateDomainValidationOption {
pub domain_name: Option<String>,
pub resource_record: Option<AwsCertificateManagerCertificateResourceRecord>,
pub validation_domain: Option<String>,
pub validation_emails: Option<Vec<String>>,
pub validation_method: Option<String>,
pub validation_status: Option<String>,
}Expand description
Contains information about one of the following:
-
The initial validation of each domain name that occurs as a result of the
RequestCertificaterequest -
The validation of each domain name in the certificate, as it pertains to Certificate Manager managed renewal
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>A fully qualified domain name (FQDN) in the certificate.
resource_record: Option<AwsCertificateManagerCertificateResourceRecord>The CNAME record that is added to the DNS database for domain validation.
validation_domain: Option<String>The domain name that Certificate Manager uses to send domain validation emails.
validation_emails: Option<Vec<String>>A list of email addresses that Certificate Manager uses to send domain validation emails.
validation_method: Option<String>The method used to validate the domain name.
validation_status: Option<String>The validation status of the domain name.
Implementations
Creates a new builder-style object to manufacture AwsCertificateManagerCertificateDomainValidationOption