Struct aws_sdk_securityhub::model::AwsDynamoDbTableGlobalSecondaryIndex [−][src]
#[non_exhaustive]pub struct AwsDynamoDbTableGlobalSecondaryIndex {
pub backfilling: bool,
pub index_arn: Option<String>,
pub index_name: Option<String>,
pub index_size_bytes: i64,
pub index_status: Option<String>,
pub item_count: i32,
pub key_schema: Option<Vec<AwsDynamoDbTableKeySchema>>,
pub projection: Option<AwsDynamoDbTableProjection>,
pub provisioned_throughput: Option<AwsDynamoDbTableProvisionedThroughput>,
}Expand description
Information abut a global secondary index for the table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backfilling: boolWhether the index is currently backfilling.
index_arn: Option<String>The ARN of the index.
index_name: Option<String>The name of the index.
index_size_bytes: i64The total size in bytes of the index.
index_status: Option<String>The current status of the index.
item_count: i32The number of items in the index.
key_schema: Option<Vec<AwsDynamoDbTableKeySchema>>The key schema for the index.
projection: Option<AwsDynamoDbTableProjection>Attributes that are copied from the table into an index.
provisioned_throughput: Option<AwsDynamoDbTableProvisionedThroughput>Information about the provisioned throughput settings for the indexes.
Implementations
Creates a new builder-style object to manufacture AwsDynamoDbTableGlobalSecondaryIndex