Struct aws_sdk_securityhub::model::AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
source · #[non_exhaustive]pub struct AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails { /* private fields */ }Expand description
Information about the target Capacity Reservation or Capacity Reservation group in which to run an Amazon EC2 instance.
Implementations
sourceimpl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
impl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
sourcepub fn capacity_reservation_id(&self) -> Option<&str>
pub fn capacity_reservation_id(&self) -> Option<&str>
The ID of the Capacity Reservation in which to run the instance.
sourcepub fn capacity_reservation_resource_group_arn(&self) -> Option<&str>
pub fn capacity_reservation_resource_group_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Capacity Reservation resource group in which to run the instance.
sourceimpl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
impl AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails.