#[non_exhaustive]pub struct AwsEc2SecurityGroupIpPermission { /* private fields */ }Expand description
An IP permission for an EC2 security group.
Implementations
sourceimpl AwsEc2SecurityGroupIpPermission
impl AwsEc2SecurityGroupIpPermission
sourcepub fn ip_protocol(&self) -> Option<&str>
pub fn ip_protocol(&self) -> Option<&str>
The IP protocol name (tcp, udp, icmp, icmpv6) or number.
[VPC only] Use -1 to specify all protocols.
When authorizing security group rules, specifying -1 or a protocol number other than tcp, udp, icmp, or icmpv6 allows traffic on all ports, regardless of any port range you specify.
For tcp, udp, and icmp, you must specify a port range.
For icmpv6, the port range is optional. If you omit the port range, traffic for all types and codes is allowed.
sourcepub fn from_port(&self) -> i32
pub fn from_port(&self) -> i32
The start of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number.
A value of -1 indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
sourcepub fn to_port(&self) -> i32
pub fn to_port(&self) -> i32
The end of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code.
A value of -1 indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
sourcepub fn user_id_group_pairs(
&self
) -> Option<&[AwsEc2SecurityGroupUserIdGroupPair]>
pub fn user_id_group_pairs(
&self
) -> Option<&[AwsEc2SecurityGroupUserIdGroupPair]>
The security group and Amazon Web Services account ID pairs.
sourcepub fn ip_ranges(&self) -> Option<&[AwsEc2SecurityGroupIpRange]>
pub fn ip_ranges(&self) -> Option<&[AwsEc2SecurityGroupIpRange]>
The IPv4 ranges.
sourcepub fn ipv6_ranges(&self) -> Option<&[AwsEc2SecurityGroupIpv6Range]>
pub fn ipv6_ranges(&self) -> Option<&[AwsEc2SecurityGroupIpv6Range]>
The IPv6 ranges.
sourcepub fn prefix_list_ids(&self) -> Option<&[AwsEc2SecurityGroupPrefixListId]>
pub fn prefix_list_ids(&self) -> Option<&[AwsEc2SecurityGroupPrefixListId]>
[VPC only] The prefix list IDs for an Amazon Web Services service. With outbound rules, this is the Amazon Web Services service to access through a VPC endpoint from instances associated with the security group.
sourceimpl AwsEc2SecurityGroupIpPermission
impl AwsEc2SecurityGroupIpPermission
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2SecurityGroupIpPermission.