#[non_exhaustive]pub struct AwsEc2VpcEndpointServiceDetails { /* private fields */ }Expand description
Contains details about the service configuration for a VPC endpoint service.
Implementations
sourceimpl AwsEc2VpcEndpointServiceDetails
impl AwsEc2VpcEndpointServiceDetails
sourcepub fn acceptance_required(&self) -> bool
pub fn acceptance_required(&self) -> bool
Whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.
sourcepub fn availability_zones(&self) -> Option<&[String]>
pub fn availability_zones(&self) -> Option<&[String]>
The Availability Zones where the service is available.
sourcepub fn base_endpoint_dns_names(&self) -> Option<&[String]>
pub fn base_endpoint_dns_names(&self) -> Option<&[String]>
The DNS names for the service.
sourcepub fn manages_vpc_endpoints(&self) -> bool
pub fn manages_vpc_endpoints(&self) -> bool
Whether the service manages its VPC endpoints.
sourcepub fn gateway_load_balancer_arns(&self) -> Option<&[String]>
pub fn gateway_load_balancer_arns(&self) -> Option<&[String]>
The ARNs of the Gateway Load Balancers for the service.
sourcepub fn network_load_balancer_arns(&self) -> Option<&[String]>
pub fn network_load_balancer_arns(&self) -> Option<&[String]>
The ARNs of the Network Load Balancers for the service.
sourcepub fn private_dns_name(&self) -> Option<&str>
pub fn private_dns_name(&self) -> Option<&str>
The private DNS name for the service.
sourcepub fn service_id(&self) -> Option<&str>
pub fn service_id(&self) -> Option<&str>
The identifier of the service.
sourcepub fn service_name(&self) -> Option<&str>
pub fn service_name(&self) -> Option<&str>
The name of the service.
sourcepub fn service_state(&self) -> Option<&str>
pub fn service_state(&self) -> Option<&str>
The current state of the service. Valid values are as follows:
-
Available -
Deleted -
Deleting -
Failed -
Pending
sourcepub fn service_type(
&self
) -> Option<&[AwsEc2VpcEndpointServiceServiceTypeDetails]>
pub fn service_type(
&self
) -> Option<&[AwsEc2VpcEndpointServiceServiceTypeDetails]>
The types for the service.
sourceimpl AwsEc2VpcEndpointServiceDetails
impl AwsEc2VpcEndpointServiceDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2VpcEndpointServiceDetails.