#[non_exhaustive]pub struct AwsEc2VpnConnectionDetails { /* private fields */ }Expand description
Details about an Amazon EC2 VPN connection.
Implementations
sourceimpl AwsEc2VpnConnectionDetails
impl AwsEc2VpnConnectionDetails
sourcepub fn vpn_connection_id(&self) -> Option<&str>
pub fn vpn_connection_id(&self) -> Option<&str>
The identifier of the VPN connection.
sourcepub fn state(&self) -> Option<&str>
pub fn state(&self) -> Option<&str>
The current state of the VPN connection. Valid values are as follows:
-
available -
deleted -
deleting -
pending
sourcepub fn customer_gateway_id(&self) -> Option<&str>
pub fn customer_gateway_id(&self) -> Option<&str>
The identifier of the customer gateway that is at your end of the VPN connection.
sourcepub fn customer_gateway_configuration(&self) -> Option<&str>
pub fn customer_gateway_configuration(&self) -> Option<&str>
The configuration information for the VPN connection's customer gateway, in the native XML format.
sourcepub fn vpn_gateway_id(&self) -> Option<&str>
pub fn vpn_gateway_id(&self) -> Option<&str>
The identifier of the virtual private gateway that is at the Amazon Web Services side of the VPN connection.
sourcepub fn category(&self) -> Option<&str>
pub fn category(&self) -> Option<&str>
The category of the VPN connection. VPN indicates an Amazon Web Services VPN connection. VPN-Classic indicates an Amazon Web Services Classic VPN connection.
sourcepub fn vgw_telemetry(&self) -> Option<&[AwsEc2VpnConnectionVgwTelemetryDetails]>
pub fn vgw_telemetry(&self) -> Option<&[AwsEc2VpnConnectionVgwTelemetryDetails]>
Information about the VPN tunnel.
sourcepub fn options(&self) -> Option<&AwsEc2VpnConnectionOptionsDetails>
pub fn options(&self) -> Option<&AwsEc2VpnConnectionOptionsDetails>
The VPN connection options.
sourcepub fn routes(&self) -> Option<&[AwsEc2VpnConnectionRoutesDetails]>
pub fn routes(&self) -> Option<&[AwsEc2VpnConnectionRoutesDetails]>
The static routes that are associated with the VPN connection.
sourcepub fn transit_gateway_id(&self) -> Option<&str>
pub fn transit_gateway_id(&self) -> Option<&str>
The identifier of the transit gateway that is associated with the VPN connection.
sourceimpl AwsEc2VpnConnectionDetails
impl AwsEc2VpnConnectionDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsEc2VpnConnectionDetails.