Struct aws_sdk_securityhub::model::AwsEc2VpnConnectionVgwTelemetryDetails [−][src]
#[non_exhaustive]pub struct AwsEc2VpnConnectionVgwTelemetryDetails {
pub accepted_route_count: i32,
pub certificate_arn: Option<String>,
pub last_status_change: Option<String>,
pub outside_ip_address: Option<String>,
pub status: Option<String>,
pub status_message: Option<String>,
}Expand description
Information about the VPN tunnel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accepted_route_count: i32The number of accepted routes.
certificate_arn: Option<String>The ARN of the VPN tunnel endpoint certificate.
last_status_change: Option<String>The date and time of the last change in status.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
outside_ip_address: Option<String>The Internet-routable IP address of the virtual private gateway's outside interface.
status: Option<String>The status of the VPN tunnel.
status_message: Option<String>If an error occurs, a description of the error.
Implementations
Creates a new builder-style object to manufacture AwsEc2VpnConnectionVgwTelemetryDetails