Struct aws_sdk_securityhub::model::AwsElasticsearchDomainDomainEndpointOptions [−][src]
#[non_exhaustive]pub struct AwsElasticsearchDomainDomainEndpointOptions {
pub enforce_https: bool,
pub tls_security_policy: Option<String>,
}Expand description
Additional options for the domain endpoint, such as whether to require HTTPS for all traffic.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enforce_https: boolWhether to require that all traffic to the domain arrive over HTTPS.
tls_security_policy: Option<String>The TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.
Valid values:
-
Policy-Min-TLS-1-0-2019-07, which supports TLSv1.0 and higher -
Policy-Min-TLS-1-2-2019-07, which only supports TLSv1.2
Implementations
Creates a new builder-style object to manufacture AwsElasticsearchDomainDomainEndpointOptions