#[non_exhaustive]pub struct AwsElbv2LoadBalancerDetails { /* private fields */ }Expand description
Information about a load balancer.
Implementations
sourceimpl AwsElbv2LoadBalancerDetails
impl AwsElbv2LoadBalancerDetails
sourcepub fn availability_zones(&self) -> Option<&[AvailabilityZone]>
pub fn availability_zones(&self) -> Option<&[AvailabilityZone]>
The Availability Zones for the load balancer.
sourcepub fn canonical_hosted_zone_id(&self) -> Option<&str>
pub fn canonical_hosted_zone_id(&self) -> Option<&str>
The ID of the Amazon Route 53 hosted zone associated with the load balancer.
sourcepub fn created_time(&self) -> Option<&str>
pub fn created_time(&self) -> Option<&str>
Indicates when the load balancer was created.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn ip_address_type(&self) -> Option<&str>
pub fn ip_address_type(&self) -> Option<&str>
The type of IP addresses used by the subnets for your load balancer. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses).
sourcepub fn scheme(&self) -> Option<&str>
pub fn scheme(&self) -> Option<&str>
The nodes of an Internet-facing load balancer have public IP addresses.
sourcepub fn security_groups(&self) -> Option<&[String]>
pub fn security_groups(&self) -> Option<&[String]>
The IDs of the security groups for the load balancer.
sourcepub fn state(&self) -> Option<&LoadBalancerState>
pub fn state(&self) -> Option<&LoadBalancerState>
The state of the load balancer.
sourcepub fn load_balancer_attributes(
&self
) -> Option<&[AwsElbv2LoadBalancerAttribute]>
pub fn load_balancer_attributes(
&self
) -> Option<&[AwsElbv2LoadBalancerAttribute]>
Attributes of the load balancer.
sourceimpl AwsElbv2LoadBalancerDetails
impl AwsElbv2LoadBalancerDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsElbv2LoadBalancerDetails.