Struct aws_sdk_securityhub::model::AwsRedshiftClusterClusterParameterStatus [−][src]
#[non_exhaustive]pub struct AwsRedshiftClusterClusterParameterStatus {
pub parameter_name: Option<String>,
pub parameter_apply_status: Option<String>,
pub parameter_apply_error_description: Option<String>,
}Expand description
The status of a parameter in a cluster parameter group for an Amazon Redshift cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameter_name: Option<String>The name of the parameter.
parameter_apply_status: Option<String>The status of the parameter. Indicates whether the parameter is in sync with the database, waiting for a cluster reboot, or encountered an error when it was applied.
Valid values: in-sync | pending-reboot | applying
| invalid-parameter | apply-deferred | apply-error |
unknown-error
parameter_apply_error_description: Option<String>The error that prevented the parameter from being applied to the database.
Implementations
Creates a new builder-style object to manufacture AwsRedshiftClusterClusterParameterStatus