Struct aws_sdk_securityhub::model::AwsRedshiftClusterPendingModifiedValues [−][src]
#[non_exhaustive]pub struct AwsRedshiftClusterPendingModifiedValues {
pub automated_snapshot_retention_period: i32,
pub cluster_identifier: Option<String>,
pub cluster_type: Option<String>,
pub cluster_version: Option<String>,
pub encryption_type: Option<String>,
pub enhanced_vpc_routing: bool,
pub maintenance_track_name: Option<String>,
pub master_user_password: Option<String>,
pub node_type: Option<String>,
pub number_of_nodes: i32,
pub publicly_accessible: bool,
}Expand description
Changes to the Amazon Redshift cluster that are currently pending.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.automated_snapshot_retention_period: i32The pending or in-progress change to the automated snapshot retention period.
cluster_identifier: Option<String>The pending or in-progress change to the identifier for the cluster.
cluster_type: Option<String>The pending or in-progress change to the cluster type.
cluster_version: Option<String>The pending or in-progress change to the service version.
encryption_type: Option<String>The encryption type for a cluster.
enhanced_vpc_routing: boolIndicates whether to create the cluster with enhanced VPC routing enabled.
maintenance_track_name: Option<String>The name of the maintenance track that the cluster changes to during the next maintenance window.
master_user_password: Option<String>The pending or in-progress change to the master user password for the cluster.
node_type: Option<String>The pending or in-progress change to the cluster's node type.
number_of_nodes: i32The pending or in-progress change to the number of nodes in the cluster.
publicly_accessible: boolThe pending or in-progress change to whether the cluster can be connected to from the public network.
Implementations
Creates a new builder-style object to manufacture AwsRedshiftClusterPendingModifiedValues