Struct aws_sdk_securityhub::model::AwsS3AccountPublicAccessBlockDetails [−][src]
#[non_exhaustive]pub struct AwsS3AccountPublicAccessBlockDetails {
pub block_public_acls: bool,
pub block_public_policy: bool,
pub ignore_public_acls: bool,
pub restrict_public_buckets: bool,
}Expand description
provides information about the Amazon S3 Public Access Block configuration for accounts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.block_public_acls: boolIndicates whether to reject calls to update an S3 bucket if the calls include a public access control list (ACL).
block_public_policy: boolIndicates whether to reject calls to update the access policy for an S3 bucket or access point if the policy allows public access.
ignore_public_acls: boolIndicates whether Amazon S3 ignores public ACLs that are associated with an S3 bucket.
restrict_public_buckets: boolIndicates whether to restrict access to an access point or S3 bucket that has a public policy to only Amazon Web Services service principals and authorized users within the S3 bucket owner's account.
Implementations
Creates a new builder-style object to manufacture AwsS3AccountPublicAccessBlockDetails