#[non_exhaustive]pub struct AwsS3BucketBucketLifecycleConfigurationRulesDetails { /* private fields */ }Expand description
Configuration for a lifecycle rule.
Implementations
sourceimpl AwsS3BucketBucketLifecycleConfigurationRulesDetails
impl AwsS3BucketBucketLifecycleConfigurationRulesDetails
sourcepub fn abort_incomplete_multipart_upload(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationRulesAbortIncompleteMultipartUploadDetails>
pub fn abort_incomplete_multipart_upload(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationRulesAbortIncompleteMultipartUploadDetails>
How Amazon S3 responds when a multipart upload is incomplete. Specifically, provides a number of days before Amazon S3 cancels the entire upload.
sourcepub fn expiration_date(&self) -> Option<&str>
pub fn expiration_date(&self) -> Option<&str>
The date when objects are moved or deleted.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn expiration_in_days(&self) -> i32
pub fn expiration_in_days(&self) -> i32
The length in days of the lifetime for objects that are subject to the rule.
sourcepub fn expired_object_delete_marker(&self) -> bool
pub fn expired_object_delete_marker(&self) -> bool
Whether Amazon S3 removes a delete marker that has no noncurrent versions. If set to true, the delete marker is expired. If set to false, the policy takes no action.
If you provide ExpiredObjectDeleteMarker, you cannot provide ExpirationInDays or ExpirationDate.
sourcepub fn filter(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationRulesFilterDetails>
pub fn filter(
&self
) -> Option<&AwsS3BucketBucketLifecycleConfigurationRulesFilterDetails>
Identifies the objects that a rule applies to.
sourcepub fn noncurrent_version_expiration_in_days(&self) -> i32
pub fn noncurrent_version_expiration_in_days(&self) -> i32
The number of days that an object is noncurrent before Amazon S3 can perform the associated action.
sourcepub fn noncurrent_version_transitions(
&self
) -> Option<&[AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetails]>
pub fn noncurrent_version_transitions(
&self
) -> Option<&[AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetails]>
Transition rules that describe when noncurrent objects transition to a specified storage class.
sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
A prefix that identifies one or more objects that the rule applies to.
sourcepub fn status(&self) -> Option<&str>
pub fn status(&self) -> Option<&str>
The current status of the rule. Indicates whether the rule is currently being applied.
sourcepub fn transitions(
&self
) -> Option<&[AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails]>
pub fn transitions(
&self
) -> Option<&[AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails]>
Transition rules that indicate when objects transition to a specified storage class.
sourceimpl AwsS3BucketBucketLifecycleConfigurationRulesDetails
impl AwsS3BucketBucketLifecycleConfigurationRulesDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketBucketLifecycleConfigurationRulesDetails.