Struct aws_sdk_securityhub::model::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
source · [−]#[non_exhaustive]pub struct AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails { /* private fields */ }Expand description
A rule for when objects transition to specific storage classes.
Implementations
sourceimpl AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
impl AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
sourcepub fn date(&self) -> Option<&str>
pub fn date(&self) -> Option<&str>
A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.
Uses the date-time format specified in RFC 3339 section 5.6, Internet Date/Time Format. The value cannot contain spaces. For example, 2020-03-22T13:22:13.933Z.
sourcepub fn days(&self) -> i32
pub fn days(&self) -> i32
The number of days after which to transition the object to the specified storage class. If you provide Days, you cannot provide Date.
sourcepub fn storage_class(&self) -> Option<&str>
pub fn storage_class(&self) -> Option<&str>
The storage class to transition the object to. Valid values are as follows:
-
DEEP_ARCHIVE -
GLACIER -
INTELLIGENT_TIERING -
ONEZONE_IA -
STANDARD_IA
sourceimpl AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
impl AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails.