Struct aws_sdk_securityhub::model::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails [−][src]
#[non_exhaustive]pub struct AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails {
pub date: Option<String>,
pub days: i32,
pub storage_class: Option<String>,
}Expand description
A rule for when objects transition to specific storage classes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.date: Option<String>A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.
Uses the date-time format specified in RFC 3339 section 5.6, Internet
Date/Time Format. The value cannot contain spaces. For example,
2020-03-22T13:22:13.933Z.
days: i32The number of days after which to transition the object to the specified storage class. If you provide Days, you cannot provide Date.
storage_class: Option<String>The storage class to transition the object to.
Implementations
Creates a new builder-style object to manufacture AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails