Struct aws_sdk_securityhub::model::AwsS3BucketWebsiteConfigurationRoutingRuleCondition [−][src]
#[non_exhaustive]pub struct AwsS3BucketWebsiteConfigurationRoutingRuleCondition {
pub http_error_code_returned_equals: Option<String>,
pub key_prefix_equals: Option<String>,
}Expand description
The condition that must be met in order to apply the routing rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.http_error_code_returned_equals: Option<String>Indicates to redirect the request if the HTTP error code matches this value.
key_prefix_equals: Option<String>Indicates to redirect the request if the key prefix matches this value.
Implementations
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfigurationRoutingRuleCondition