Struct aws_sdk_securityhub::model::AwsS3BucketWebsiteConfigurationRoutingRuleRedirect [−][src]
#[non_exhaustive]pub struct AwsS3BucketWebsiteConfigurationRoutingRuleRedirect {
pub hostname: Option<String>,
pub http_redirect_code: Option<String>,
pub protocol: Option<String>,
pub replace_key_prefix_with: Option<String>,
pub replace_key_with: Option<String>,
}Expand description
The rules to redirect the request if the condition in Condition is
met.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hostname: Option<String>The host name to use in the redirect request.
http_redirect_code: Option<String>The HTTP redirect code to use in the response.
protocol: Option<String>The protocol to use to redirect the request. By default, uses the protocol from the original request.
replace_key_prefix_with: Option<String>The object key prefix to use in the redirect request.
Cannot be provided if ReplaceKeyWith is present.
replace_key_with: Option<String>The specific object key to use in the redirect request.
Cannot be provided if ReplaceKeyPrefixWith is present.
Implementations
Creates a new builder-style object to manufacture AwsS3BucketWebsiteConfigurationRoutingRuleRedirect