Struct aws_sdk_securityhub::model::AwsSsmComplianceSummary [−][src]
#[non_exhaustive]pub struct AwsSsmComplianceSummary {Show 18 fields
pub status: Option<String>,
pub compliant_critical_count: i32,
pub compliant_high_count: i32,
pub compliant_medium_count: i32,
pub execution_type: Option<String>,
pub non_compliant_critical_count: i32,
pub compliant_informational_count: i32,
pub non_compliant_informational_count: i32,
pub compliant_unspecified_count: i32,
pub non_compliant_low_count: i32,
pub non_compliant_high_count: i32,
pub compliant_low_count: i32,
pub compliance_type: Option<String>,
pub patch_baseline_id: Option<String>,
pub overall_severity: Option<String>,
pub non_compliant_medium_count: i32,
pub non_compliant_unspecified_count: i32,
pub patch_group: Option<String>,
}Expand description
Provides the details about the compliance status for a patch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<String>The current patch compliance status.
The possible status values are:
-
COMPLIANT -
NON_COMPLIANT -
UNSPECIFIED_DATA
compliant_critical_count: i32For the patches that are compliant, the number that have a severity of
CRITICAL.
compliant_high_count: i32For the patches that are compliant, the number that have a severity of
HIGH.
compliant_medium_count: i32For the patches that are compliant, the number that have a severity of
MEDIUM.
execution_type: Option<String>The type of execution that was used determine compliance.
non_compliant_critical_count: i32For the patch items that are noncompliant, the number of items that have a severity of
CRITICAL.
compliant_informational_count: i32For the patches that are compliant, the number that have a severity of
INFORMATIONAL.
non_compliant_informational_count: i32For the patches that are noncompliant, the number that have a severity of
INFORMATIONAL.
compliant_unspecified_count: i32For the patches that are compliant, the number that have a severity of
UNSPECIFIED.
non_compliant_low_count: i32For the patches that are noncompliant, the number that have a severity of
LOW.
non_compliant_high_count: i32For the patches that are noncompliant, the number that have a severity of
HIGH.
compliant_low_count: i32For the patches that are compliant, the number that have a severity of
LOW.
compliance_type: Option<String>The type of resource for which the compliance was determined. For
AwsSsmPatchCompliance, ComplianceType is Patch.
patch_baseline_id: Option<String>The identifier of the patch baseline. The patch baseline lists the patches that are approved for installation.
overall_severity: Option<String>The highest severity for the patches.
non_compliant_medium_count: i32For the patches that are noncompliant, the number that have a severity of
MEDIUM.
non_compliant_unspecified_count: i32For the patches that are noncompliant, the number that have a severity of
UNSPECIFIED.
patch_group: Option<String>The identifier of the patch group for which compliance was determined. A patch group uses tags to group EC2 instances that should have the same patch compliance.
Implementations
Creates a new builder-style object to manufacture AwsSsmComplianceSummary