Struct aws_sdk_securityhub::output::batch_disable_standards_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchDisableStandardsOutput
Implementations
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The details of the standards subscriptions that were disabled.
The details of the standards subscriptions that were disabled.
Consumes the builder and constructs a BatchDisableStandardsOutput