Struct aws_sdk_securityhub::output::batch_enable_standards_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchEnableStandardsOutput
Implementations
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The details of the standards subscriptions that were enabled.
The details of the standards subscriptions that were enabled.
Consumes the builder and constructs a BatchEnableStandardsOutput