Struct aws_sdk_securityhub::output::batch_update_findings_output::Builder[][src]

#[non_exhaustive]
pub struct Builder { /* fields omitted */ }
Implementations

Appends an item to processed_findings.

To override the contents of this collection use set_processed_findings.

The list of findings that were updated successfully.

The list of findings that were updated successfully.

Appends an item to unprocessed_findings.

To override the contents of this collection use set_unprocessed_findings.

The list of findings that were not updated.

The list of findings that were not updated.

Consumes the builder and constructs a BatchUpdateFindingsOutput