Struct aws_sdk_securityhub::output::get_enabled_standards_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetEnabledStandardsOutput
Implementations
Appends an item to standards_subscriptions.
To override the contents of this collection use set_standards_subscriptions.
The list of StandardsSubscriptions objects that include information about
the enabled standards.
The list of StandardsSubscriptions objects that include information about
the enabled standards.
The pagination token to use to request the next page of results.
The pagination token to use to request the next page of results.
Consumes the builder and constructs a GetEnabledStandardsOutput