Struct aws_sdk_securityhub::output::list_finding_aggregators_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListFindingAggregatorsOutput
Implementations
Appends an item to finding_aggregators.
To override the contents of this collection use set_finding_aggregators.
The list of finding aggregators. This operation currently only returns a single result.
The list of finding aggregators. This operation currently only returns a single result.
If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
Consumes the builder and constructs a ListFindingAggregatorsOutput