#[non_exhaustive]pub struct ListFindingAggregatorsOutput { /* private fields */ }Implementations
sourceimpl ListFindingAggregatorsOutput
impl ListFindingAggregatorsOutput
sourcepub fn finding_aggregators(&self) -> Option<&[FindingAggregator]>
pub fn finding_aggregators(&self) -> Option<&[FindingAggregator]>
The list of finding aggregators. This operation currently only returns a single result.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
sourceimpl ListFindingAggregatorsOutput
impl ListFindingAggregatorsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListFindingAggregatorsOutput.