Struct aws_sdk_securityhub::output::ListFindingAggregatorsOutput [−][src]
#[non_exhaustive]pub struct ListFindingAggregatorsOutput {
pub finding_aggregators: Option<Vec<FindingAggregator>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding_aggregators: Option<Vec<FindingAggregator>>The list of finding aggregators. This operation currently only returns a single result.
next_token: Option<String>If there are more results, this is the token to provide in the next call to ListFindingAggregators.
This operation currently only returns a single result.
Implementations
Creates a new builder-style object to manufacture ListFindingAggregatorsOutput