#[non_exhaustive]pub struct ResourceResultBuilder { /* private fields */ }Expand description
A builder for ResourceResult.
Implementations
Sourceimpl ResourceResultBuilder
impl ResourceResultBuilder
Sourcepub fn resource_guid(self, input: impl Into<String>) -> Self
pub fn resource_guid(self, input: impl Into<String>) -> Self
The global identifier used to identify a resource.
Sourcepub fn set_resource_guid(self, input: Option<String>) -> Self
pub fn set_resource_guid(self, input: Option<String>) -> Self
The global identifier used to identify a resource.
Sourcepub fn get_resource_guid(&self) -> &Option<String>
pub fn get_resource_guid(&self) -> &Option<String>
The global identifier used to identify a resource.
Sourcepub fn resource_id(self, input: impl Into<String>) -> Self
pub fn resource_id(self, input: impl Into<String>) -> Self
The unique identifier for a resource.
This field is required.Sourcepub fn set_resource_id(self, input: Option<String>) -> Self
pub fn set_resource_id(self, input: Option<String>) -> Self
The unique identifier for a resource.
Sourcepub fn get_resource_id(&self) -> &Option<String>
pub fn get_resource_id(&self) -> &Option<String>
The unique identifier for a resource.
Sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account that recorded the resource data in Security Hub.
This field is required.Sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
The Amazon Web Services account that recorded the resource data in Security Hub.
Sourcepub fn get_account_id(&self) -> &Option<String>
pub fn get_account_id(&self) -> &Option<String>
The Amazon Web Services account that recorded the resource data in Security Hub.
Sourcepub fn account_name(self, input: impl Into<String>) -> Self
pub fn account_name(self, input: impl Into<String>) -> Self
The name of the Amazon Web Services account that's associated with the resource.
Sourcepub fn set_account_name(self, input: Option<String>) -> Self
pub fn set_account_name(self, input: Option<String>) -> Self
The name of the Amazon Web Services account that's associated with the resource.
Sourcepub fn get_account_name(&self) -> &Option<String>
pub fn get_account_name(&self) -> &Option<String>
The name of the Amazon Web Services account that's associated with the resource.
Sourcepub fn region(self, input: impl Into<String>) -> Self
pub fn region(self, input: impl Into<String>) -> Self
The Amazon Web Services Region that recorded the resource data in Security Hub.
This field is required.Sourcepub fn set_region(self, input: Option<String>) -> Self
pub fn set_region(self, input: Option<String>) -> Self
The Amazon Web Services Region that recorded the resource data in Security Hub.
Sourcepub fn get_region(&self) -> &Option<String>
pub fn get_region(&self) -> &Option<String>
The Amazon Web Services Region that recorded the resource data in Security Hub.
Sourcepub fn resource_provider(self, input: impl Into<String>) -> Self
pub fn resource_provider(self, input: impl Into<String>) -> Self
The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.
Sourcepub fn set_resource_provider(self, input: Option<String>) -> Self
pub fn set_resource_provider(self, input: Option<String>) -> Self
The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.
Sourcepub fn get_resource_provider(&self) -> &Option<String>
pub fn get_resource_provider(&self) -> &Option<String>
The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.
Sourcepub fn resource_owner_account_id(self, input: impl Into<String>) -> Self
pub fn resource_owner_account_id(self, input: impl Into<String>) -> Self
The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
Sourcepub fn set_resource_owner_account_id(self, input: Option<String>) -> Self
pub fn set_resource_owner_account_id(self, input: Option<String>) -> Self
The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
Sourcepub fn get_resource_owner_account_id(&self) -> &Option<String>
pub fn get_resource_owner_account_id(&self) -> &Option<String>
The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
Sourcepub fn resource_owner_org_id(self, input: impl Into<String>) -> Self
pub fn resource_owner_org_id(self, input: impl Into<String>) -> Self
The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
Sourcepub fn set_resource_owner_org_id(self, input: Option<String>) -> Self
pub fn set_resource_owner_org_id(self, input: Option<String>) -> Self
The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
Sourcepub fn get_resource_owner_org_id(&self) -> &Option<String>
pub fn get_resource_owner_org_id(&self) -> &Option<String>
The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
Sourcepub fn resource_cloud_partition(self, input: impl Into<String>) -> Self
pub fn resource_cloud_partition(self, input: impl Into<String>) -> Self
The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.
Sourcepub fn set_resource_cloud_partition(self, input: Option<String>) -> Self
pub fn set_resource_cloud_partition(self, input: Option<String>) -> Self
The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.
Sourcepub fn get_resource_cloud_partition(&self) -> &Option<String>
pub fn get_resource_cloud_partition(&self) -> &Option<String>
The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.
Sourcepub fn resource_region(self, input: impl Into<String>) -> Self
pub fn resource_region(self, input: impl Into<String>) -> Self
The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.
Sourcepub fn set_resource_region(self, input: Option<String>) -> Self
pub fn set_resource_region(self, input: Option<String>) -> Self
The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.
Sourcepub fn get_resource_region(&self) -> &Option<String>
pub fn get_resource_region(&self) -> &Option<String>
The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.
Sourcepub fn resource_category(self, input: ResourceCategory) -> Self
pub fn resource_category(self, input: ResourceCategory) -> Self
The grouping where the resource belongs.
Sourcepub fn set_resource_category(self, input: Option<ResourceCategory>) -> Self
pub fn set_resource_category(self, input: Option<ResourceCategory>) -> Self
The grouping where the resource belongs.
Sourcepub fn get_resource_category(&self) -> &Option<ResourceCategory>
pub fn get_resource_category(&self) -> &Option<ResourceCategory>
The grouping where the resource belongs.
Sourcepub fn resource_type(self, input: impl Into<String>) -> Self
pub fn resource_type(self, input: impl Into<String>) -> Self
The type of resource.
This field is required.Sourcepub fn set_resource_type(self, input: Option<String>) -> Self
pub fn set_resource_type(self, input: Option<String>) -> Self
The type of resource.
Sourcepub fn get_resource_type(&self) -> &Option<String>
pub fn get_resource_type(&self) -> &Option<String>
The type of resource.
Sourcepub fn resource_name(self, input: impl Into<String>) -> Self
pub fn resource_name(self, input: impl Into<String>) -> Self
The name of the resource.
Sourcepub fn set_resource_name(self, input: Option<String>) -> Self
pub fn set_resource_name(self, input: Option<String>) -> Self
The name of the resource.
Sourcepub fn get_resource_name(&self) -> &Option<String>
pub fn get_resource_name(&self) -> &Option<String>
The name of the resource.
Sourcepub fn resource_creation_time_dt(self, input: impl Into<String>) -> Self
pub fn resource_creation_time_dt(self, input: impl Into<String>) -> Self
The time when the resource was created.
Sourcepub fn set_resource_creation_time_dt(self, input: Option<String>) -> Self
pub fn set_resource_creation_time_dt(self, input: Option<String>) -> Self
The time when the resource was created.
Sourcepub fn get_resource_creation_time_dt(&self) -> &Option<String>
pub fn get_resource_creation_time_dt(&self) -> &Option<String>
The time when the resource was created.
Sourcepub fn resource_detail_capture_time_dt(self, input: impl Into<String>) -> Self
pub fn resource_detail_capture_time_dt(self, input: impl Into<String>) -> Self
The timestamp when information about the resource was captured.
This field is required.Sourcepub fn set_resource_detail_capture_time_dt(self, input: Option<String>) -> Self
pub fn set_resource_detail_capture_time_dt(self, input: Option<String>) -> Self
The timestamp when information about the resource was captured.
Sourcepub fn get_resource_detail_capture_time_dt(&self) -> &Option<String>
pub fn get_resource_detail_capture_time_dt(&self) -> &Option<String>
The timestamp when information about the resource was captured.
Sourcepub fn findings_summary(self, input: ResourceFindingsSummary) -> Self
pub fn findings_summary(self, input: ResourceFindingsSummary) -> Self
Appends an item to findings_summary.
To override the contents of this collection use set_findings_summary.
An aggregated view of security findings associated with a resource.
Sourcepub fn set_findings_summary(
self,
input: Option<Vec<ResourceFindingsSummary>>,
) -> Self
pub fn set_findings_summary( self, input: Option<Vec<ResourceFindingsSummary>>, ) -> Self
An aggregated view of security findings associated with a resource.
Sourcepub fn get_findings_summary(&self) -> &Option<Vec<ResourceFindingsSummary>>
pub fn get_findings_summary(&self) -> &Option<Vec<ResourceFindingsSummary>>
An aggregated view of security findings associated with a resource.
Appends an item to resource_tags.
To override the contents of this collection use set_resource_tags.
The key-value pairs associated with a resource.
The key-value pairs associated with a resource.
The key-value pairs associated with a resource.
Sourcepub fn resource_config(self, input: Document) -> Self
pub fn resource_config(self, input: Document) -> Self
The configuration details of a resource.
This field is required.Sourcepub fn set_resource_config(self, input: Option<Document>) -> Self
pub fn set_resource_config(self, input: Option<Document>) -> Self
The configuration details of a resource.
Sourcepub fn get_resource_config(&self) -> &Option<Document>
pub fn get_resource_config(&self) -> &Option<Document>
The configuration details of a resource.
Sourcepub fn resource_sub_category(self, input: ResourceSubCategory) -> Self
pub fn resource_sub_category(self, input: ResourceSubCategory) -> Self
The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.
Sourcepub fn set_resource_sub_category(
self,
input: Option<ResourceSubCategory>,
) -> Self
pub fn set_resource_sub_category( self, input: Option<ResourceSubCategory>, ) -> Self
The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.
Sourcepub fn get_resource_sub_category(&self) -> &Option<ResourceSubCategory>
pub fn get_resource_sub_category(&self) -> &Option<ResourceSubCategory>
The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.
Sourcepub fn discovery_type(self, input: DiscoveryType) -> Self
pub fn discovery_type(self, input: DiscoveryType) -> Self
Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.
Sourcepub fn set_discovery_type(self, input: Option<DiscoveryType>) -> Self
pub fn set_discovery_type(self, input: Option<DiscoveryType>) -> Self
Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.
Sourcepub fn get_discovery_type(&self) -> &Option<DiscoveryType>
pub fn get_discovery_type(&self) -> &Option<DiscoveryType>
Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.
Sourcepub fn resource_info(self, input: ResourceInfo) -> Self
pub fn resource_info(self, input: ResourceInfo) -> Self
Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.
Sourcepub fn set_resource_info(self, input: Option<ResourceInfo>) -> Self
pub fn set_resource_info(self, input: Option<ResourceInfo>) -> Self
Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.
Sourcepub fn get_resource_info(&self) -> &Option<ResourceInfo>
pub fn get_resource_info(&self) -> &Option<ResourceInfo>
Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.
Sourcepub fn build(self) -> ResourceResult
pub fn build(self) -> ResourceResult
Consumes the builder and constructs a ResourceResult.